Class: Google::Cloud::Sql::V1::AclEntry
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::AclEntry
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb
Overview
An entry for an Access Control list.
Instance Attribute Summary collapse
-
#expiration_time ⇒ ::Google::Protobuf::Timestamp
The time when this access control entry expires in RFC 3339 format, for example
2012-11-15T16:19:00.094Z. -
#kind ⇒ ::String
This is always
sql#aclEntry. -
#name ⇒ ::String
Optional.
-
#value ⇒ ::String
The allowlisted value for the access control list.
Instance Attribute Details
#expiration_time ⇒ ::Google::Protobuf::Timestamp
Returns The time when this access control entry expires in
RFC 3339 format, for example
2012-11-15T16:19:00.094Z.
39 40 41 42 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 39 class AclEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#kind ⇒ ::String
Returns This is always sql#aclEntry.
39 40 41 42 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 39 class AclEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |