Class: Google::Cloud::Sql::V1::Backup

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_backups.rb

Overview

A backup resource.

Defined Under Namespace

Modules: SqlBackupState, SqlBackupType

Instance Attribute Summary collapse

Instance Attribute Details

#backup_interval::Google::Type::Interval (readonly)

Returns Output only. This output contains the following values: start_time: All database writes up to this time are available. end_time: Any database writes after this time aren't available.

Returns:

  • (::Google::Type::Interval)

    Output only. This output contains the following values: start_time: All database writes up to this time are available. end_time: Any database writes after this time aren't available.



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backups.rb', line 213

class Backup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The backup type.
  module SqlBackupType
    # This is an unknown backup type.
    SQL_BACKUP_TYPE_UNSPECIFIED = 0

    # The backup schedule triggers a backup automatically.
    AUTOMATED = 1

    # The user triggers a backup manually.
    ON_DEMAND = 2

    # The backup created when instance is deleted.
    FINAL = 3
  end

  # The backup's state
  module SqlBackupState
    # The state of the backup is unknown.
    SQL_BACKUP_STATE_UNSPECIFIED = 0

    # The backup that's added to a queue.
    ENQUEUED = 1

    # The backup is in progress.
    RUNNING = 2

    # The backup failed.
    FAILED = 3

    # The backup is successful.
    SUCCESSFUL = 4

    # The backup is being deleted.
    DELETING = 5

    # Deletion of the backup failed.
    DELETION_FAILED = 6
  end
end

#backup_kind::Google::Cloud::Sql::V1::SqlBackupKind (readonly)

Returns Output only. Specifies the kind of backup, PHYSICAL or DEFAULT_SNAPSHOT.

Returns:



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backups.rb', line 213

class Backup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The backup type.
  module SqlBackupType
    # This is an unknown backup type.
    SQL_BACKUP_TYPE_UNSPECIFIED = 0

    # The backup schedule triggers a backup automatically.
    AUTOMATED = 1

    # The user triggers a backup manually.
    ON_DEMAND = 2

    # The backup created when instance is deleted.
    FINAL = 3
  end

  # The backup's state
  module SqlBackupState
    # The state of the backup is unknown.
    SQL_BACKUP_STATE_UNSPECIFIED = 0

    # The backup that's added to a queue.
    ENQUEUED = 1

    # The backup is in progress.
    RUNNING = 2

    # The backup failed.
    FAILED = 3

    # The backup is successful.
    SUCCESSFUL = 4

    # The backup is being deleted.
    DELETING = 5

    # Deletion of the backup failed.
    DELETION_FAILED = 6
  end
end

#backup_run::String (readonly)

Returns Output only. The mapping to backup run resource used for IAM validations.

Returns:

  • (::String)

    Output only. The mapping to backup run resource used for IAM validations.



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backups.rb', line 213

class Backup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The backup type.
  module SqlBackupType
    # This is an unknown backup type.
    SQL_BACKUP_TYPE_UNSPECIFIED = 0

    # The backup schedule triggers a backup automatically.
    AUTOMATED = 1

    # The user triggers a backup manually.
    ON_DEMAND = 2

    # The backup created when instance is deleted.
    FINAL = 3
  end

  # The backup's state
  module SqlBackupState
    # The state of the backup is unknown.
    SQL_BACKUP_STATE_UNSPECIFIED = 0

    # The backup that's added to a queue.
    ENQUEUED = 1

    # The backup is in progress.
    RUNNING = 2

    # The backup failed.
    FAILED = 3

    # The backup is successful.
    SUCCESSFUL = 4

    # The backup is being deleted.
    DELETING = 5

    # Deletion of the backup failed.
    DELETION_FAILED = 6
  end
end

#database_version::Google::Cloud::Sql::V1::SqlDatabaseVersion (readonly)

Returns Output only. The database version of the instance of at the time this backup was made.

Returns:



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backups.rb', line 213

class Backup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The backup type.
  module SqlBackupType
    # This is an unknown backup type.
    SQL_BACKUP_TYPE_UNSPECIFIED = 0

    # The backup schedule triggers a backup automatically.
    AUTOMATED = 1

    # The user triggers a backup manually.
    ON_DEMAND = 2

    # The backup created when instance is deleted.
    FINAL = 3
  end

  # The backup's state
  module SqlBackupState
    # The state of the backup is unknown.
    SQL_BACKUP_STATE_UNSPECIFIED = 0

    # The backup that's added to a queue.
    ENQUEUED = 1

    # The backup is in progress.
    RUNNING = 2

    # The backup failed.
    FAILED = 3

    # The backup is successful.
    SUCCESSFUL = 4

    # The backup is being deleted.
    DELETING = 5

    # Deletion of the backup failed.
    DELETION_FAILED = 6
  end
end

#description::String

Returns The description of this backup.

Returns:

  • (::String)

    The description of this backup.



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backups.rb', line 213

class Backup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The backup type.
  module SqlBackupType
    # This is an unknown backup type.
    SQL_BACKUP_TYPE_UNSPECIFIED = 0

    # The backup schedule triggers a backup automatically.
    AUTOMATED = 1

    # The user triggers a backup manually.
    ON_DEMAND = 2

    # The backup created when instance is deleted.
    FINAL = 3
  end

  # The backup's state
  module SqlBackupState
    # The state of the backup is unknown.
    SQL_BACKUP_STATE_UNSPECIFIED = 0

    # The backup that's added to a queue.
    ENQUEUED = 1

    # The backup is in progress.
    RUNNING = 2

    # The backup failed.
    FAILED = 3

    # The backup is successful.
    SUCCESSFUL = 4

    # The backup is being deleted.
    DELETING = 5

    # Deletion of the backup failed.
    DELETION_FAILED = 6
  end
end

#error::Google::Cloud::Sql::V1::OperationError (readonly)

Returns Output only. Information about why the backup operation fails (for example, when the backup state fails).

Returns:



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backups.rb', line 213

class Backup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The backup type.
  module SqlBackupType
    # This is an unknown backup type.
    SQL_BACKUP_TYPE_UNSPECIFIED = 0

    # The backup schedule triggers a backup automatically.
    AUTOMATED = 1

    # The user triggers a backup manually.
    ON_DEMAND = 2

    # The backup created when instance is deleted.
    FINAL = 3
  end

  # The backup's state
  module SqlBackupState
    # The state of the backup is unknown.
    SQL_BACKUP_STATE_UNSPECIFIED = 0

    # The backup that's added to a queue.
    ENQUEUED = 1

    # The backup is in progress.
    RUNNING = 2

    # The backup failed.
    FAILED = 3

    # The backup is successful.
    SUCCESSFUL = 4

    # The backup is being deleted.
    DELETING = 5

    # Deletion of the backup failed.
    DELETION_FAILED = 6
  end
end

#expiry_time::Google::Protobuf::Timestamp

Returns Backup expiration time. A UTC timestamp of when this backup expired.

Note: The following fields are mutually exclusive: expiry_time, ttl_days. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Protobuf::Timestamp)

    Backup expiration time. A UTC timestamp of when this backup expired.

    Note: The following fields are mutually exclusive: expiry_time, ttl_days. If a field in that set is populated, all other fields in the set will automatically be cleared.



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backups.rb', line 213

class Backup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The backup type.
  module SqlBackupType
    # This is an unknown backup type.
    SQL_BACKUP_TYPE_UNSPECIFIED = 0

    # The backup schedule triggers a backup automatically.
    AUTOMATED = 1

    # The user triggers a backup manually.
    ON_DEMAND = 2

    # The backup created when instance is deleted.
    FINAL = 3
  end

  # The backup's state
  module SqlBackupState
    # The state of the backup is unknown.
    SQL_BACKUP_STATE_UNSPECIFIED = 0

    # The backup that's added to a queue.
    ENQUEUED = 1

    # The backup is in progress.
    RUNNING = 2

    # The backup failed.
    FAILED = 3

    # The backup is successful.
    SUCCESSFUL = 4

    # The backup is being deleted.
    DELETING = 5

    # Deletion of the backup failed.
    DELETION_FAILED = 6
  end
end

#instance::String

Returns The name of the source database instance.

Returns:

  • (::String)

    The name of the source database instance.



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backups.rb', line 213

class Backup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The backup type.
  module SqlBackupType
    # This is an unknown backup type.
    SQL_BACKUP_TYPE_UNSPECIFIED = 0

    # The backup schedule triggers a backup automatically.
    AUTOMATED = 1

    # The user triggers a backup manually.
    ON_DEMAND = 2

    # The backup created when instance is deleted.
    FINAL = 3
  end

  # The backup's state
  module SqlBackupState
    # The state of the backup is unknown.
    SQL_BACKUP_STATE_UNSPECIFIED = 0

    # The backup that's added to a queue.
    ENQUEUED = 1

    # The backup is in progress.
    RUNNING = 2

    # The backup failed.
    FAILED = 3

    # The backup is successful.
    SUCCESSFUL = 4

    # The backup is being deleted.
    DELETING = 5

    # Deletion of the backup failed.
    DELETION_FAILED = 6
  end
end

#instance_deletion_time::Google::Protobuf::Timestamp (readonly)

Returns Optional. Output only. Timestamp in UTC of when the instance associated with this backup is deleted.

Returns:



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backups.rb', line 213

class Backup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The backup type.
  module SqlBackupType
    # This is an unknown backup type.
    SQL_BACKUP_TYPE_UNSPECIFIED = 0

    # The backup schedule triggers a backup automatically.
    AUTOMATED = 1

    # The user triggers a backup manually.
    ON_DEMAND = 2

    # The backup created when instance is deleted.
    FINAL = 3
  end

  # The backup's state
  module SqlBackupState
    # The state of the backup is unknown.
    SQL_BACKUP_STATE_UNSPECIFIED = 0

    # The backup that's added to a queue.
    ENQUEUED = 1

    # The backup is in progress.
    RUNNING = 2

    # The backup failed.
    FAILED = 3

    # The backup is successful.
    SUCCESSFUL = 4

    # The backup is being deleted.
    DELETING = 5

    # Deletion of the backup failed.
    DELETION_FAILED = 6
  end
end

#instance_settings::Google::Cloud::Sql::V1::DatabaseInstance (readonly)

Returns Optional. Output only. The instance setting of the source instance that's associated with this backup.

Returns:



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backups.rb', line 213

class Backup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The backup type.
  module SqlBackupType
    # This is an unknown backup type.
    SQL_BACKUP_TYPE_UNSPECIFIED = 0

    # The backup schedule triggers a backup automatically.
    AUTOMATED = 1

    # The user triggers a backup manually.
    ON_DEMAND = 2

    # The backup created when instance is deleted.
    FINAL = 3
  end

  # The backup's state
  module SqlBackupState
    # The state of the backup is unknown.
    SQL_BACKUP_STATE_UNSPECIFIED = 0

    # The backup that's added to a queue.
    ENQUEUED = 1

    # The backup is in progress.
    RUNNING = 2

    # The backup failed.
    FAILED = 3

    # The backup is successful.
    SUCCESSFUL = 4

    # The backup is being deleted.
    DELETING = 5

    # Deletion of the backup failed.
    DELETION_FAILED = 6
  end
end

#kind::String (readonly)

Returns Output only. This is always sql#backup.

Returns:

  • (::String)

    Output only. This is always sql#backup.



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backups.rb', line 213

class Backup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The backup type.
  module SqlBackupType
    # This is an unknown backup type.
    SQL_BACKUP_TYPE_UNSPECIFIED = 0

    # The backup schedule triggers a backup automatically.
    AUTOMATED = 1

    # The user triggers a backup manually.
    ON_DEMAND = 2

    # The backup created when instance is deleted.
    FINAL = 3
  end

  # The backup's state
  module SqlBackupState
    # The state of the backup is unknown.
    SQL_BACKUP_STATE_UNSPECIFIED = 0

    # The backup that's added to a queue.
    ENQUEUED = 1

    # The backup is in progress.
    RUNNING = 2

    # The backup failed.
    FAILED = 3

    # The backup is successful.
    SUCCESSFUL = 4

    # The backup is being deleted.
    DELETING = 5

    # Deletion of the backup failed.
    DELETION_FAILED = 6
  end
end

#kms_key::String (readonly)

Returns Output only. This output contains the encryption configuration for a backup and the resource name of the KMS key for disk encryption.

Returns:

  • (::String)

    Output only. This output contains the encryption configuration for a backup and the resource name of the KMS key for disk encryption.



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backups.rb', line 213

class Backup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The backup type.
  module SqlBackupType
    # This is an unknown backup type.
    SQL_BACKUP_TYPE_UNSPECIFIED = 0

    # The backup schedule triggers a backup automatically.
    AUTOMATED = 1

    # The user triggers a backup manually.
    ON_DEMAND = 2

    # The backup created when instance is deleted.
    FINAL = 3
  end

  # The backup's state
  module SqlBackupState
    # The state of the backup is unknown.
    SQL_BACKUP_STATE_UNSPECIFIED = 0

    # The backup that's added to a queue.
    ENQUEUED = 1

    # The backup is in progress.
    RUNNING = 2

    # The backup failed.
    FAILED = 3

    # The backup is successful.
    SUCCESSFUL = 4

    # The backup is being deleted.
    DELETING = 5

    # Deletion of the backup failed.
    DELETION_FAILED = 6
  end
end

#kms_key_version::String (readonly)

Returns Output only. This output contains the encryption status for a backup and the version of the KMS key that's used to encrypt the Cloud SQL instance.

Returns:

  • (::String)

    Output only. This output contains the encryption status for a backup and the version of the KMS key that's used to encrypt the Cloud SQL instance.



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backups.rb', line 213

class Backup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The backup type.
  module SqlBackupType
    # This is an unknown backup type.
    SQL_BACKUP_TYPE_UNSPECIFIED = 0

    # The backup schedule triggers a backup automatically.
    AUTOMATED = 1

    # The user triggers a backup manually.
    ON_DEMAND = 2

    # The backup created when instance is deleted.
    FINAL = 3
  end

  # The backup's state
  module SqlBackupState
    # The state of the backup is unknown.
    SQL_BACKUP_STATE_UNSPECIFIED = 0

    # The backup that's added to a queue.
    ENQUEUED = 1

    # The backup is in progress.
    RUNNING = 2

    # The backup failed.
    FAILED = 3

    # The backup is successful.
    SUCCESSFUL = 4

    # The backup is being deleted.
    DELETING = 5

    # Deletion of the backup failed.
    DELETION_FAILED = 6
  end
end

#location::String

Returns The storage location of the backups. The location can be multi-regional.

Returns:

  • (::String)

    The storage location of the backups. The location can be multi-regional.



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backups.rb', line 213

class Backup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The backup type.
  module SqlBackupType
    # This is an unknown backup type.
    SQL_BACKUP_TYPE_UNSPECIFIED = 0

    # The backup schedule triggers a backup automatically.
    AUTOMATED = 1

    # The user triggers a backup manually.
    ON_DEMAND = 2

    # The backup created when instance is deleted.
    FINAL = 3
  end

  # The backup's state
  module SqlBackupState
    # The state of the backup is unknown.
    SQL_BACKUP_STATE_UNSPECIFIED = 0

    # The backup that's added to a queue.
    ENQUEUED = 1

    # The backup is in progress.
    RUNNING = 2

    # The backup failed.
    FAILED = 3

    # The backup is successful.
    SUCCESSFUL = 4

    # The backup is being deleted.
    DELETING = 5

    # Deletion of the backup failed.
    DELETION_FAILED = 6
  end
end

#max_chargeable_bytes::Integer (readonly)

Returns Output only. The maximum chargeable bytes for the backup.

Returns:

  • (::Integer)

    Output only. The maximum chargeable bytes for the backup.



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backups.rb', line 213

class Backup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The backup type.
  module SqlBackupType
    # This is an unknown backup type.
    SQL_BACKUP_TYPE_UNSPECIFIED = 0

    # The backup schedule triggers a backup automatically.
    AUTOMATED = 1

    # The user triggers a backup manually.
    ON_DEMAND = 2

    # The backup created when instance is deleted.
    FINAL = 3
  end

  # The backup's state
  module SqlBackupState
    # The state of the backup is unknown.
    SQL_BACKUP_STATE_UNSPECIFIED = 0

    # The backup that's added to a queue.
    ENQUEUED = 1

    # The backup is in progress.
    RUNNING = 2

    # The backup failed.
    FAILED = 3

    # The backup is successful.
    SUCCESSFUL = 4

    # The backup is being deleted.
    DELETING = 5

    # Deletion of the backup failed.
    DELETION_FAILED = 6
  end
end

#name::String (readonly)

Returns Output only. The resource name of the backup. Format: projects/{project}/backups/{backup}.

Returns:

  • (::String)

    Output only. The resource name of the backup. Format: projects/{project}/backups/{backup}.



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backups.rb', line 213

class Backup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The backup type.
  module SqlBackupType
    # This is an unknown backup type.
    SQL_BACKUP_TYPE_UNSPECIFIED = 0

    # The backup schedule triggers a backup automatically.
    AUTOMATED = 1

    # The user triggers a backup manually.
    ON_DEMAND = 2

    # The backup created when instance is deleted.
    FINAL = 3
  end

  # The backup's state
  module SqlBackupState
    # The state of the backup is unknown.
    SQL_BACKUP_STATE_UNSPECIFIED = 0

    # The backup that's added to a queue.
    ENQUEUED = 1

    # The backup is in progress.
    RUNNING = 2

    # The backup failed.
    FAILED = 3

    # The backup is successful.
    SUCCESSFUL = 4

    # The backup is being deleted.
    DELETING = 5

    # Deletion of the backup failed.
    DELETION_FAILED = 6
  end
end

#satisfies_pzi::Google::Protobuf::BoolValue (readonly)

Returns Output only. This status indicates whether the backup satisfies PZI.

The status is reserved for future use.

Returns:

  • (::Google::Protobuf::BoolValue)

    Output only. This status indicates whether the backup satisfies PZI.

    The status is reserved for future use.



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backups.rb', line 213

class Backup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The backup type.
  module SqlBackupType
    # This is an unknown backup type.
    SQL_BACKUP_TYPE_UNSPECIFIED = 0

    # The backup schedule triggers a backup automatically.
    AUTOMATED = 1

    # The user triggers a backup manually.
    ON_DEMAND = 2

    # The backup created when instance is deleted.
    FINAL = 3
  end

  # The backup's state
  module SqlBackupState
    # The state of the backup is unknown.
    SQL_BACKUP_STATE_UNSPECIFIED = 0

    # The backup that's added to a queue.
    ENQUEUED = 1

    # The backup is in progress.
    RUNNING = 2

    # The backup failed.
    FAILED = 3

    # The backup is successful.
    SUCCESSFUL = 4

    # The backup is being deleted.
    DELETING = 5

    # Deletion of the backup failed.
    DELETION_FAILED = 6
  end
end

#satisfies_pzs::Google::Protobuf::BoolValue (readonly)

Returns Output only. This status indicates whether the backup satisfies PZS.

The status is reserved for future use.

Returns:

  • (::Google::Protobuf::BoolValue)

    Output only. This status indicates whether the backup satisfies PZS.

    The status is reserved for future use.



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backups.rb', line 213

class Backup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The backup type.
  module SqlBackupType
    # This is an unknown backup type.
    SQL_BACKUP_TYPE_UNSPECIFIED = 0

    # The backup schedule triggers a backup automatically.
    AUTOMATED = 1

    # The user triggers a backup manually.
    ON_DEMAND = 2

    # The backup created when instance is deleted.
    FINAL = 3
  end

  # The backup's state
  module SqlBackupState
    # The state of the backup is unknown.
    SQL_BACKUP_STATE_UNSPECIFIED = 0

    # The backup that's added to a queue.
    ENQUEUED = 1

    # The backup is in progress.
    RUNNING = 2

    # The backup failed.
    FAILED = 3

    # The backup is successful.
    SUCCESSFUL = 4

    # The backup is being deleted.
    DELETING = 5

    # Deletion of the backup failed.
    DELETION_FAILED = 6
  end
end

Returns Output only. The URI of this resource.

Returns:

  • (::String)

    Output only. The URI of this resource.



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backups.rb', line 213

class Backup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The backup type.
  module SqlBackupType
    # This is an unknown backup type.
    SQL_BACKUP_TYPE_UNSPECIFIED = 0

    # The backup schedule triggers a backup automatically.
    AUTOMATED = 1

    # The user triggers a backup manually.
    ON_DEMAND = 2

    # The backup created when instance is deleted.
    FINAL = 3
  end

  # The backup's state
  module SqlBackupState
    # The state of the backup is unknown.
    SQL_BACKUP_STATE_UNSPECIFIED = 0

    # The backup that's added to a queue.
    ENQUEUED = 1

    # The backup is in progress.
    RUNNING = 2

    # The backup failed.
    FAILED = 3

    # The backup is successful.
    SUCCESSFUL = 4

    # The backup is being deleted.
    DELETING = 5

    # Deletion of the backup failed.
    DELETION_FAILED = 6
  end
end

#state::Google::Cloud::Sql::V1::Backup::SqlBackupState (readonly)

Returns Output only. The status of this backup.

Returns:



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backups.rb', line 213

class Backup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The backup type.
  module SqlBackupType
    # This is an unknown backup type.
    SQL_BACKUP_TYPE_UNSPECIFIED = 0

    # The backup schedule triggers a backup automatically.
    AUTOMATED = 1

    # The user triggers a backup manually.
    ON_DEMAND = 2

    # The backup created when instance is deleted.
    FINAL = 3
  end

  # The backup's state
  module SqlBackupState
    # The state of the backup is unknown.
    SQL_BACKUP_STATE_UNSPECIFIED = 0

    # The backup that's added to a queue.
    ENQUEUED = 1

    # The backup is in progress.
    RUNNING = 2

    # The backup failed.
    FAILED = 3

    # The backup is successful.
    SUCCESSFUL = 4

    # The backup is being deleted.
    DELETING = 5

    # Deletion of the backup failed.
    DELETION_FAILED = 6
  end
end

#time_zone::String (readonly)

Returns Output only. This output contains a backup time zone. If a Cloud SQL for SQL Server instance has a different time zone from the backup's time zone, then the restore to the instance doesn't happen.

Returns:

  • (::String)

    Output only. This output contains a backup time zone. If a Cloud SQL for SQL Server instance has a different time zone from the backup's time zone, then the restore to the instance doesn't happen.



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backups.rb', line 213

class Backup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The backup type.
  module SqlBackupType
    # This is an unknown backup type.
    SQL_BACKUP_TYPE_UNSPECIFIED = 0

    # The backup schedule triggers a backup automatically.
    AUTOMATED = 1

    # The user triggers a backup manually.
    ON_DEMAND = 2

    # The backup created when instance is deleted.
    FINAL = 3
  end

  # The backup's state
  module SqlBackupState
    # The state of the backup is unknown.
    SQL_BACKUP_STATE_UNSPECIFIED = 0

    # The backup that's added to a queue.
    ENQUEUED = 1

    # The backup is in progress.
    RUNNING = 2

    # The backup failed.
    FAILED = 3

    # The backup is successful.
    SUCCESSFUL = 4

    # The backup is being deleted.
    DELETING = 5

    # Deletion of the backup failed.
    DELETION_FAILED = 6
  end
end

#ttl_days::Integer

Returns Input only. The time-to-live (TTL) interval for this resource (in days). For example: ttlDays:7, means 7 days from the current time. The expiration time can't exceed 365 days from the time that the backup is created.

Note: The following fields are mutually exclusive: ttl_days, expiry_time. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Integer)

    Input only. The time-to-live (TTL) interval for this resource (in days). For example: ttlDays:7, means 7 days from the current time. The expiration time can't exceed 365 days from the time that the backup is created.

    Note: The following fields are mutually exclusive: ttl_days, expiry_time. If a field in that set is populated, all other fields in the set will automatically be cleared.



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backups.rb', line 213

class Backup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The backup type.
  module SqlBackupType
    # This is an unknown backup type.
    SQL_BACKUP_TYPE_UNSPECIFIED = 0

    # The backup schedule triggers a backup automatically.
    AUTOMATED = 1

    # The user triggers a backup manually.
    ON_DEMAND = 2

    # The backup created when instance is deleted.
    FINAL = 3
  end

  # The backup's state
  module SqlBackupState
    # The state of the backup is unknown.
    SQL_BACKUP_STATE_UNSPECIFIED = 0

    # The backup that's added to a queue.
    ENQUEUED = 1

    # The backup is in progress.
    RUNNING = 2

    # The backup failed.
    FAILED = 3

    # The backup is successful.
    SUCCESSFUL = 4

    # The backup is being deleted.
    DELETING = 5

    # Deletion of the backup failed.
    DELETION_FAILED = 6
  end
end

#type::Google::Cloud::Sql::V1::Backup::SqlBackupType (readonly)

Returns Output only. The type of this backup. The type can be "AUTOMATED", "ON_DEMAND" or “FINAL”.

Returns:



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backups.rb', line 213

class Backup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The backup type.
  module SqlBackupType
    # This is an unknown backup type.
    SQL_BACKUP_TYPE_UNSPECIFIED = 0

    # The backup schedule triggers a backup automatically.
    AUTOMATED = 1

    # The user triggers a backup manually.
    ON_DEMAND = 2

    # The backup created when instance is deleted.
    FINAL = 3
  end

  # The backup's state
  module SqlBackupState
    # The state of the backup is unknown.
    SQL_BACKUP_STATE_UNSPECIFIED = 0

    # The backup that's added to a queue.
    ENQUEUED = 1

    # The backup is in progress.
    RUNNING = 2

    # The backup failed.
    FAILED = 3

    # The backup is successful.
    SUCCESSFUL = 4

    # The backup is being deleted.
    DELETING = 5

    # Deletion of the backup failed.
    DELETION_FAILED = 6
  end
end