Class: Google::Cloud::Sql::V1::BackupRetentionSettings

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb

Overview

We currently only support backup retention by specifying the number of backups we will retain.

Defined Under Namespace

Modules: RetentionUnit

Instance Attribute Summary collapse

Instance Attribute Details

#retained_backups::Google::Protobuf::Int32Value

Returns Depending on the value of retention_unit, this is used to determine if a backup needs to be deleted. If retention_unit is 'COUNT', we will retain this many backups.

Returns:

  • (::Google::Protobuf::Int32Value)

    Depending on the value of retention_unit, this is used to determine if a backup needs to be deleted. If retention_unit is 'COUNT', we will retain this many backups.



90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 90

class BackupRetentionSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The units that retained_backups specifies, we only support COUNT.
  module RetentionUnit
    # Backup retention unit is unspecified, will be treated as COUNT.
    RETENTION_UNIT_UNSPECIFIED = 0

    # Retention will be by count, eg. "retain the most recent 7 backups".
    COUNT = 1
  end
end

#retention_unit::Google::Cloud::Sql::V1::BackupRetentionSettings::RetentionUnit

Returns The unit that 'retained_backups' represents.

Returns:



90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 90

class BackupRetentionSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The units that retained_backups specifies, we only support COUNT.
  module RetentionUnit
    # Backup retention unit is unspecified, will be treated as COUNT.
    RETENTION_UNIT_UNSPECIFIED = 0

    # Retention will be by count, eg. "retain the most recent 7 backups".
    COUNT = 1
  end
end