Class: Google::Cloud::Sql::V1::BackupRunsListResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::BackupRunsListResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_backup_runs.rb
Overview
Backup run list results.
Instance Attribute Summary collapse
-
#items ⇒ ::Array<::Google::Cloud::Sql::V1::BackupRun>
A list of backup runs in reverse chronological order of the enqueued time.
-
#kind ⇒ ::String
This is always
sql#backupRunsList. -
#next_page_token ⇒ ::String
The continuation token, used to page through large result sets.
Instance Attribute Details
#items ⇒ ::Array<::Google::Cloud::Sql::V1::BackupRun>
Returns A list of backup runs in reverse chronological order of the enqueued time.
178 179 180 181 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backup_runs.rb', line 178 class BackupRunsListResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#kind ⇒ ::String
Returns This is always sql#backupRunsList.
178 179 180 181 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backup_runs.rb', line 178 class BackupRunsListResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns The continuation token, used to page through large result sets. Provide this value in a subsequent request to return the next page of results.
178 179 180 181 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backup_runs.rb', line 178 class BackupRunsListResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |