Class: Google::Cloud::Sql::V1::BinLogCoordinates

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb

Overview

Binary log coordinates.

Instance Attribute Summary collapse

Instance Attribute Details

#bin_log_file_name::String

Returns Name of the binary log file for a Cloud SQL instance.

Returns:

  • (::String)

    Name of the binary log file for a Cloud SQL instance.



1117
1118
1119
1120
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1117

class BinLogCoordinates
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#bin_log_position::Integer

Returns Position (offset) within the binary log file.

Returns:

  • (::Integer)

    Position (offset) within the binary log file.



1117
1118
1119
1120
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1117

class BinLogCoordinates
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#kind::String

Returns This is always sql#binLogCoordinates.

Returns:

  • (::String)

    This is always sql#binLogCoordinates.



1117
1118
1119
1120
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1117

class BinLogCoordinates
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end