Class: Google::Cloud::Sql::V1::DatabaseInstance::SqlFailoverReplica

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb

Instance Attribute Summary collapse

Instance Attribute Details

#available::Google::Protobuf::BoolValue

Returns The availability status of the failover replica. A false status indicates that the failover replica is out of sync. The primary instance can only failover to the failover replica when the status is true.

Returns:

  • (::Google::Protobuf::BoolValue)

    The availability status of the failover replica. A false status indicates that the failover replica is out of sync. The primary instance can only failover to the failover replica when the status is true.



1355
1356
1357
1358
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1355

class SqlFailoverReplica
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns The name of the failover replica. If specified at instance creation, a failover replica is created for the instance. The name doesn't include the project ID.

Returns:

  • (::String)

    The name of the failover replica. If specified at instance creation, a failover replica is created for the instance. The name doesn't include the project ID.



1355
1356
1357
1358
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1355

class SqlFailoverReplica
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end