Class: Google::Cloud::Sql::V1::DatabaseInstance::SqlOutOfDiskReport

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb

Overview

This message wraps up the information written by out-of-disk detection job.

Defined Under Namespace

Modules: SqlOutOfDiskState

Instance Attribute Summary collapse

Instance Attribute Details

Returns The minimum recommended increase size in GigaBytes This field is consumed by the frontend

  • Writers:
    • the proactive database wellness job for OOD.
  • Readers:.

Returns:

  • (::Integer)

    The minimum recommended increase size in GigaBytes This field is consumed by the frontend

    • Writers:
      • the proactive database wellness job for OOD.
    • Readers:


1394
1395
1396
1397
1398
1399
1400
1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1394

class SqlOutOfDiskReport
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This enum lists all possible states regarding out-of-disk issues.
  module SqlOutOfDiskState
    # Unspecified state
    SQL_OUT_OF_DISK_STATE_UNSPECIFIED = 0

    # The instance has plenty space on data disk
    NORMAL = 1

    # Data disk is almost used up. It is shutdown to prevent data
    # corruption.
    SOFT_SHUTDOWN = 2
  end
end

#sql_out_of_disk_state::Google::Cloud::Sql::V1::DatabaseInstance::SqlOutOfDiskReport::SqlOutOfDiskState

Returns This field represents the state generated by the proactive database wellness job for OutOfDisk issues.

  • Writers:
    • the proactive database wellness job for OOD.
  • Readers:
    • the proactive database wellness job.

Returns:



1394
1395
1396
1397
1398
1399
1400
1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1394

class SqlOutOfDiskReport
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This enum lists all possible states regarding out-of-disk issues.
  module SqlOutOfDiskState
    # Unspecified state
    SQL_OUT_OF_DISK_STATE_UNSPECIFIED = 0

    # The instance has plenty space on data disk
    NORMAL = 1

    # Data disk is almost used up. It is shutdown to prevent data
    # corruption.
    SOFT_SHUTDOWN = 2
  end
end