Class: Google::Cloud::Sql::V1::DatabaseInstance::SqlScheduledMaintenance
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::DatabaseInstance::SqlScheduledMaintenance
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb
Overview
Any scheduled maintenance for this instance.
Instance Attribute Summary collapse
-
#can_defer ⇒ ::Boolean
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#can_reschedule ⇒ ::Boolean
If the scheduled maintenance can be rescheduled.
-
#schedule_deadline_time ⇒ ::Google::Protobuf::Timestamp
Maintenance cannot be rescheduled to start beyond this deadline.
-
#start_time ⇒ ::Google::Protobuf::Timestamp
The start time of any upcoming scheduled maintenance for this instance.
Instance Attribute Details
#can_defer ⇒ ::Boolean
Deprecated.
This field is deprecated and may be removed in the next major version update.
1373 1374 1375 1376 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1373 class SqlScheduledMaintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#can_reschedule ⇒ ::Boolean
Returns If the scheduled maintenance can be rescheduled.
1373 1374 1375 1376 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1373 class SqlScheduledMaintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#schedule_deadline_time ⇒ ::Google::Protobuf::Timestamp
Returns Maintenance cannot be rescheduled to start beyond this deadline.
1373 1374 1375 1376 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1373 class SqlScheduledMaintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#start_time ⇒ ::Google::Protobuf::Timestamp
Returns The start time of any upcoming scheduled maintenance for this instance.
1373 1374 1375 1376 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1373 class SqlScheduledMaintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |