Class: Google::Cloud::Sql::V1::DemoteMasterConfiguration

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb

Overview

Read-replica configuration for connecting to the on-premises primary instance.

Instance Attribute Summary collapse

Instance Attribute Details

#kind::String

Returns This is always sql#demoteMasterConfiguration.

Returns:

  • (::String)

    This is always sql#demoteMasterConfiguration.



378
379
380
381
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 378

class DemoteMasterConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#mysql_replica_configuration::Google::Cloud::Sql::V1::DemoteMasterMySqlReplicaConfiguration

Returns MySQL specific configuration when replicating from a MySQL on-premises primary instance. Replication configuration information such as the username, password, certificates, and keys are not stored in the instance metadata. The configuration information is used only to set up the replication connection and is stored by MySQL in a file named master.info in the data directory.

Returns:

  • (::Google::Cloud::Sql::V1::DemoteMasterMySqlReplicaConfiguration)

    MySQL specific configuration when replicating from a MySQL on-premises primary instance. Replication configuration information such as the username, password, certificates, and keys are not stored in the instance metadata. The configuration information is used only to set up the replication connection and is stored by MySQL in a file named master.info in the data directory.



378
379
380
381
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 378

class DemoteMasterConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end