Class: Google::Cloud::Sql::V1::DemoteMasterContext

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb

Overview

Database instance demote primary instance context.

Instance Attribute Summary collapse

Instance Attribute Details

#kind::String

Returns This is always sql#demoteMasterContext.

Returns:

  • (::String)

    This is always sql#demoteMasterContext.



1632
1633
1634
1635
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1632

class DemoteMasterContext
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#master_instance_name::String

Returns The name of the instance which will act as on-premises primary instance in the replication setup.

Returns:

  • (::String)

    The name of the instance which will act as on-premises primary instance in the replication setup.



1632
1633
1634
1635
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1632

class DemoteMasterContext
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#replica_configuration::Google::Cloud::Sql::V1::DemoteMasterConfiguration

Returns Configuration specific to read-replicas replicating from the on-premises primary instance.

Returns:



1632
1633
1634
1635
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1632

class DemoteMasterContext
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#skip_replication_setup::Boolean

Returns Flag to skip replication setup on the instance.

Returns:

  • (::Boolean)

    Flag to skip replication setup on the instance.



1632
1633
1634
1635
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1632

class DemoteMasterContext
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#verify_gtid_consistency::Google::Protobuf::BoolValue

Returns Verify the GTID consistency for demote operation. Default value: True. Setting this flag to false enables you to bypass the GTID consistency check between on-premises primary instance and Cloud SQL instance during the demotion operation but also exposes you to the risk of future replication failures. Change the value only if you know the reason for the GTID divergence and are confident that doing so will not cause any replication issues.

Returns:

  • (::Google::Protobuf::BoolValue)

    Verify the GTID consistency for demote operation. Default value: True. Setting this flag to false enables you to bypass the GTID consistency check between on-premises primary instance and Cloud SQL instance during the demotion operation but also exposes you to the risk of future replication failures. Change the value only if you know the reason for the GTID divergence and are confident that doing so will not cause any replication issues.



1632
1633
1634
1635
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1632

class DemoteMasterContext
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end