Class: Google::Cloud::Sql::V1::DemoteMasterMySqlReplicaConfiguration

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb

Overview

Read-replica configuration specific to MySQL databases.

Instance Attribute Summary collapse

Instance Attribute Details

#ca_certificate::String

Returns PEM representation of the trusted CA's x509 certificate.

Returns:

  • (::String)

    PEM representation of the trusted CA's x509 certificate.



404
405
406
407
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 404

class DemoteMasterMySqlReplicaConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#client_certificate::String

Returns PEM representation of the replica's x509 certificate.

Returns:

  • (::String)

    PEM representation of the replica's x509 certificate.



404
405
406
407
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 404

class DemoteMasterMySqlReplicaConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#client_key::String

Returns PEM representation of the replica's private key. The corresponding public key is encoded in the client's certificate. The format of the replica's private key can be either PKCS #1 or PKCS #8.

Returns:

  • (::String)

    PEM representation of the replica's private key. The corresponding public key is encoded in the client's certificate. The format of the replica's private key can be either PKCS #1 or PKCS #8.



404
405
406
407
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 404

class DemoteMasterMySqlReplicaConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#kind::String

Returns This is always sql#demoteMasterMysqlReplicaConfiguration.

Returns:

  • (::String)

    This is always sql#demoteMasterMysqlReplicaConfiguration.



404
405
406
407
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 404

class DemoteMasterMySqlReplicaConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#password::String

Returns The password for the replication connection.

Returns:

  • (::String)

    The password for the replication connection.



404
405
406
407
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 404

class DemoteMasterMySqlReplicaConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#username::String

Returns The username for the replication connection.

Returns:

  • (::String)

    The username for the replication connection.



404
405
406
407
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 404

class DemoteMasterMySqlReplicaConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end