Class: Google::Cloud::Sql::V1::DenyMaintenancePeriod

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb

Overview

Deny maintenance Periods. This specifies a date range during when all CSA rollout will be denied.

Instance Attribute Summary collapse

Instance Attribute Details

#end_date::String

Returns "deny maintenance period" end date. If the year of the end date is empty, the year of the start date also must be empty. In this case, it means the no maintenance interval recurs every year. The date is in format yyyy-mm-dd i.e., 2020-11-01, or mm-dd, i.e., 11-01.

Returns:

  • (::String)

    "deny maintenance period" end date. If the year of the end date is empty, the year of the start date also must be empty. In this case, it means the no maintenance interval recurs every year. The date is in format yyyy-mm-dd i.e., 2020-11-01, or mm-dd, i.e., 11-01



1082
1083
1084
1085
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1082

class DenyMaintenancePeriod
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#start_date::String

Returns "deny maintenance period" start date. If the year of the start date is empty, the year of the end date also must be empty. In this case, it means the deny maintenance period recurs every year. The date is in format yyyy-mm-dd i.e., 2020-11-01, or mm-dd, i.e., 11-01.

Returns:

  • (::String)

    "deny maintenance period" start date. If the year of the start date is empty, the year of the end date also must be empty. In this case, it means the deny maintenance period recurs every year. The date is in format yyyy-mm-dd i.e., 2020-11-01, or mm-dd, i.e., 11-01



1082
1083
1084
1085
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1082

class DenyMaintenancePeriod
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#time::String

Returns Time in UTC when the "deny maintenance period" starts on start_date and ends on end_date. The time is in format: HH:mm:SS, i.e., 00:00:00.

Returns:

  • (::String)

    Time in UTC when the "deny maintenance period" starts on start_date and ends on end_date. The time is in format: HH:mm:SS, i.e., 00:00:00



1082
1083
1084
1085
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1082

class DenyMaintenancePeriod
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end