Class: Google::Cloud::Sql::V1::ExecuteSqlPayload

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb

Overview

The request payload used to execute SQL statements.

Defined Under Namespace

Modules: PartialResultMode

Instance Attribute Summary collapse

Instance Attribute Details

#application::String

Returns Optional. Specifies the name of the application that is making the request. This field is used for telemetry. Only alphanumeric characters, dashes, and underscores are allowed. The maximum length is 32 characters.

Returns:

  • (::String)

    Optional. Specifies the name of the application that is making the request. This field is used for telemetry. Only alphanumeric characters, dashes, and underscores are allowed. The maximum length is 32 characters.



2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 2104

class ExecuteSqlPayload
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Controls how the API should respond when the SQL execution result exceeds
  # 10 MB.
  module PartialResultMode
    # Unspecified mode, effectively the same as `FAIL_PARTIAL_RESULT`.
    PARTIAL_RESULT_MODE_UNSPECIFIED = 0

    # Throw an error if the result exceeds 10 MB or if only a partial result
    # can be retrieved. Don't return the result.
    FAIL_PARTIAL_RESULT = 1

    # Return a truncated result and set `partial_result` to true if the result
    # exceeds 10 MB or if only a partial result can be retrieved due to error.
    # Don't throw an error.
    ALLOW_PARTIAL_RESULT = 2
  end
end

#auto_iam_authn::Boolean

Returns Optional. When set to true, the API caller identity associated with the request is used for database authentication. The API caller must be an IAM user in the database.

Returns:

  • (::Boolean)

    Optional. When set to true, the API caller identity associated with the request is used for database authentication. The API caller must be an IAM user in the database.



2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 2104

class ExecuteSqlPayload
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Controls how the API should respond when the SQL execution result exceeds
  # 10 MB.
  module PartialResultMode
    # Unspecified mode, effectively the same as `FAIL_PARTIAL_RESULT`.
    PARTIAL_RESULT_MODE_UNSPECIFIED = 0

    # Throw an error if the result exceeds 10 MB or if only a partial result
    # can be retrieved. Don't return the result.
    FAIL_PARTIAL_RESULT = 1

    # Return a truncated result and set `partial_result` to true if the result
    # exceeds 10 MB or if only a partial result can be retrieved due to error.
    # Don't throw an error.
    ALLOW_PARTIAL_RESULT = 2
  end
end

#database::String

Returns Optional. Name of the database on which the statement will be executed.

Returns:

  • (::String)

    Optional. Name of the database on which the statement will be executed.



2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 2104

class ExecuteSqlPayload
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Controls how the API should respond when the SQL execution result exceeds
  # 10 MB.
  module PartialResultMode
    # Unspecified mode, effectively the same as `FAIL_PARTIAL_RESULT`.
    PARTIAL_RESULT_MODE_UNSPECIFIED = 0

    # Throw an error if the result exceeds 10 MB or if only a partial result
    # can be retrieved. Don't return the result.
    FAIL_PARTIAL_RESULT = 1

    # Return a truncated result and set `partial_result` to true if the result
    # exceeds 10 MB or if only a partial result can be retrieved due to error.
    # Don't throw an error.
    ALLOW_PARTIAL_RESULT = 2
  end
end

#partial_result_mode::Google::Cloud::Sql::V1::ExecuteSqlPayload::PartialResultMode

Returns Optional. Controls how the API should respond when the SQL execution result is incomplete due to the size limit or another error. The default mode is to throw an error.

Returns:



2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 2104

class ExecuteSqlPayload
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Controls how the API should respond when the SQL execution result exceeds
  # 10 MB.
  module PartialResultMode
    # Unspecified mode, effectively the same as `FAIL_PARTIAL_RESULT`.
    PARTIAL_RESULT_MODE_UNSPECIFIED = 0

    # Throw an error if the result exceeds 10 MB or if only a partial result
    # can be retrieved. Don't return the result.
    FAIL_PARTIAL_RESULT = 1

    # Return a truncated result and set `partial_result` to true if the result
    # exceeds 10 MB or if only a partial result can be retrieved due to error.
    # Don't throw an error.
    ALLOW_PARTIAL_RESULT = 2
  end
end

#row_limit::Integer

Returns Optional. The maximum number of rows returned per SQL statement.

Returns:

  • (::Integer)

    Optional. The maximum number of rows returned per SQL statement.



2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 2104

class ExecuteSqlPayload
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Controls how the API should respond when the SQL execution result exceeds
  # 10 MB.
  module PartialResultMode
    # Unspecified mode, effectively the same as `FAIL_PARTIAL_RESULT`.
    PARTIAL_RESULT_MODE_UNSPECIFIED = 0

    # Throw an error if the result exceeds 10 MB or if only a partial result
    # can be retrieved. Don't return the result.
    FAIL_PARTIAL_RESULT = 1

    # Return a truncated result and set `partial_result` to true if the result
    # exceeds 10 MB or if only a partial result can be retrieved due to error.
    # Don't throw an error.
    ALLOW_PARTIAL_RESULT = 2
  end
end

#sql_statement::String

Returns Required. SQL statements to run on the database. It can be a single statement or a sequence of statements separated by semicolons.

Returns:

  • (::String)

    Required. SQL statements to run on the database. It can be a single statement or a sequence of statements separated by semicolons.



2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 2104

class ExecuteSqlPayload
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Controls how the API should respond when the SQL execution result exceeds
  # 10 MB.
  module PartialResultMode
    # Unspecified mode, effectively the same as `FAIL_PARTIAL_RESULT`.
    PARTIAL_RESULT_MODE_UNSPECIFIED = 0

    # Throw an error if the result exceeds 10 MB or if only a partial result
    # can be retrieved. Don't return the result.
    FAIL_PARTIAL_RESULT = 1

    # Return a truncated result and set `partial_result` to true if the result
    # exceeds 10 MB or if only a partial result can be retrieved due to error.
    # Don't throw an error.
    ALLOW_PARTIAL_RESULT = 2
  end
end

#user::String

Returns Optional. The name of an existing database user to connect to the database. When auto_iam_authn is set to true, this field is ignored and the API caller's IAM user is used.

Returns:

  • (::String)

    Optional. The name of an existing database user to connect to the database. When auto_iam_authn is set to true, this field is ignored and the API caller's IAM user is used.



2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 2104

class ExecuteSqlPayload
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Controls how the API should respond when the SQL execution result exceeds
  # 10 MB.
  module PartialResultMode
    # Unspecified mode, effectively the same as `FAIL_PARTIAL_RESULT`.
    PARTIAL_RESULT_MODE_UNSPECIFIED = 0

    # Throw an error if the result exceeds 10 MB or if only a partial result
    # can be retrieved. Don't return the result.
    FAIL_PARTIAL_RESULT = 1

    # Return a truncated result and set `partial_result` to true if the result
    # exceeds 10 MB or if only a partial result can be retrieved due to error.
    # Don't throw an error.
    ALLOW_PARTIAL_RESULT = 2
  end
end