Module: Google::Cloud::Sql::V1::ExecuteSqlPayload::PartialResultMode

Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb

Overview

Controls how the API should respond when the SQL execution result exceeds 10 MB.

Constant Summary collapse

PARTIAL_RESULT_MODE_UNSPECIFIED =

Unspecified mode, effectively the same as FAIL_PARTIAL_RESULT.

0
FAIL_PARTIAL_RESULT =

Throw an error if the result exceeds 10 MB or if only a partial result can be retrieved. Don't return the result.

1
ALLOW_PARTIAL_RESULT =

Return a truncated result and set partial_result to true if the result exceeds 10 MB or if only a partial result can be retrieved due to error. Don't throw an error.

2