Class: Google::Cloud::Sql::V1::ExportContext::SqlBakExportOptions

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb

Overview

Options for exporting BAK files (SQL Server-only)

Instance Attribute Summary collapse

Instance Attribute Details

#bak_type::Google::Cloud::Sql::V1::BakType

Returns Type of this bak file will be export, FULL or DIFF, SQL Server only.

Returns:



570
571
572
573
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 570

class SqlBakExportOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#copy_only::Google::Protobuf::BoolValue

Deprecated.

This field is deprecated and may be removed in the next major version update.

Returns Deprecated: copy_only is deprecated. Use differential_base instead.

Returns:



570
571
572
573
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 570

class SqlBakExportOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#differential_base::Google::Protobuf::BoolValue

Returns Whether or not the backup can be used as a differential base copy_only backup can not be served as differential base.

Returns:

  • (::Google::Protobuf::BoolValue)

    Whether or not the backup can be used as a differential base copy_only backup can not be served as differential base



570
571
572
573
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 570

class SqlBakExportOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#export_log_end_time::Google::Protobuf::Timestamp

Returns Optional. The end timestamp when transaction log will be included in the export operation. RFC 3339 format (for example, 2023-10-01T16:19:00.094) in UTC. When omitted, all available logs until current time will be included. Only applied to Cloud SQL for SQL Server.

Returns:

  • (::Google::Protobuf::Timestamp)

    Optional. The end timestamp when transaction log will be included in the export operation. RFC 3339 format (for example, 2023-10-01T16:19:00.094) in UTC. When omitted, all available logs until current time will be included. Only applied to Cloud SQL for SQL Server.



570
571
572
573
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 570

class SqlBakExportOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#export_log_start_time::Google::Protobuf::Timestamp

Returns Optional. The begin timestamp when transaction log will be included in the export operation. RFC 3339 format (for example, 2023-10-01T16:19:00.094) in UTC. When omitted, all available logs from the beginning of retention period will be included. Only applied to Cloud SQL for SQL Server.

Returns:

  • (::Google::Protobuf::Timestamp)

    Optional. The begin timestamp when transaction log will be included in the export operation. RFC 3339 format (for example, 2023-10-01T16:19:00.094) in UTC. When omitted, all available logs from the beginning of retention period will be included. Only applied to Cloud SQL for SQL Server.



570
571
572
573
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 570

class SqlBakExportOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#stripe_count::Google::Protobuf::Int32Value

Returns Option for specifying how many stripes to use for the export. If blank, and the value of the striped field is true, the number of stripes is automatically chosen.

Returns:

  • (::Google::Protobuf::Int32Value)

    Option for specifying how many stripes to use for the export. If blank, and the value of the striped field is true, the number of stripes is automatically chosen.



570
571
572
573
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 570

class SqlBakExportOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#striped::Google::Protobuf::BoolValue

Returns Whether or not the export should be striped.

Returns:



570
571
572
573
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 570

class SqlBakExportOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end