Class: Google::Cloud::Sql::V1::ExportContext::SqlCsvExportOptions

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb

Instance Attribute Summary collapse

Instance Attribute Details

#escape_character::String

Returns Specifies the character that should appear before a data character that needs to be escaped.

Returns:

  • (::String)

    Specifies the character that should appear before a data character that needs to be escaped.



478
479
480
481
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 478

class SqlCsvExportOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#fields_terminated_by::String

Returns Specifies the character that separates columns within each row (line) of the file.

Returns:

  • (::String)

    Specifies the character that separates columns within each row (line) of the file.



478
479
480
481
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 478

class SqlCsvExportOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#lines_terminated_by::String

Returns This is used to separate lines. If a line does not contain all fields, the rest of the columns are set to their default values.

Returns:

  • (::String)

    This is used to separate lines. If a line does not contain all fields, the rest of the columns are set to their default values.



478
479
480
481
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 478

class SqlCsvExportOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#quote_character::String

Returns Specifies the quoting character to be used when a data value is quoted.

Returns:

  • (::String)

    Specifies the quoting character to be used when a data value is quoted.



478
479
480
481
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 478

class SqlCsvExportOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#select_query::String

Returns The select query used to extract the data.

Returns:

  • (::String)

    The select query used to extract the data.



478
479
480
481
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 478

class SqlCsvExportOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end