Class: Google::Cloud::Sql::V1::ExportContext::SqlExportOptions::MysqlExportOptions

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb

Overview

Options for exporting from MySQL.

Instance Attribute Summary collapse

Instance Attribute Details

#master_data::Google::Protobuf::Int32Value

Returns Option to include SQL statement required to set up replication. If set to 1, the dump file includes a CHANGE MASTER TO statement with the binary log coordinates, and --set-gtid-purged is set to ON. If set to 2, the CHANGE MASTER TO statement is written as a SQL comment and has no effect. If set to any value other than 1, --set-gtid-purged is set to OFF.

Returns:

  • (::Google::Protobuf::Int32Value)

    Option to include SQL statement required to set up replication. If set to 1, the dump file includes a CHANGE MASTER TO statement with the binary log coordinates, and --set-gtid-purged is set to ON. If set to 2, the CHANGE MASTER TO statement is written as a SQL comment and has no effect. If set to any value other than 1, --set-gtid-purged is set to OFF.



515
516
517
518
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 515

class MysqlExportOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end