Class: Google::Cloud::Sql::V1::ExportContext::SqlExportOptions::PostgresExportOptions

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb

Overview

Options for exporting from a Cloud SQL for PostgreSQL instance.

Instance Attribute Summary collapse

Instance Attribute Details

#clean::Google::Protobuf::BoolValue

Returns Optional. Use this option to include DROP <object> SQL statements. Use these statements to delete database objects before running the import operation.

Returns:

  • (::Google::Protobuf::BoolValue)

    Optional. Use this option to include DROP <object> SQL statements. Use these statements to delete database objects before running the import operation.



530
531
532
533
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 530

class PostgresExportOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#if_exists::Google::Protobuf::BoolValue

Returns Optional. Option to include an IF EXISTS SQL statement with each DROP statement produced by clean.

Returns:



530
531
532
533
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 530

class PostgresExportOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end