Class: Google::Cloud::Sql::V1::FinalBackupConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb

Overview

Config used to determine the final backup settings for the instance.

Instance Attribute Summary collapse

Instance Attribute Details

#enabled::Boolean

Returns Whether the final backup is enabled for the instance.

Returns:

  • (::Boolean)

    Whether the final backup is enabled for the instance.



1591
1592
1593
1594
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1591

class FinalBackupConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#retention_days::Integer

Returns The number of days to retain the final backup after the instance deletion. The final backup will be purged at (time_of_instance_deletion + retention_days).

Returns:

  • (::Integer)

    The number of days to retain the final backup after the instance deletion. The final backup will be purged at (time_of_instance_deletion + retention_days).



1591
1592
1593
1594
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1591

class FinalBackupConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end