Class: Google::Cloud::Sql::V1::ImportContext
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::ImportContext
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb
Overview
Database instance import context.
Defined Under Namespace
Classes: SqlBakImportOptions, SqlCsvImportOptions, SqlImportOptions, SqlTdeImportOptions
Instance Attribute Summary collapse
-
#bak_import_options ⇒ ::Google::Cloud::Sql::V1::ImportContext::SqlBakImportOptions
Import parameters specific to SQL Server .BAK files.
-
#csv_import_options ⇒ ::Google::Cloud::Sql::V1::ImportContext::SqlCsvImportOptions
Options for importing data as CSV.
-
#database ⇒ ::String
The target database for the import.
-
#file_type ⇒ ::Google::Cloud::Sql::V1::SqlFileType
The file type for the specified uri.`SQL`: The file contains SQL statements.
-
#import_user ⇒ ::String
The PostgreSQL user for this import operation.
-
#kind ⇒ ::String
This is always
sql#importContext. -
#sql_import_options ⇒ ::Google::Cloud::Sql::V1::ImportContext::SqlImportOptions
Optional.
-
#tde_import_options ⇒ ::Google::Cloud::Sql::V1::ImportContext::SqlTdeImportOptions
Optional.
-
#uri ⇒ ::String
Path to the import file in Cloud Storage, in the form
gs://bucketName/fileName.
Instance Attribute Details
#bak_import_options ⇒ ::Google::Cloud::Sql::V1::ImportContext::SqlBakImportOptions
Returns Import parameters specific to SQL Server .BAK files.
637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 637 class ImportContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] threads # @return [::Google::Protobuf::Int32Value] # Optional. The number of threads to use for parallel import. # @!attribute [rw] parallel # @return [::Google::Protobuf::BoolValue] # Optional. Whether or not the import should be parallel. # @!attribute [rw] postgres_import_options # @return [::Google::Cloud::Sql::V1::ImportContext::SqlImportOptions::PostgresImportOptions] # Optional. Options for importing from a Cloud SQL for PostgreSQL instance. class SqlImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] clean # @return [::Google::Protobuf::BoolValue] # Optional. The --clean flag for the pg_restore utility. This flag # applies only if you enabled Cloud SQL to import files in parallel. # @!attribute [rw] if_exists # @return [::Google::Protobuf::BoolValue] # Optional. The --if-exists flag for the pg_restore utility. This flag # applies only if you enabled Cloud SQL to import files in parallel. class PostgresImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # @!attribute [rw] table # @return [::String] # The table to which CSV data is imported. # @!attribute [rw] columns # @return [::Array<::String>] # The columns to which CSV data is imported. If not specified, all columns # of the database table are loaded with CSV data. # @!attribute [rw] escape_character # @return [::String] # Specifies the character that should appear before a data character that # needs to be escaped. # @!attribute [rw] quote_character # @return [::String] # Specifies the quoting character to be used when a data value is quoted. # @!attribute [rw] fields_terminated_by # @return [::String] # Specifies the character that separates columns within each row (line) of # the file. # @!attribute [rw] lines_terminated_by # @return [::String] # This is used to separate lines. If a line does not contain all fields, # the rest of the columns are set to their default values. class SqlCsvImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] encryption_options # @return [::Google::Cloud::Sql::V1::ImportContext::SqlBakImportOptions::EncryptionOptions] # @!attribute [rw] striped # @return [::Google::Protobuf::BoolValue] # Whether or not the backup set being restored is striped. # Applies only to Cloud SQL for SQL Server. # @!attribute [rw] no_recovery # @return [::Google::Protobuf::BoolValue] # Whether or not the backup importing will restore database # with NORECOVERY option. # Applies only to Cloud SQL for SQL Server. # @!attribute [rw] recovery_only # @return [::Google::Protobuf::BoolValue] # Whether or not the backup importing request will just bring database # online without downloading Bak content only one of "no_recovery" and # "recovery_only" can be true otherwise error will return. Applies only to # Cloud SQL for SQL Server. # @!attribute [rw] bak_type # @return [::Google::Cloud::Sql::V1::BakType] # Type of the bak content, FULL or DIFF # @!attribute [rw] stop_at # @return [::Google::Protobuf::Timestamp] # Optional. The timestamp when the import should stop. This timestamp is in # the [RFC 3339](https://tools.ietf.org/html/rfc3339) format (for example, # `2023-10-01T16:19:00.094`). This field is equivalent to the STOPAT # keyword and applies to Cloud SQL for SQL Server only. # @!attribute [rw] stop_at_mark # @return [::String] # Optional. The marked transaction where the import should stop. This field # is equivalent to the STOPATMARK keyword and applies to Cloud SQL for SQL # Server only. class SqlBakImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] cert_path # @return [::String] # Path to the Certificate (.cer) in Cloud Storage, in the form # `gs://bucketName/fileName`. The instance must have # write permissions to the bucket and read access to the file. # @!attribute [rw] pvk_path # @return [::String] # Path to the Certificate Private Key (.pvk) in Cloud Storage, in the # form `gs://bucketName/fileName`. The instance must have # write permissions to the bucket and read access to the file. # @!attribute [rw] pvk_password # @return [::String] # Password that encrypts the private key # @!attribute [rw] keep_encrypted # @return [::Google::Protobuf::BoolValue] # Optional. Whether the imported file remains encrypted. class EncryptionOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # @!attribute [rw] certificate_path # @return [::String] # Required. Path to the TDE certificate public key # in the form gs://bucketName/fileName. # The instance must have read access to the file. # Applicable only for SQL Server instances. # @!attribute [rw] private_key_path # @return [::String] # Required. Path to the TDE certificate private key # in the form gs://bucketName/fileName. # The instance must have read access to the file. # Applicable only for SQL Server instances. # @!attribute [rw] private_key_password # @return [::String] # Required. Password that encrypts the private key. # @!attribute [rw] name # @return [::String] # Required. Certificate name. # Applicable only for SQL Server instances. class SqlTdeImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#csv_import_options ⇒ ::Google::Cloud::Sql::V1::ImportContext::SqlCsvImportOptions
Returns Options for importing data as CSV.
637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 637 class ImportContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] threads # @return [::Google::Protobuf::Int32Value] # Optional. The number of threads to use for parallel import. # @!attribute [rw] parallel # @return [::Google::Protobuf::BoolValue] # Optional. Whether or not the import should be parallel. # @!attribute [rw] postgres_import_options # @return [::Google::Cloud::Sql::V1::ImportContext::SqlImportOptions::PostgresImportOptions] # Optional. Options for importing from a Cloud SQL for PostgreSQL instance. class SqlImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] clean # @return [::Google::Protobuf::BoolValue] # Optional. The --clean flag for the pg_restore utility. This flag # applies only if you enabled Cloud SQL to import files in parallel. # @!attribute [rw] if_exists # @return [::Google::Protobuf::BoolValue] # Optional. The --if-exists flag for the pg_restore utility. This flag # applies only if you enabled Cloud SQL to import files in parallel. class PostgresImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # @!attribute [rw] table # @return [::String] # The table to which CSV data is imported. # @!attribute [rw] columns # @return [::Array<::String>] # The columns to which CSV data is imported. If not specified, all columns # of the database table are loaded with CSV data. # @!attribute [rw] escape_character # @return [::String] # Specifies the character that should appear before a data character that # needs to be escaped. # @!attribute [rw] quote_character # @return [::String] # Specifies the quoting character to be used when a data value is quoted. # @!attribute [rw] fields_terminated_by # @return [::String] # Specifies the character that separates columns within each row (line) of # the file. # @!attribute [rw] lines_terminated_by # @return [::String] # This is used to separate lines. If a line does not contain all fields, # the rest of the columns are set to their default values. class SqlCsvImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] encryption_options # @return [::Google::Cloud::Sql::V1::ImportContext::SqlBakImportOptions::EncryptionOptions] # @!attribute [rw] striped # @return [::Google::Protobuf::BoolValue] # Whether or not the backup set being restored is striped. # Applies only to Cloud SQL for SQL Server. # @!attribute [rw] no_recovery # @return [::Google::Protobuf::BoolValue] # Whether or not the backup importing will restore database # with NORECOVERY option. # Applies only to Cloud SQL for SQL Server. # @!attribute [rw] recovery_only # @return [::Google::Protobuf::BoolValue] # Whether or not the backup importing request will just bring database # online without downloading Bak content only one of "no_recovery" and # "recovery_only" can be true otherwise error will return. Applies only to # Cloud SQL for SQL Server. # @!attribute [rw] bak_type # @return [::Google::Cloud::Sql::V1::BakType] # Type of the bak content, FULL or DIFF # @!attribute [rw] stop_at # @return [::Google::Protobuf::Timestamp] # Optional. The timestamp when the import should stop. This timestamp is in # the [RFC 3339](https://tools.ietf.org/html/rfc3339) format (for example, # `2023-10-01T16:19:00.094`). This field is equivalent to the STOPAT # keyword and applies to Cloud SQL for SQL Server only. # @!attribute [rw] stop_at_mark # @return [::String] # Optional. The marked transaction where the import should stop. This field # is equivalent to the STOPATMARK keyword and applies to Cloud SQL for SQL # Server only. class SqlBakImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] cert_path # @return [::String] # Path to the Certificate (.cer) in Cloud Storage, in the form # `gs://bucketName/fileName`. The instance must have # write permissions to the bucket and read access to the file. # @!attribute [rw] pvk_path # @return [::String] # Path to the Certificate Private Key (.pvk) in Cloud Storage, in the # form `gs://bucketName/fileName`. The instance must have # write permissions to the bucket and read access to the file. # @!attribute [rw] pvk_password # @return [::String] # Password that encrypts the private key # @!attribute [rw] keep_encrypted # @return [::Google::Protobuf::BoolValue] # Optional. Whether the imported file remains encrypted. class EncryptionOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # @!attribute [rw] certificate_path # @return [::String] # Required. Path to the TDE certificate public key # in the form gs://bucketName/fileName. # The instance must have read access to the file. # Applicable only for SQL Server instances. # @!attribute [rw] private_key_path # @return [::String] # Required. Path to the TDE certificate private key # in the form gs://bucketName/fileName. # The instance must have read access to the file. # Applicable only for SQL Server instances. # @!attribute [rw] private_key_password # @return [::String] # Required. Password that encrypts the private key. # @!attribute [rw] name # @return [::String] # Required. Certificate name. # Applicable only for SQL Server instances. class SqlTdeImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#database ⇒ ::String
Returns The target database for the import. If fileType is SQL, this field
is required only if the import file does not specify a database, and is
overridden by any database specification in the import file. For entire
instance parallel import operations, the database is overridden by the
database name stored in subdirectory name. If
fileType is CSV, one database must be specified.
637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 637 class ImportContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] threads # @return [::Google::Protobuf::Int32Value] # Optional. The number of threads to use for parallel import. # @!attribute [rw] parallel # @return [::Google::Protobuf::BoolValue] # Optional. Whether or not the import should be parallel. # @!attribute [rw] postgres_import_options # @return [::Google::Cloud::Sql::V1::ImportContext::SqlImportOptions::PostgresImportOptions] # Optional. Options for importing from a Cloud SQL for PostgreSQL instance. class SqlImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] clean # @return [::Google::Protobuf::BoolValue] # Optional. The --clean flag for the pg_restore utility. This flag # applies only if you enabled Cloud SQL to import files in parallel. # @!attribute [rw] if_exists # @return [::Google::Protobuf::BoolValue] # Optional. The --if-exists flag for the pg_restore utility. This flag # applies only if you enabled Cloud SQL to import files in parallel. class PostgresImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # @!attribute [rw] table # @return [::String] # The table to which CSV data is imported. # @!attribute [rw] columns # @return [::Array<::String>] # The columns to which CSV data is imported. If not specified, all columns # of the database table are loaded with CSV data. # @!attribute [rw] escape_character # @return [::String] # Specifies the character that should appear before a data character that # needs to be escaped. # @!attribute [rw] quote_character # @return [::String] # Specifies the quoting character to be used when a data value is quoted. # @!attribute [rw] fields_terminated_by # @return [::String] # Specifies the character that separates columns within each row (line) of # the file. # @!attribute [rw] lines_terminated_by # @return [::String] # This is used to separate lines. If a line does not contain all fields, # the rest of the columns are set to their default values. class SqlCsvImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] encryption_options # @return [::Google::Cloud::Sql::V1::ImportContext::SqlBakImportOptions::EncryptionOptions] # @!attribute [rw] striped # @return [::Google::Protobuf::BoolValue] # Whether or not the backup set being restored is striped. # Applies only to Cloud SQL for SQL Server. # @!attribute [rw] no_recovery # @return [::Google::Protobuf::BoolValue] # Whether or not the backup importing will restore database # with NORECOVERY option. # Applies only to Cloud SQL for SQL Server. # @!attribute [rw] recovery_only # @return [::Google::Protobuf::BoolValue] # Whether or not the backup importing request will just bring database # online without downloading Bak content only one of "no_recovery" and # "recovery_only" can be true otherwise error will return. Applies only to # Cloud SQL for SQL Server. # @!attribute [rw] bak_type # @return [::Google::Cloud::Sql::V1::BakType] # Type of the bak content, FULL or DIFF # @!attribute [rw] stop_at # @return [::Google::Protobuf::Timestamp] # Optional. The timestamp when the import should stop. This timestamp is in # the [RFC 3339](https://tools.ietf.org/html/rfc3339) format (for example, # `2023-10-01T16:19:00.094`). This field is equivalent to the STOPAT # keyword and applies to Cloud SQL for SQL Server only. # @!attribute [rw] stop_at_mark # @return [::String] # Optional. The marked transaction where the import should stop. This field # is equivalent to the STOPATMARK keyword and applies to Cloud SQL for SQL # Server only. class SqlBakImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] cert_path # @return [::String] # Path to the Certificate (.cer) in Cloud Storage, in the form # `gs://bucketName/fileName`. The instance must have # write permissions to the bucket and read access to the file. # @!attribute [rw] pvk_path # @return [::String] # Path to the Certificate Private Key (.pvk) in Cloud Storage, in the # form `gs://bucketName/fileName`. The instance must have # write permissions to the bucket and read access to the file. # @!attribute [rw] pvk_password # @return [::String] # Password that encrypts the private key # @!attribute [rw] keep_encrypted # @return [::Google::Protobuf::BoolValue] # Optional. Whether the imported file remains encrypted. class EncryptionOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # @!attribute [rw] certificate_path # @return [::String] # Required. Path to the TDE certificate public key # in the form gs://bucketName/fileName. # The instance must have read access to the file. # Applicable only for SQL Server instances. # @!attribute [rw] private_key_path # @return [::String] # Required. Path to the TDE certificate private key # in the form gs://bucketName/fileName. # The instance must have read access to the file. # Applicable only for SQL Server instances. # @!attribute [rw] private_key_password # @return [::String] # Required. Password that encrypts the private key. # @!attribute [rw] name # @return [::String] # Required. Certificate name. # Applicable only for SQL Server instances. class SqlTdeImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#file_type ⇒ ::Google::Cloud::Sql::V1::SqlFileType
Returns The file type for the specified uri.`SQL: The file
contains SQL statements. \CSV`: The file contains CSV data.
637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 637 class ImportContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] threads # @return [::Google::Protobuf::Int32Value] # Optional. The number of threads to use for parallel import. # @!attribute [rw] parallel # @return [::Google::Protobuf::BoolValue] # Optional. Whether or not the import should be parallel. # @!attribute [rw] postgres_import_options # @return [::Google::Cloud::Sql::V1::ImportContext::SqlImportOptions::PostgresImportOptions] # Optional. Options for importing from a Cloud SQL for PostgreSQL instance. class SqlImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] clean # @return [::Google::Protobuf::BoolValue] # Optional. The --clean flag for the pg_restore utility. This flag # applies only if you enabled Cloud SQL to import files in parallel. # @!attribute [rw] if_exists # @return [::Google::Protobuf::BoolValue] # Optional. The --if-exists flag for the pg_restore utility. This flag # applies only if you enabled Cloud SQL to import files in parallel. class PostgresImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # @!attribute [rw] table # @return [::String] # The table to which CSV data is imported. # @!attribute [rw] columns # @return [::Array<::String>] # The columns to which CSV data is imported. If not specified, all columns # of the database table are loaded with CSV data. # @!attribute [rw] escape_character # @return [::String] # Specifies the character that should appear before a data character that # needs to be escaped. # @!attribute [rw] quote_character # @return [::String] # Specifies the quoting character to be used when a data value is quoted. # @!attribute [rw] fields_terminated_by # @return [::String] # Specifies the character that separates columns within each row (line) of # the file. # @!attribute [rw] lines_terminated_by # @return [::String] # This is used to separate lines. If a line does not contain all fields, # the rest of the columns are set to their default values. class SqlCsvImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] encryption_options # @return [::Google::Cloud::Sql::V1::ImportContext::SqlBakImportOptions::EncryptionOptions] # @!attribute [rw] striped # @return [::Google::Protobuf::BoolValue] # Whether or not the backup set being restored is striped. # Applies only to Cloud SQL for SQL Server. # @!attribute [rw] no_recovery # @return [::Google::Protobuf::BoolValue] # Whether or not the backup importing will restore database # with NORECOVERY option. # Applies only to Cloud SQL for SQL Server. # @!attribute [rw] recovery_only # @return [::Google::Protobuf::BoolValue] # Whether or not the backup importing request will just bring database # online without downloading Bak content only one of "no_recovery" and # "recovery_only" can be true otherwise error will return. Applies only to # Cloud SQL for SQL Server. # @!attribute [rw] bak_type # @return [::Google::Cloud::Sql::V1::BakType] # Type of the bak content, FULL or DIFF # @!attribute [rw] stop_at # @return [::Google::Protobuf::Timestamp] # Optional. The timestamp when the import should stop. This timestamp is in # the [RFC 3339](https://tools.ietf.org/html/rfc3339) format (for example, # `2023-10-01T16:19:00.094`). This field is equivalent to the STOPAT # keyword and applies to Cloud SQL for SQL Server only. # @!attribute [rw] stop_at_mark # @return [::String] # Optional. The marked transaction where the import should stop. This field # is equivalent to the STOPATMARK keyword and applies to Cloud SQL for SQL # Server only. class SqlBakImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] cert_path # @return [::String] # Path to the Certificate (.cer) in Cloud Storage, in the form # `gs://bucketName/fileName`. The instance must have # write permissions to the bucket and read access to the file. # @!attribute [rw] pvk_path # @return [::String] # Path to the Certificate Private Key (.pvk) in Cloud Storage, in the # form `gs://bucketName/fileName`. The instance must have # write permissions to the bucket and read access to the file. # @!attribute [rw] pvk_password # @return [::String] # Password that encrypts the private key # @!attribute [rw] keep_encrypted # @return [::Google::Protobuf::BoolValue] # Optional. Whether the imported file remains encrypted. class EncryptionOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # @!attribute [rw] certificate_path # @return [::String] # Required. Path to the TDE certificate public key # in the form gs://bucketName/fileName. # The instance must have read access to the file. # Applicable only for SQL Server instances. # @!attribute [rw] private_key_path # @return [::String] # Required. Path to the TDE certificate private key # in the form gs://bucketName/fileName. # The instance must have read access to the file. # Applicable only for SQL Server instances. # @!attribute [rw] private_key_password # @return [::String] # Required. Password that encrypts the private key. # @!attribute [rw] name # @return [::String] # Required. Certificate name. # Applicable only for SQL Server instances. class SqlTdeImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#import_user ⇒ ::String
Returns The PostgreSQL user for this import operation. PostgreSQL instances only.
637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 637 class ImportContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] threads # @return [::Google::Protobuf::Int32Value] # Optional. The number of threads to use for parallel import. # @!attribute [rw] parallel # @return [::Google::Protobuf::BoolValue] # Optional. Whether or not the import should be parallel. # @!attribute [rw] postgres_import_options # @return [::Google::Cloud::Sql::V1::ImportContext::SqlImportOptions::PostgresImportOptions] # Optional. Options for importing from a Cloud SQL for PostgreSQL instance. class SqlImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] clean # @return [::Google::Protobuf::BoolValue] # Optional. The --clean flag for the pg_restore utility. This flag # applies only if you enabled Cloud SQL to import files in parallel. # @!attribute [rw] if_exists # @return [::Google::Protobuf::BoolValue] # Optional. The --if-exists flag for the pg_restore utility. This flag # applies only if you enabled Cloud SQL to import files in parallel. class PostgresImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # @!attribute [rw] table # @return [::String] # The table to which CSV data is imported. # @!attribute [rw] columns # @return [::Array<::String>] # The columns to which CSV data is imported. If not specified, all columns # of the database table are loaded with CSV data. # @!attribute [rw] escape_character # @return [::String] # Specifies the character that should appear before a data character that # needs to be escaped. # @!attribute [rw] quote_character # @return [::String] # Specifies the quoting character to be used when a data value is quoted. # @!attribute [rw] fields_terminated_by # @return [::String] # Specifies the character that separates columns within each row (line) of # the file. # @!attribute [rw] lines_terminated_by # @return [::String] # This is used to separate lines. If a line does not contain all fields, # the rest of the columns are set to their default values. class SqlCsvImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] encryption_options # @return [::Google::Cloud::Sql::V1::ImportContext::SqlBakImportOptions::EncryptionOptions] # @!attribute [rw] striped # @return [::Google::Protobuf::BoolValue] # Whether or not the backup set being restored is striped. # Applies only to Cloud SQL for SQL Server. # @!attribute [rw] no_recovery # @return [::Google::Protobuf::BoolValue] # Whether or not the backup importing will restore database # with NORECOVERY option. # Applies only to Cloud SQL for SQL Server. # @!attribute [rw] recovery_only # @return [::Google::Protobuf::BoolValue] # Whether or not the backup importing request will just bring database # online without downloading Bak content only one of "no_recovery" and # "recovery_only" can be true otherwise error will return. Applies only to # Cloud SQL for SQL Server. # @!attribute [rw] bak_type # @return [::Google::Cloud::Sql::V1::BakType] # Type of the bak content, FULL or DIFF # @!attribute [rw] stop_at # @return [::Google::Protobuf::Timestamp] # Optional. The timestamp when the import should stop. This timestamp is in # the [RFC 3339](https://tools.ietf.org/html/rfc3339) format (for example, # `2023-10-01T16:19:00.094`). This field is equivalent to the STOPAT # keyword and applies to Cloud SQL for SQL Server only. # @!attribute [rw] stop_at_mark # @return [::String] # Optional. The marked transaction where the import should stop. This field # is equivalent to the STOPATMARK keyword and applies to Cloud SQL for SQL # Server only. class SqlBakImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] cert_path # @return [::String] # Path to the Certificate (.cer) in Cloud Storage, in the form # `gs://bucketName/fileName`. The instance must have # write permissions to the bucket and read access to the file. # @!attribute [rw] pvk_path # @return [::String] # Path to the Certificate Private Key (.pvk) in Cloud Storage, in the # form `gs://bucketName/fileName`. The instance must have # write permissions to the bucket and read access to the file. # @!attribute [rw] pvk_password # @return [::String] # Password that encrypts the private key # @!attribute [rw] keep_encrypted # @return [::Google::Protobuf::BoolValue] # Optional. Whether the imported file remains encrypted. class EncryptionOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # @!attribute [rw] certificate_path # @return [::String] # Required. Path to the TDE certificate public key # in the form gs://bucketName/fileName. # The instance must have read access to the file. # Applicable only for SQL Server instances. # @!attribute [rw] private_key_path # @return [::String] # Required. Path to the TDE certificate private key # in the form gs://bucketName/fileName. # The instance must have read access to the file. # Applicable only for SQL Server instances. # @!attribute [rw] private_key_password # @return [::String] # Required. Password that encrypts the private key. # @!attribute [rw] name # @return [::String] # Required. Certificate name. # Applicable only for SQL Server instances. class SqlTdeImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#kind ⇒ ::String
Returns This is always sql#importContext.
637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 637 class ImportContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] threads # @return [::Google::Protobuf::Int32Value] # Optional. The number of threads to use for parallel import. # @!attribute [rw] parallel # @return [::Google::Protobuf::BoolValue] # Optional. Whether or not the import should be parallel. # @!attribute [rw] postgres_import_options # @return [::Google::Cloud::Sql::V1::ImportContext::SqlImportOptions::PostgresImportOptions] # Optional. Options for importing from a Cloud SQL for PostgreSQL instance. class SqlImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] clean # @return [::Google::Protobuf::BoolValue] # Optional. The --clean flag for the pg_restore utility. This flag # applies only if you enabled Cloud SQL to import files in parallel. # @!attribute [rw] if_exists # @return [::Google::Protobuf::BoolValue] # Optional. The --if-exists flag for the pg_restore utility. This flag # applies only if you enabled Cloud SQL to import files in parallel. class PostgresImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # @!attribute [rw] table # @return [::String] # The table to which CSV data is imported. # @!attribute [rw] columns # @return [::Array<::String>] # The columns to which CSV data is imported. If not specified, all columns # of the database table are loaded with CSV data. # @!attribute [rw] escape_character # @return [::String] # Specifies the character that should appear before a data character that # needs to be escaped. # @!attribute [rw] quote_character # @return [::String] # Specifies the quoting character to be used when a data value is quoted. # @!attribute [rw] fields_terminated_by # @return [::String] # Specifies the character that separates columns within each row (line) of # the file. # @!attribute [rw] lines_terminated_by # @return [::String] # This is used to separate lines. If a line does not contain all fields, # the rest of the columns are set to their default values. class SqlCsvImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] encryption_options # @return [::Google::Cloud::Sql::V1::ImportContext::SqlBakImportOptions::EncryptionOptions] # @!attribute [rw] striped # @return [::Google::Protobuf::BoolValue] # Whether or not the backup set being restored is striped. # Applies only to Cloud SQL for SQL Server. # @!attribute [rw] no_recovery # @return [::Google::Protobuf::BoolValue] # Whether or not the backup importing will restore database # with NORECOVERY option. # Applies only to Cloud SQL for SQL Server. # @!attribute [rw] recovery_only # @return [::Google::Protobuf::BoolValue] # Whether or not the backup importing request will just bring database # online without downloading Bak content only one of "no_recovery" and # "recovery_only" can be true otherwise error will return. Applies only to # Cloud SQL for SQL Server. # @!attribute [rw] bak_type # @return [::Google::Cloud::Sql::V1::BakType] # Type of the bak content, FULL or DIFF # @!attribute [rw] stop_at # @return [::Google::Protobuf::Timestamp] # Optional. The timestamp when the import should stop. This timestamp is in # the [RFC 3339](https://tools.ietf.org/html/rfc3339) format (for example, # `2023-10-01T16:19:00.094`). This field is equivalent to the STOPAT # keyword and applies to Cloud SQL for SQL Server only. # @!attribute [rw] stop_at_mark # @return [::String] # Optional. The marked transaction where the import should stop. This field # is equivalent to the STOPATMARK keyword and applies to Cloud SQL for SQL # Server only. class SqlBakImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] cert_path # @return [::String] # Path to the Certificate (.cer) in Cloud Storage, in the form # `gs://bucketName/fileName`. The instance must have # write permissions to the bucket and read access to the file. # @!attribute [rw] pvk_path # @return [::String] # Path to the Certificate Private Key (.pvk) in Cloud Storage, in the # form `gs://bucketName/fileName`. The instance must have # write permissions to the bucket and read access to the file. # @!attribute [rw] pvk_password # @return [::String] # Password that encrypts the private key # @!attribute [rw] keep_encrypted # @return [::Google::Protobuf::BoolValue] # Optional. Whether the imported file remains encrypted. class EncryptionOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # @!attribute [rw] certificate_path # @return [::String] # Required. Path to the TDE certificate public key # in the form gs://bucketName/fileName. # The instance must have read access to the file. # Applicable only for SQL Server instances. # @!attribute [rw] private_key_path # @return [::String] # Required. Path to the TDE certificate private key # in the form gs://bucketName/fileName. # The instance must have read access to the file. # Applicable only for SQL Server instances. # @!attribute [rw] private_key_password # @return [::String] # Required. Password that encrypts the private key. # @!attribute [rw] name # @return [::String] # Required. Certificate name. # Applicable only for SQL Server instances. class SqlTdeImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#sql_import_options ⇒ ::Google::Cloud::Sql::V1::ImportContext::SqlImportOptions
Returns Optional. Options for importing data from SQL statements.
637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 637 class ImportContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] threads # @return [::Google::Protobuf::Int32Value] # Optional. The number of threads to use for parallel import. # @!attribute [rw] parallel # @return [::Google::Protobuf::BoolValue] # Optional. Whether or not the import should be parallel. # @!attribute [rw] postgres_import_options # @return [::Google::Cloud::Sql::V1::ImportContext::SqlImportOptions::PostgresImportOptions] # Optional. Options for importing from a Cloud SQL for PostgreSQL instance. class SqlImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] clean # @return [::Google::Protobuf::BoolValue] # Optional. The --clean flag for the pg_restore utility. This flag # applies only if you enabled Cloud SQL to import files in parallel. # @!attribute [rw] if_exists # @return [::Google::Protobuf::BoolValue] # Optional. The --if-exists flag for the pg_restore utility. This flag # applies only if you enabled Cloud SQL to import files in parallel. class PostgresImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # @!attribute [rw] table # @return [::String] # The table to which CSV data is imported. # @!attribute [rw] columns # @return [::Array<::String>] # The columns to which CSV data is imported. If not specified, all columns # of the database table are loaded with CSV data. # @!attribute [rw] escape_character # @return [::String] # Specifies the character that should appear before a data character that # needs to be escaped. # @!attribute [rw] quote_character # @return [::String] # Specifies the quoting character to be used when a data value is quoted. # @!attribute [rw] fields_terminated_by # @return [::String] # Specifies the character that separates columns within each row (line) of # the file. # @!attribute [rw] lines_terminated_by # @return [::String] # This is used to separate lines. If a line does not contain all fields, # the rest of the columns are set to their default values. class SqlCsvImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] encryption_options # @return [::Google::Cloud::Sql::V1::ImportContext::SqlBakImportOptions::EncryptionOptions] # @!attribute [rw] striped # @return [::Google::Protobuf::BoolValue] # Whether or not the backup set being restored is striped. # Applies only to Cloud SQL for SQL Server. # @!attribute [rw] no_recovery # @return [::Google::Protobuf::BoolValue] # Whether or not the backup importing will restore database # with NORECOVERY option. # Applies only to Cloud SQL for SQL Server. # @!attribute [rw] recovery_only # @return [::Google::Protobuf::BoolValue] # Whether or not the backup importing request will just bring database # online without downloading Bak content only one of "no_recovery" and # "recovery_only" can be true otherwise error will return. Applies only to # Cloud SQL for SQL Server. # @!attribute [rw] bak_type # @return [::Google::Cloud::Sql::V1::BakType] # Type of the bak content, FULL or DIFF # @!attribute [rw] stop_at # @return [::Google::Protobuf::Timestamp] # Optional. The timestamp when the import should stop. This timestamp is in # the [RFC 3339](https://tools.ietf.org/html/rfc3339) format (for example, # `2023-10-01T16:19:00.094`). This field is equivalent to the STOPAT # keyword and applies to Cloud SQL for SQL Server only. # @!attribute [rw] stop_at_mark # @return [::String] # Optional. The marked transaction where the import should stop. This field # is equivalent to the STOPATMARK keyword and applies to Cloud SQL for SQL # Server only. class SqlBakImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] cert_path # @return [::String] # Path to the Certificate (.cer) in Cloud Storage, in the form # `gs://bucketName/fileName`. The instance must have # write permissions to the bucket and read access to the file. # @!attribute [rw] pvk_path # @return [::String] # Path to the Certificate Private Key (.pvk) in Cloud Storage, in the # form `gs://bucketName/fileName`. The instance must have # write permissions to the bucket and read access to the file. # @!attribute [rw] pvk_password # @return [::String] # Password that encrypts the private key # @!attribute [rw] keep_encrypted # @return [::Google::Protobuf::BoolValue] # Optional. Whether the imported file remains encrypted. class EncryptionOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # @!attribute [rw] certificate_path # @return [::String] # Required. Path to the TDE certificate public key # in the form gs://bucketName/fileName. # The instance must have read access to the file. # Applicable only for SQL Server instances. # @!attribute [rw] private_key_path # @return [::String] # Required. Path to the TDE certificate private key # in the form gs://bucketName/fileName. # The instance must have read access to the file. # Applicable only for SQL Server instances. # @!attribute [rw] private_key_password # @return [::String] # Required. Password that encrypts the private key. # @!attribute [rw] name # @return [::String] # Required. Certificate name. # Applicable only for SQL Server instances. class SqlTdeImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#tde_import_options ⇒ ::Google::Cloud::Sql::V1::ImportContext::SqlTdeImportOptions
Returns Optional. Import parameters specific to SQL Server TDE certificates.
637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 637 class ImportContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] threads # @return [::Google::Protobuf::Int32Value] # Optional. The number of threads to use for parallel import. # @!attribute [rw] parallel # @return [::Google::Protobuf::BoolValue] # Optional. Whether or not the import should be parallel. # @!attribute [rw] postgres_import_options # @return [::Google::Cloud::Sql::V1::ImportContext::SqlImportOptions::PostgresImportOptions] # Optional. Options for importing from a Cloud SQL for PostgreSQL instance. class SqlImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] clean # @return [::Google::Protobuf::BoolValue] # Optional. The --clean flag for the pg_restore utility. This flag # applies only if you enabled Cloud SQL to import files in parallel. # @!attribute [rw] if_exists # @return [::Google::Protobuf::BoolValue] # Optional. The --if-exists flag for the pg_restore utility. This flag # applies only if you enabled Cloud SQL to import files in parallel. class PostgresImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # @!attribute [rw] table # @return [::String] # The table to which CSV data is imported. # @!attribute [rw] columns # @return [::Array<::String>] # The columns to which CSV data is imported. If not specified, all columns # of the database table are loaded with CSV data. # @!attribute [rw] escape_character # @return [::String] # Specifies the character that should appear before a data character that # needs to be escaped. # @!attribute [rw] quote_character # @return [::String] # Specifies the quoting character to be used when a data value is quoted. # @!attribute [rw] fields_terminated_by # @return [::String] # Specifies the character that separates columns within each row (line) of # the file. # @!attribute [rw] lines_terminated_by # @return [::String] # This is used to separate lines. If a line does not contain all fields, # the rest of the columns are set to their default values. class SqlCsvImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] encryption_options # @return [::Google::Cloud::Sql::V1::ImportContext::SqlBakImportOptions::EncryptionOptions] # @!attribute [rw] striped # @return [::Google::Protobuf::BoolValue] # Whether or not the backup set being restored is striped. # Applies only to Cloud SQL for SQL Server. # @!attribute [rw] no_recovery # @return [::Google::Protobuf::BoolValue] # Whether or not the backup importing will restore database # with NORECOVERY option. # Applies only to Cloud SQL for SQL Server. # @!attribute [rw] recovery_only # @return [::Google::Protobuf::BoolValue] # Whether or not the backup importing request will just bring database # online without downloading Bak content only one of "no_recovery" and # "recovery_only" can be true otherwise error will return. Applies only to # Cloud SQL for SQL Server. # @!attribute [rw] bak_type # @return [::Google::Cloud::Sql::V1::BakType] # Type of the bak content, FULL or DIFF # @!attribute [rw] stop_at # @return [::Google::Protobuf::Timestamp] # Optional. The timestamp when the import should stop. This timestamp is in # the [RFC 3339](https://tools.ietf.org/html/rfc3339) format (for example, # `2023-10-01T16:19:00.094`). This field is equivalent to the STOPAT # keyword and applies to Cloud SQL for SQL Server only. # @!attribute [rw] stop_at_mark # @return [::String] # Optional. The marked transaction where the import should stop. This field # is equivalent to the STOPATMARK keyword and applies to Cloud SQL for SQL # Server only. class SqlBakImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] cert_path # @return [::String] # Path to the Certificate (.cer) in Cloud Storage, in the form # `gs://bucketName/fileName`. The instance must have # write permissions to the bucket and read access to the file. # @!attribute [rw] pvk_path # @return [::String] # Path to the Certificate Private Key (.pvk) in Cloud Storage, in the # form `gs://bucketName/fileName`. The instance must have # write permissions to the bucket and read access to the file. # @!attribute [rw] pvk_password # @return [::String] # Password that encrypts the private key # @!attribute [rw] keep_encrypted # @return [::Google::Protobuf::BoolValue] # Optional. Whether the imported file remains encrypted. class EncryptionOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # @!attribute [rw] certificate_path # @return [::String] # Required. Path to the TDE certificate public key # in the form gs://bucketName/fileName. # The instance must have read access to the file. # Applicable only for SQL Server instances. # @!attribute [rw] private_key_path # @return [::String] # Required. Path to the TDE certificate private key # in the form gs://bucketName/fileName. # The instance must have read access to the file. # Applicable only for SQL Server instances. # @!attribute [rw] private_key_password # @return [::String] # Required. Password that encrypts the private key. # @!attribute [rw] name # @return [::String] # Required. Certificate name. # Applicable only for SQL Server instances. class SqlTdeImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#uri ⇒ ::String
Returns Path to the import file in Cloud Storage, in the form
gs://bucketName/fileName. Compressed gzip files (.gz) are supported
when fileType is SQL. The instance must have
write permissions to the bucket and read access to the file.
637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 637 class ImportContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] threads # @return [::Google::Protobuf::Int32Value] # Optional. The number of threads to use for parallel import. # @!attribute [rw] parallel # @return [::Google::Protobuf::BoolValue] # Optional. Whether or not the import should be parallel. # @!attribute [rw] postgres_import_options # @return [::Google::Cloud::Sql::V1::ImportContext::SqlImportOptions::PostgresImportOptions] # Optional. Options for importing from a Cloud SQL for PostgreSQL instance. class SqlImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] clean # @return [::Google::Protobuf::BoolValue] # Optional. The --clean flag for the pg_restore utility. This flag # applies only if you enabled Cloud SQL to import files in parallel. # @!attribute [rw] if_exists # @return [::Google::Protobuf::BoolValue] # Optional. The --if-exists flag for the pg_restore utility. This flag # applies only if you enabled Cloud SQL to import files in parallel. class PostgresImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # @!attribute [rw] table # @return [::String] # The table to which CSV data is imported. # @!attribute [rw] columns # @return [::Array<::String>] # The columns to which CSV data is imported. If not specified, all columns # of the database table are loaded with CSV data. # @!attribute [rw] escape_character # @return [::String] # Specifies the character that should appear before a data character that # needs to be escaped. # @!attribute [rw] quote_character # @return [::String] # Specifies the quoting character to be used when a data value is quoted. # @!attribute [rw] fields_terminated_by # @return [::String] # Specifies the character that separates columns within each row (line) of # the file. # @!attribute [rw] lines_terminated_by # @return [::String] # This is used to separate lines. If a line does not contain all fields, # the rest of the columns are set to their default values. class SqlCsvImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] encryption_options # @return [::Google::Cloud::Sql::V1::ImportContext::SqlBakImportOptions::EncryptionOptions] # @!attribute [rw] striped # @return [::Google::Protobuf::BoolValue] # Whether or not the backup set being restored is striped. # Applies only to Cloud SQL for SQL Server. # @!attribute [rw] no_recovery # @return [::Google::Protobuf::BoolValue] # Whether or not the backup importing will restore database # with NORECOVERY option. # Applies only to Cloud SQL for SQL Server. # @!attribute [rw] recovery_only # @return [::Google::Protobuf::BoolValue] # Whether or not the backup importing request will just bring database # online without downloading Bak content only one of "no_recovery" and # "recovery_only" can be true otherwise error will return. Applies only to # Cloud SQL for SQL Server. # @!attribute [rw] bak_type # @return [::Google::Cloud::Sql::V1::BakType] # Type of the bak content, FULL or DIFF # @!attribute [rw] stop_at # @return [::Google::Protobuf::Timestamp] # Optional. The timestamp when the import should stop. This timestamp is in # the [RFC 3339](https://tools.ietf.org/html/rfc3339) format (for example, # `2023-10-01T16:19:00.094`). This field is equivalent to the STOPAT # keyword and applies to Cloud SQL for SQL Server only. # @!attribute [rw] stop_at_mark # @return [::String] # Optional. The marked transaction where the import should stop. This field # is equivalent to the STOPATMARK keyword and applies to Cloud SQL for SQL # Server only. class SqlBakImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] cert_path # @return [::String] # Path to the Certificate (.cer) in Cloud Storage, in the form # `gs://bucketName/fileName`. The instance must have # write permissions to the bucket and read access to the file. # @!attribute [rw] pvk_path # @return [::String] # Path to the Certificate Private Key (.pvk) in Cloud Storage, in the # form `gs://bucketName/fileName`. The instance must have # write permissions to the bucket and read access to the file. # @!attribute [rw] pvk_password # @return [::String] # Password that encrypts the private key # @!attribute [rw] keep_encrypted # @return [::Google::Protobuf::BoolValue] # Optional. Whether the imported file remains encrypted. class EncryptionOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # @!attribute [rw] certificate_path # @return [::String] # Required. Path to the TDE certificate public key # in the form gs://bucketName/fileName. # The instance must have read access to the file. # Applicable only for SQL Server instances. # @!attribute [rw] private_key_path # @return [::String] # Required. Path to the TDE certificate private key # in the form gs://bucketName/fileName. # The instance must have read access to the file. # Applicable only for SQL Server instances. # @!attribute [rw] private_key_password # @return [::String] # Required. Password that encrypts the private key. # @!attribute [rw] name # @return [::String] # Required. Certificate name. # Applicable only for SQL Server instances. class SqlTdeImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |