Class: Google::Cloud::Sql::V1::ImportContext::SqlBakImportOptions::EncryptionOptions

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb

Instance Attribute Summary collapse

Instance Attribute Details

#cert_path::String

Returns Path to the Certificate (.cer) in Cloud Storage, in the form gs://bucketName/fileName. The instance must have write permissions to the bucket and read access to the file.

Returns:

  • (::String)

    Path to the Certificate (.cer) in Cloud Storage, in the form gs://bucketName/fileName. The instance must have write permissions to the bucket and read access to the file.



746
747
748
749
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 746

class EncryptionOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#keep_encrypted::Google::Protobuf::BoolValue

Returns Optional. Whether the imported file remains encrypted.

Returns:



746
747
748
749
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 746

class EncryptionOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#pvk_password::String

Returns Password that encrypts the private key.

Returns:

  • (::String)

    Password that encrypts the private key



746
747
748
749
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 746

class EncryptionOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#pvk_path::String

Returns Path to the Certificate Private Key (.pvk) in Cloud Storage, in the form gs://bucketName/fileName. The instance must have write permissions to the bucket and read access to the file.

Returns:

  • (::String)

    Path to the Certificate Private Key (.pvk) in Cloud Storage, in the form gs://bucketName/fileName. The instance must have write permissions to the bucket and read access to the file.



746
747
748
749
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 746

class EncryptionOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end