Class: Google::Cloud::Sql::V1::ImportContext::SqlCsvImportOptions

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb

Instance Attribute Summary collapse

Instance Attribute Details

#columns::Array<::String>

Returns The columns to which CSV data is imported. If not specified, all columns of the database table are loaded with CSV data.

Returns:

  • (::Array<::String>)

    The columns to which CSV data is imported. If not specified, all columns of the database table are loaded with CSV data.



690
691
692
693
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 690

class SqlCsvImportOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#escape_character::String

Returns Specifies the character that should appear before a data character that needs to be escaped.

Returns:

  • (::String)

    Specifies the character that should appear before a data character that needs to be escaped.



690
691
692
693
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 690

class SqlCsvImportOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#fields_terminated_by::String

Returns Specifies the character that separates columns within each row (line) of the file.

Returns:

  • (::String)

    Specifies the character that separates columns within each row (line) of the file.



690
691
692
693
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 690

class SqlCsvImportOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#lines_terminated_by::String

Returns This is used to separate lines. If a line does not contain all fields, the rest of the columns are set to their default values.

Returns:

  • (::String)

    This is used to separate lines. If a line does not contain all fields, the rest of the columns are set to their default values.



690
691
692
693
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 690

class SqlCsvImportOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#quote_character::String

Returns Specifies the quoting character to be used when a data value is quoted.

Returns:

  • (::String)

    Specifies the quoting character to be used when a data value is quoted.



690
691
692
693
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 690

class SqlCsvImportOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#table::String

Returns The table to which CSV data is imported.

Returns:

  • (::String)

    The table to which CSV data is imported.



690
691
692
693
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 690

class SqlCsvImportOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end