Class: Google::Cloud::Sql::V1::InsightsConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb

Overview

Insights configuration. This specifies when Cloud SQL Insights feature is enabled and optional configuration.

Instance Attribute Summary collapse

Instance Attribute Details

#enhanced_query_insights_enabled::Google::Protobuf::BoolValue

Returns Optional. Whether enhanced query insights feature is enabled.

Returns:



1137
1138
1139
1140
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1137

class InsightsConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#query_insights_enabled::Boolean

Returns Whether Query Insights feature is enabled.

Returns:

  • (::Boolean)

    Whether Query Insights feature is enabled.



1137
1138
1139
1140
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1137

class InsightsConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#query_plans_per_minute::Google::Protobuf::Int32Value

Returns Number of query execution plans captured by Insights per minute for all queries combined. Default is 5.

Returns:



1137
1138
1139
1140
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1137

class InsightsConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#query_string_length::Google::Protobuf::Int32Value

Returns Maximum query length stored in bytes. Default value: 1024 bytes. Range: 256-4500 bytes. Query lengths greater than this field value will be truncated to this value. When unset, query length will be the default value. Changing query length will restart the database.

Returns:

  • (::Google::Protobuf::Int32Value)

    Maximum query length stored in bytes. Default value: 1024 bytes. Range: 256-4500 bytes. Query lengths greater than this field value will be truncated to this value. When unset, query length will be the default value. Changing query length will restart the database.



1137
1138
1139
1140
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1137

class InsightsConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#record_application_tags::Boolean

Returns Whether Query Insights will record application tags from query when enabled.

Returns:

  • (::Boolean)

    Whether Query Insights will record application tags from query when enabled.



1137
1138
1139
1140
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1137

class InsightsConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#record_client_address::Boolean

Returns Whether Query Insights will record client address when enabled.

Returns:

  • (::Boolean)

    Whether Query Insights will record client address when enabled.



1137
1138
1139
1140
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1137

class InsightsConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end