Class: Google::Cloud::Sql::V1::InstancesListResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::InstancesListResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb
Overview
Database instances list response.
Instance Attribute Summary collapse
-
#items ⇒ ::Array<::Google::Cloud::Sql::V1::DatabaseInstance>
List of database instance resources.
-
#kind ⇒ ::String
This is always
sql#instancesList. -
#next_page_token ⇒ ::String
The continuation token, used to page through large result sets.
-
#warnings ⇒ ::Array<::Google::Cloud::Sql::V1::ApiWarning>
List of warnings that occurred while handling the request.
Instance Attribute Details
#items ⇒ ::Array<::Google::Cloud::Sql::V1::DatabaseInstance>
Returns List of database instance resources.
781 782 783 784 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 781 class InstancesListResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#kind ⇒ ::String
Returns This is always sql#instancesList.
781 782 783 784 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 781 class InstancesListResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns The continuation token, used to page through large result sets. Provide this value in a subsequent request to return the next page of results.
781 782 783 784 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 781 class InstancesListResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#warnings ⇒ ::Array<::Google::Cloud::Sql::V1::ApiWarning>
Returns List of warnings that occurred while handling the request.
781 782 783 784 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 781 class InstancesListResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |