Class: Google::Cloud::Sql::V1::InstancesListServerCertificatesResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::InstancesListServerCertificatesResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb
Overview
Instances ListServerCertificates response.
Instance Attribute Summary collapse
-
#active_version ⇒ ::String
The
sha1_fingerprintof the active certificate fromserver_certs. -
#ca_certs ⇒ ::Array<::Google::Cloud::Sql::V1::SslCert>
List of server CA certificates for the instance.
-
#kind ⇒ ::String
This is always
sql#instancesListServerCertificates. -
#server_certs ⇒ ::Array<::Google::Cloud::Sql::V1::SslCert>
List of server certificates for the instance, signed by the corresponding CA from the
ca_certslist.
Instance Attribute Details
#active_version ⇒ ::String
Returns The sha1_fingerprint of the active certificate from server_certs.
814 815 816 817 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 814 class InstancesListServerCertificatesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#ca_certs ⇒ ::Array<::Google::Cloud::Sql::V1::SslCert>
Returns List of server CA certificates for the instance.
814 815 816 817 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 814 class InstancesListServerCertificatesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#kind ⇒ ::String
Returns This is always sql#instancesListServerCertificates.
814 815 816 817 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 814 class InstancesListServerCertificatesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#server_certs ⇒ ::Array<::Google::Cloud::Sql::V1::SslCert>
Returns List of server certificates for the instance, signed by the corresponding
CA from the ca_certs list.
814 815 816 817 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 814 class InstancesListServerCertificatesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |