Class: Google::Cloud::Sql::V1::IpMapping

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb

Overview

Database instance IP mapping

Instance Attribute Summary collapse

Instance Attribute Details

#ip_address::String

Returns The IP address assigned.

Returns:

  • (::String)

    The IP address assigned.



1203
1204
1205
1206
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1203

class IpMapping
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#time_to_retire::Google::Protobuf::Timestamp

Returns The due time for this IP to be retired in RFC 3339 format, for example 2012-11-15T16:19:00.094Z. This field is only available when the IP is scheduled to be retired.

Returns:

  • (::Google::Protobuf::Timestamp)

    The due time for this IP to be retired in RFC 3339 format, for example 2012-11-15T16:19:00.094Z. This field is only available when the IP is scheduled to be retired.



1203
1204
1205
1206
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1203

class IpMapping
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#type::Google::Cloud::Sql::V1::SqlIpAddressType

Returns The type of this IP address. A PRIMARY address is a public address that can accept incoming connections. A PRIVATE address is a private address that can accept incoming connections. An OUTGOING address is the source address of connections originating from the instance, if supported.

Returns:

  • (::Google::Cloud::Sql::V1::SqlIpAddressType)

    The type of this IP address. A PRIMARY address is a public address that can accept incoming connections. A PRIVATE address is a private address that can accept incoming connections. An OUTGOING address is the source address of connections originating from the instance, if supported.



1203
1204
1205
1206
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1203

class IpMapping
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end