Class: Google::Cloud::Sql::V1::ListBackupsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_backups.rb

Overview

The response payload containing a list of the backups.

Instance Attribute Summary collapse

Instance Attribute Details

#backups::Array<::Google::Cloud::Sql::V1::Backup>

Returns A list of backups.

Returns:



89
90
91
92
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backups.rb', line 89

class ListBackupsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns A token, which can be sent as page_token to retrieve the next page. If this field is omitted, then there aren't subsequent pages.

Returns:

  • (::String)

    A token, which can be sent as page_token to retrieve the next page. If this field is omitted, then there aren't subsequent pages.



89
90
91
92
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backups.rb', line 89

class ListBackupsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#warnings::Array<::Google::Cloud::Sql::V1::ApiWarning>

Returns If a region isn't unavailable or if an unknown error occurs, then a warning message is returned.

Returns:



89
90
91
92
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backups.rb', line 89

class ListBackupsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end