Class: Google::Cloud::Sql::V1::OnPremisesConfiguration

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb

Overview

On-premises instance configuration.

Defined Under Namespace

Modules: SslOption

Instance Attribute Summary collapse

Instance Attribute Details

#ca_certificate::String

Returns PEM representation of the trusted CA's x509 certificate.

Returns:

  • (::String)

    PEM representation of the trusted CA's x509 certificate.



2008
2009
2010
2011
2012
2013
2014
2015
2016
2017
2018
2019
2020
2021
2022
2023
2024
2025
2026
2027
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 2008

class OnPremisesConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # SslOption defines the SSL mode to be used for replica connection to the
  # on-premises source.
  module SslOption
    # Unknown SSL option i.e. SSL option not specified by user.
    SSL_OPTION_UNSPECIFIED = 0

    # SSL is not used for replica connection to the on-premises source.
    DISABLE = 1

    # SSL is required for replica connection to the on-premises source.
    REQUIRE = 2

    # Verify CA is required for replica connection to the on-premises source.
    VERIFY_CA = 3
  end
end

#client_certificate::String

Returns PEM representation of the replica's x509 certificate.

Returns:

  • (::String)

    PEM representation of the replica's x509 certificate.



2008
2009
2010
2011
2012
2013
2014
2015
2016
2017
2018
2019
2020
2021
2022
2023
2024
2025
2026
2027
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 2008

class OnPremisesConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # SslOption defines the SSL mode to be used for replica connection to the
  # on-premises source.
  module SslOption
    # Unknown SSL option i.e. SSL option not specified by user.
    SSL_OPTION_UNSPECIFIED = 0

    # SSL is not used for replica connection to the on-premises source.
    DISABLE = 1

    # SSL is required for replica connection to the on-premises source.
    REQUIRE = 2

    # Verify CA is required for replica connection to the on-premises source.
    VERIFY_CA = 3
  end
end

#client_key::String

Returns PEM representation of the replica's private key. The corresponding public key is encoded in the client's certificate.

Returns:

  • (::String)

    PEM representation of the replica's private key. The corresponding public key is encoded in the client's certificate.



2008
2009
2010
2011
2012
2013
2014
2015
2016
2017
2018
2019
2020
2021
2022
2023
2024
2025
2026
2027
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 2008

class OnPremisesConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # SslOption defines the SSL mode to be used for replica connection to the
  # on-premises source.
  module SslOption
    # Unknown SSL option i.e. SSL option not specified by user.
    SSL_OPTION_UNSPECIFIED = 0

    # SSL is not used for replica connection to the on-premises source.
    DISABLE = 1

    # SSL is required for replica connection to the on-premises source.
    REQUIRE = 2

    # Verify CA is required for replica connection to the on-premises source.
    VERIFY_CA = 3
  end
end

#dump_file_path::String

Returns The dump file to create the Cloud SQL replica.

Returns:

  • (::String)

    The dump file to create the Cloud SQL replica.



2008
2009
2010
2011
2012
2013
2014
2015
2016
2017
2018
2019
2020
2021
2022
2023
2024
2025
2026
2027
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 2008

class OnPremisesConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # SslOption defines the SSL mode to be used for replica connection to the
  # on-premises source.
  module SslOption
    # Unknown SSL option i.e. SSL option not specified by user.
    SSL_OPTION_UNSPECIFIED = 0

    # SSL is not used for replica connection to the on-premises source.
    DISABLE = 1

    # SSL is required for replica connection to the on-premises source.
    REQUIRE = 2

    # Verify CA is required for replica connection to the on-premises source.
    VERIFY_CA = 3
  end
end

#host_port::String

Returns The host and port of the on-premises instance in host:port format.

Returns:

  • (::String)

    The host and port of the on-premises instance in host:port format



2008
2009
2010
2011
2012
2013
2014
2015
2016
2017
2018
2019
2020
2021
2022
2023
2024
2025
2026
2027
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 2008

class OnPremisesConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # SslOption defines the SSL mode to be used for replica connection to the
  # on-premises source.
  module SslOption
    # Unknown SSL option i.e. SSL option not specified by user.
    SSL_OPTION_UNSPECIFIED = 0

    # SSL is not used for replica connection to the on-premises source.
    DISABLE = 1

    # SSL is required for replica connection to the on-premises source.
    REQUIRE = 2

    # Verify CA is required for replica connection to the on-premises source.
    VERIFY_CA = 3
  end
end

#kind::String

Returns This is always sql#onPremisesConfiguration.

Returns:

  • (::String)

    This is always sql#onPremisesConfiguration.



2008
2009
2010
2011
2012
2013
2014
2015
2016
2017
2018
2019
2020
2021
2022
2023
2024
2025
2026
2027
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 2008

class OnPremisesConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # SslOption defines the SSL mode to be used for replica connection to the
  # on-premises source.
  module SslOption
    # Unknown SSL option i.e. SSL option not specified by user.
    SSL_OPTION_UNSPECIFIED = 0

    # SSL is not used for replica connection to the on-premises source.
    DISABLE = 1

    # SSL is required for replica connection to the on-premises source.
    REQUIRE = 2

    # Verify CA is required for replica connection to the on-premises source.
    VERIFY_CA = 3
  end
end

#password::String

Returns The password for connecting to on-premises instance.

Returns:

  • (::String)

    The password for connecting to on-premises instance.



2008
2009
2010
2011
2012
2013
2014
2015
2016
2017
2018
2019
2020
2021
2022
2023
2024
2025
2026
2027
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 2008

class OnPremisesConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # SslOption defines the SSL mode to be used for replica connection to the
  # on-premises source.
  module SslOption
    # Unknown SSL option i.e. SSL option not specified by user.
    SSL_OPTION_UNSPECIFIED = 0

    # SSL is not used for replica connection to the on-premises source.
    DISABLE = 1

    # SSL is required for replica connection to the on-premises source.
    REQUIRE = 2

    # Verify CA is required for replica connection to the on-premises source.
    VERIFY_CA = 3
  end
end

#selected_objects::Array<::Google::Cloud::Sql::V1::SelectedObjects>

Returns Optional. A list of objects that the user selects for replication from an external source instance.

Returns:



2008
2009
2010
2011
2012
2013
2014
2015
2016
2017
2018
2019
2020
2021
2022
2023
2024
2025
2026
2027
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 2008

class OnPremisesConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # SslOption defines the SSL mode to be used for replica connection to the
  # on-premises source.
  module SslOption
    # Unknown SSL option i.e. SSL option not specified by user.
    SSL_OPTION_UNSPECIFIED = 0

    # SSL is not used for replica connection to the on-premises source.
    DISABLE = 1

    # SSL is required for replica connection to the on-premises source.
    REQUIRE = 2

    # Verify CA is required for replica connection to the on-premises source.
    VERIFY_CA = 3
  end
end

#source_instance::Google::Cloud::Sql::V1::InstanceReference

Returns The reference to Cloud SQL instance if the source is Cloud SQL.

Returns:



2008
2009
2010
2011
2012
2013
2014
2015
2016
2017
2018
2019
2020
2021
2022
2023
2024
2025
2026
2027
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 2008

class OnPremisesConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # SslOption defines the SSL mode to be used for replica connection to the
  # on-premises source.
  module SslOption
    # Unknown SSL option i.e. SSL option not specified by user.
    SSL_OPTION_UNSPECIFIED = 0

    # SSL is not used for replica connection to the on-premises source.
    DISABLE = 1

    # SSL is required for replica connection to the on-premises source.
    REQUIRE = 2

    # Verify CA is required for replica connection to the on-premises source.
    VERIFY_CA = 3
  end
end

#ssl_option::Google::Cloud::Sql::V1::OnPremisesConfiguration::SslOption

Returns Optional. SSL option for replica connection to the on-premises source.

Returns:



2008
2009
2010
2011
2012
2013
2014
2015
2016
2017
2018
2019
2020
2021
2022
2023
2024
2025
2026
2027
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 2008

class OnPremisesConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # SslOption defines the SSL mode to be used for replica connection to the
  # on-premises source.
  module SslOption
    # Unknown SSL option i.e. SSL option not specified by user.
    SSL_OPTION_UNSPECIFIED = 0

    # SSL is not used for replica connection to the on-premises source.
    DISABLE = 1

    # SSL is required for replica connection to the on-premises source.
    REQUIRE = 2

    # Verify CA is required for replica connection to the on-premises source.
    VERIFY_CA = 3
  end
end

#username::String

Returns The username for connecting to on-premises instance.

Returns:

  • (::String)

    The username for connecting to on-premises instance.



2008
2009
2010
2011
2012
2013
2014
2015
2016
2017
2018
2019
2020
2021
2022
2023
2024
2025
2026
2027
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 2008

class OnPremisesConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # SslOption defines the SSL mode to be used for replica connection to the
  # on-premises source.
  module SslOption
    # Unknown SSL option i.e. SSL option not specified by user.
    SSL_OPTION_UNSPECIFIED = 0

    # SSL is not used for replica connection to the on-premises source.
    DISABLE = 1

    # SSL is required for replica connection to the on-premises source.
    REQUIRE = 2

    # Verify CA is required for replica connection to the on-premises source.
    VERIFY_CA = 3
  end
end