Class: Google::Cloud::Sql::V1::OperationsListResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::OperationsListResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_operations.rb
Overview
Operations list response.
Instance Attribute Summary collapse
-
#items ⇒ ::Array<::Google::Cloud::Sql::V1::Operation>
List of operation resources.
-
#kind ⇒ ::String
This is always
sql#operationsList. -
#next_page_token ⇒ ::String
The continuation token, used to page through large result sets.
Instance Attribute Details
#items ⇒ ::Array<::Google::Cloud::Sql::V1::Operation>
Returns List of operation resources.
66 67 68 69 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_operations.rb', line 66 class OperationsListResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#kind ⇒ ::String
Returns This is always sql#operationsList.
66 67 68 69 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_operations.rb', line 66 class OperationsListResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns The continuation token, used to page through large result sets. Provide this value in a subsequent request to return the next page of results.
66 67 68 69 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_operations.rb', line 66 class OperationsListResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |