Class: Google::Cloud::Sql::V1::PointInTimeRestoreContext

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb

Overview

The context to perform a point-in-time recovery of an instance managed by Backup and Disaster Recovery (DR) Service.

Instance Attribute Summary collapse

Instance Attribute Details

#allocated_ip_range::String

Returns Optional. The name of the allocated IP range for the internal IP Cloud SQL instance. For example: "google-managed-services-default". If you set this, then Cloud SQL creates the IP address for the cloned instance in the allocated range. This range must comply with RFC 1035 standards. Specifically, the name must be 1-63 characters long and match the regular expression a-z?. Reserved for future use.

Returns:

  • (::String)

    Optional. The name of the allocated IP range for the internal IP Cloud SQL instance. For example: "google-managed-services-default". If you set this, then Cloud SQL creates the IP address for the cloned instance in the allocated range. This range must comply with RFC 1035 standards. Specifically, the name must be 1-63 characters long and match the regular expression a-z?. Reserved for future use.



1102
1103
1104
1105
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1102

class PointInTimeRestoreContext
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#datasource::String

Returns The Backup and Disaster Recovery (DR) Service Datasource URI. Format: projects/{project}/locations/{region}/backupVaults/{backupvault}/dataSources/{datasource}.

Returns:

  • (::String)

    The Backup and Disaster Recovery (DR) Service Datasource URI. Format: projects/{project}/locations/{region}/backupVaults/{backupvault}/dataSources/{datasource}.



1102
1103
1104
1105
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1102

class PointInTimeRestoreContext
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#point_in_time::Google::Protobuf::Timestamp

Returns Required. The date and time to which you want to restore the instance.

Returns:



1102
1103
1104
1105
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1102

class PointInTimeRestoreContext
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#preferred_secondary_zone::String

Returns Optional. Point-in-time recovery of a regional instance in the specified zones. If not specified, clone to the same secondary zone as the source instance. This value cannot be the same as the preferred_zone field.

Returns:

  • (::String)

    Optional. Point-in-time recovery of a regional instance in the specified zones. If not specified, clone to the same secondary zone as the source instance. This value cannot be the same as the preferred_zone field.



1102
1103
1104
1105
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1102

class PointInTimeRestoreContext
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#preferred_zone::String

Returns Optional. Point-in-time recovery of an instance to the specified zone. If no zone is specified, then clone to the same primary zone as the source instance.

Returns:

  • (::String)

    Optional. Point-in-time recovery of an instance to the specified zone. If no zone is specified, then clone to the same primary zone as the source instance.



1102
1103
1104
1105
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1102

class PointInTimeRestoreContext
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#private_network::String

Returns Optional. The resource link for the VPC network from which the Cloud SQL instance is accessible for private IP. For example, /projects/myProject/global/networks/default.

Returns:

  • (::String)

    Optional. The resource link for the VPC network from which the Cloud SQL instance is accessible for private IP. For example, /projects/myProject/global/networks/default.



1102
1103
1104
1105
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1102

class PointInTimeRestoreContext
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#region::String

Returns Optional. The region of the target instance where the datasource will be restored. For example: "us-central1".

Returns:

  • (::String)

    Optional. The region of the target instance where the datasource will be restored. For example: "us-central1".



1102
1103
1104
1105
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1102

class PointInTimeRestoreContext
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#target_instance::String

Returns Target instance name.

Returns:

  • (::String)

    Target instance name.



1102
1103
1104
1105
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1102

class PointInTimeRestoreContext
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#target_instance_clear_settings_field_names::Array<::String>

Returns Optional. Specifies the instance settings that will be cleared from the source instance. This field is only applicable for cross project PITRs.

Returns:

  • (::Array<::String>)

    Optional. Specifies the instance settings that will be cleared from the source instance. This field is only applicable for cross project PITRs.



1102
1103
1104
1105
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1102

class PointInTimeRestoreContext
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#target_instance_settings::Google::Cloud::Sql::V1::DatabaseInstance

Returns Optional. Specifies the instance settings that will be overridden from the source instance. This field is only applicable for cross project PITRs.

Returns:



1102
1103
1104
1105
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1102

class PointInTimeRestoreContext
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end