Class: Google::Cloud::Sql::V1::PreCheckResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb

Overview

Structured PreCheckResponse containing message, type, and required actions.

Defined Under Namespace

Modules: MessageType

Instance Attribute Summary collapse

Instance Attribute Details

#actions_required::Array<::String>

Returns The actions that the user needs to take. Use repeated for multiple actions.

Returns:

  • (::Array<::String>)

    The actions that the user needs to take. Use repeated for multiple actions.



212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 212

class PreCheckResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of message which can be an info, a warning, or an error that
  # requires user intervention.
  module MessageType
    # Default unspecified value to prevent unintended behavior changes.
    MESSAGE_TYPE_UNSPECIFIED = 0

    # General informational messages that don't require action.
    INFO = 1

    # Warnings that might impact the upgrade but don't block it.
    WARNING = 2

    # Errors that a user must resolve before proceeding with the upgrade.
    ERROR = 3
  end
end

#message::String

Returns The message to be displayed to the user.

Returns:

  • (::String)

    The message to be displayed to the user.



212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 212

class PreCheckResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of message which can be an info, a warning, or an error that
  # requires user intervention.
  module MessageType
    # Default unspecified value to prevent unintended behavior changes.
    MESSAGE_TYPE_UNSPECIFIED = 0

    # General informational messages that don't require action.
    INFO = 1

    # Warnings that might impact the upgrade but don't block it.
    WARNING = 2

    # Errors that a user must resolve before proceeding with the upgrade.
    ERROR = 3
  end
end

#message_type::Google::Cloud::Sql::V1::PreCheckResponse::MessageType

Returns The type of message whether it is an info, warning, or error.

Returns:



212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 212

class PreCheckResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of message which can be an info, a warning, or an error that
  # requires user intervention.
  module MessageType
    # Default unspecified value to prevent unintended behavior changes.
    MESSAGE_TYPE_UNSPECIFIED = 0

    # General informational messages that don't require action.
    INFO = 1

    # Warnings that might impact the upgrade but don't block it.
    WARNING = 2

    # Errors that a user must resolve before proceeding with the upgrade.
    ERROR = 3
  end
end