Class: Google::Cloud::Sql::V1::PscConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb

Overview

PSC settings for a Cloud SQL instance.

Instance Attribute Summary collapse

Instance Attribute Details

#allowed_consumer_projects::Array<::String>

Returns Optional. The list of consumer projects that are allow-listed for PSC connections to this instance. This instance can be connected to with PSC from any network in these projects.

Each consumer project in this list may be represented by a project number (numeric) or by a project id (alphanumeric).

Returns:

  • (::Array<::String>)

    Optional. The list of consumer projects that are allow-listed for PSC connections to this instance. This instance can be connected to with PSC from any network in these projects.

    Each consumer project in this list may be represented by a project number (numeric) or by a project id (alphanumeric).



986
987
988
989
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 986

class PscConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#network_attachment_uri::String

Returns Optional. The network attachment of the consumer network that the Private Service Connect enabled Cloud SQL instance is authorized to connect via PSC interface. format: projects/PROJECT/regions/REGION/networkAttachments/ID.

Returns:

  • (::String)

    Optional. The network attachment of the consumer network that the Private Service Connect enabled Cloud SQL instance is authorized to connect via PSC interface. format: projects/PROJECT/regions/REGION/networkAttachments/ID



986
987
988
989
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 986

class PscConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#psc_auto_connection_policy_enabled::Boolean

Returns Optional. Whether to set up the PSC service connection policy automatically.

Returns:

  • (::Boolean)

    Optional. Whether to set up the PSC service connection policy automatically.



986
987
988
989
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 986

class PscConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#psc_auto_connections::Array<::Google::Cloud::Sql::V1::PscAutoConnectionConfig>

Returns Optional. The list of settings for requested Private Service Connect consumer endpoints that can be used to connect to this Cloud SQL instance.

Returns:



986
987
988
989
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 986

class PscConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#psc_auto_dns_enabled::Boolean

Returns Optional. Indicates whether Private Service Connect DNS automation is enabled for this instance. When enabled, Cloud SQL provisions a universal DNS record across all networks configured with Private Service Connect auto-connections. This will default to true for new instances when Private Service Connect is enabled.

Returns:

  • (::Boolean)

    Optional. Indicates whether Private Service Connect DNS automation is enabled for this instance. When enabled, Cloud SQL provisions a universal DNS record across all networks configured with Private Service Connect auto-connections. This will default to true for new instances when Private Service Connect is enabled.



986
987
988
989
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 986

class PscConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#psc_enabled::Boolean

Returns Whether PSC connectivity is enabled for this instance.

Returns:

  • (::Boolean)

    Whether PSC connectivity is enabled for this instance.



986
987
988
989
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 986

class PscConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#psc_write_endpoint_dns_enabled::Boolean

Returns Optional. Indicates whether Private Service Connect write endpoint DNS automation is enabled for this instance. When enabled, Cloud SQL provisions a universal global DNS record across all networks configured with Private Service Connect auto-connections that points to the cluster primary instance. This feature is only supported for Enterprise Plus edition. This will default to true for new Enterprise Plus instances when psc_auto_dns_enabled is enabled.

Returns:

  • (::Boolean)

    Optional. Indicates whether Private Service Connect write endpoint DNS automation is enabled for this instance. When enabled, Cloud SQL provisions a universal global DNS record across all networks configured with Private Service Connect auto-connections that points to the cluster primary instance. This feature is only supported for Enterprise Plus edition. This will default to true for new Enterprise Plus instances when psc_auto_dns_enabled is enabled.



986
987
988
989
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 986

class PscConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end