Class: Google::Cloud::Sql::V1::ReadPoolAutoScaleConfig::TargetMetric

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb

Overview

Target metric for read pool auto scaling.

Instance Attribute Summary collapse

Instance Attribute Details

#metric::String

Returns The metric name to be used for auto scaling.

Returns:

  • (::String)

    The metric name to be used for auto scaling.



2054
2055
2056
2057
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2054

class TargetMetric
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#target_value::Float

Returns The target value for the metric.

Returns:

  • (::Float)

    The target value for the metric.



2054
2055
2056
2057
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2054

class TargetMetric
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end