Class: Google::Cloud::Sql::V1::ReplicationCluster

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb

Overview

A primary instance and disaster recovery (DR) replica pair. A DR replica is a cross-region replica that you designate for failover in the event that the primary instance experiences regional failure. Applicable to MySQL and PostgreSQL.

Instance Attribute Summary collapse

Instance Attribute Details

#dr_replica::Boolean (readonly)

Returns Output only. Read-only field that indicates whether the replica is a DR replica. This field is not set if the instance is a primary instance.

Returns:

  • (::Boolean)

    Output only. Read-only field that indicates whether the replica is a DR replica. This field is not set if the instance is a primary instance.



1550
1551
1552
1553
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1550

class ReplicationCluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#failover_dr_replica_name::String

Returns Optional. If the instance is a primary instance, then this field identifies the disaster recovery (DR) replica. A DR replica is an optional configuration for Enterprise Plus edition instances. If the instance is a read replica, then the field is not set. Set this field to a replica name to designate a DR replica for a primary instance. Remove the replica name to remove the DR replica designation.

Returns:

  • (::String)

    Optional. If the instance is a primary instance, then this field identifies the disaster recovery (DR) replica. A DR replica is an optional configuration for Enterprise Plus edition instances. If the instance is a read replica, then the field is not set. Set this field to a replica name to designate a DR replica for a primary instance. Remove the replica name to remove the DR replica designation.



1550
1551
1552
1553
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1550

class ReplicationCluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#psa_write_endpoint::String (readonly)

Returns Output only. If set, this field indicates this instance has a private service access (PSA) DNS endpoint that is pointing to the primary instance of the cluster. If this instance is the primary, then the DNS endpoint points to this instance. After a switchover or replica failover operation, this DNS endpoint points to the promoted instance. This is a read-only field, returned to the user as information. This field can exist even if a standalone instance doesn't have a DR replica yet or the DR replica is deleted.

Returns:

  • (::String)

    Output only. If set, this field indicates this instance has a private service access (PSA) DNS endpoint that is pointing to the primary instance of the cluster. If this instance is the primary, then the DNS endpoint points to this instance. After a switchover or replica failover operation, this DNS endpoint points to the promoted instance. This is a read-only field, returned to the user as information. This field can exist even if a standalone instance doesn't have a DR replica yet or the DR replica is deleted.



1550
1551
1552
1553
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1550

class ReplicationCluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end