Class: Google::Cloud::Sql::V1::RotateServerCaContext

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb

Overview

Instance rotate server CA context.

Instance Attribute Summary collapse

Instance Attribute Details

#kind::String

Returns This is always sql#rotateServerCaContext.

Returns:

  • (::String)

    This is always sql#rotateServerCaContext.



1691
1692
1693
1694
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1691

class RotateServerCaContext
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_version::String

Returns The fingerprint of the next version to be rotated to. If left unspecified, will be rotated to the most recently added server CA version.

Returns:

  • (::String)

    The fingerprint of the next version to be rotated to. If left unspecified, will be rotated to the most recently added server CA version.



1691
1692
1693
1694
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1691

class RotateServerCaContext
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end