Class: Google::Cloud::Sql::V1::RotateServerCertificateContext

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb

Overview

Instance rotate server certificate context.

Instance Attribute Summary collapse

Instance Attribute Details

#kind::String

Returns Optional. This is always sql#rotateServerCertificateContext.

Returns:

  • (::String)

    Optional. This is always sql#rotateServerCertificateContext.



1704
1705
1706
1707
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1704

class RotateServerCertificateContext
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_version::String

Returns The fingerprint of the next version to be rotated to. If left unspecified, will be rotated to the most recently added server certificate version.

Returns:

  • (::String)

    The fingerprint of the next version to be rotated to. If left unspecified, will be rotated to the most recently added server certificate version.



1704
1705
1706
1707
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1704

class RotateServerCertificateContext
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end