Class: Google::Cloud::Sql::V1::SqlActiveDirectoryConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb

Overview

Active Directory configuration, relevant only for Cloud SQL for SQL Server.

Defined Under Namespace

Modules: ActiveDirectoryMode

Instance Attribute Summary collapse

Instance Attribute Details

#admin_credential_secret_name::String

Returns Optional. The secret manager key storing the administrator credential. (e.g., projects/{project}/secrets/{secret}).

Returns:

  • (::String)

    Optional. The secret manager key storing the administrator credential. (e.g., projects/{project}/secrets/{secret}).



2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
2159
2160
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2141

class SqlActiveDirectoryConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The modes of Active Directory configuration.
  module ActiveDirectoryMode
    # Unspecified mode. Will default to MANAGED_ACTIVE_DIRECTORY if the mode is
    # not specified to maintain backward compatibility.
    ACTIVE_DIRECTORY_MODE_UNSPECIFIED = 0

    # Managed Active Directory mode.
    MANAGED_ACTIVE_DIRECTORY = 1

    # Deprecated: Use CUSTOMER_MANAGED_ACTIVE_DIRECTORY instead.
    SELF_MANAGED_ACTIVE_DIRECTORY = 2

    # Customer-managed Active Directory mode.
    CUSTOMER_MANAGED_ACTIVE_DIRECTORY = 3
  end
end

#dns_servers::Array<::String>

Returns Optional. Domain controller IPv4 addresses used to bootstrap Active Directory.

Returns:

  • (::Array<::String>)

    Optional. Domain controller IPv4 addresses used to bootstrap Active Directory.



2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
2159
2160
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2141

class SqlActiveDirectoryConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The modes of Active Directory configuration.
  module ActiveDirectoryMode
    # Unspecified mode. Will default to MANAGED_ACTIVE_DIRECTORY if the mode is
    # not specified to maintain backward compatibility.
    ACTIVE_DIRECTORY_MODE_UNSPECIFIED = 0

    # Managed Active Directory mode.
    MANAGED_ACTIVE_DIRECTORY = 1

    # Deprecated: Use CUSTOMER_MANAGED_ACTIVE_DIRECTORY instead.
    SELF_MANAGED_ACTIVE_DIRECTORY = 2

    # Customer-managed Active Directory mode.
    CUSTOMER_MANAGED_ACTIVE_DIRECTORY = 3
  end
end

#domain::String

Returns The name of the domain (e.g., mydomain.com).

Returns:

  • (::String)

    The name of the domain (e.g., mydomain.com).



2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
2159
2160
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2141

class SqlActiveDirectoryConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The modes of Active Directory configuration.
  module ActiveDirectoryMode
    # Unspecified mode. Will default to MANAGED_ACTIVE_DIRECTORY if the mode is
    # not specified to maintain backward compatibility.
    ACTIVE_DIRECTORY_MODE_UNSPECIFIED = 0

    # Managed Active Directory mode.
    MANAGED_ACTIVE_DIRECTORY = 1

    # Deprecated: Use CUSTOMER_MANAGED_ACTIVE_DIRECTORY instead.
    SELF_MANAGED_ACTIVE_DIRECTORY = 2

    # Customer-managed Active Directory mode.
    CUSTOMER_MANAGED_ACTIVE_DIRECTORY = 3
  end
end

#kind::String

Returns This is always sql#activeDirectoryConfig.

Returns:

  • (::String)

    This is always sql#activeDirectoryConfig.



2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
2159
2160
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2141

class SqlActiveDirectoryConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The modes of Active Directory configuration.
  module ActiveDirectoryMode
    # Unspecified mode. Will default to MANAGED_ACTIVE_DIRECTORY if the mode is
    # not specified to maintain backward compatibility.
    ACTIVE_DIRECTORY_MODE_UNSPECIFIED = 0

    # Managed Active Directory mode.
    MANAGED_ACTIVE_DIRECTORY = 1

    # Deprecated: Use CUSTOMER_MANAGED_ACTIVE_DIRECTORY instead.
    SELF_MANAGED_ACTIVE_DIRECTORY = 2

    # Customer-managed Active Directory mode.
    CUSTOMER_MANAGED_ACTIVE_DIRECTORY = 3
  end
end

#mode::Google::Cloud::Sql::V1::SqlActiveDirectoryConfig::ActiveDirectoryMode

Returns Optional. The mode of the Active Directory configuration.

Returns:



2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
2159
2160
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2141

class SqlActiveDirectoryConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The modes of Active Directory configuration.
  module ActiveDirectoryMode
    # Unspecified mode. Will default to MANAGED_ACTIVE_DIRECTORY if the mode is
    # not specified to maintain backward compatibility.
    ACTIVE_DIRECTORY_MODE_UNSPECIFIED = 0

    # Managed Active Directory mode.
    MANAGED_ACTIVE_DIRECTORY = 1

    # Deprecated: Use CUSTOMER_MANAGED_ACTIVE_DIRECTORY instead.
    SELF_MANAGED_ACTIVE_DIRECTORY = 2

    # Customer-managed Active Directory mode.
    CUSTOMER_MANAGED_ACTIVE_DIRECTORY = 3
  end
end

#organizational_unit::String

Returns Optional. The organizational unit distinguished name. This is the full hierarchical path to the organizational unit.

Returns:

  • (::String)

    Optional. The organizational unit distinguished name. This is the full hierarchical path to the organizational unit.



2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
2159
2160
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2141

class SqlActiveDirectoryConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The modes of Active Directory configuration.
  module ActiveDirectoryMode
    # Unspecified mode. Will default to MANAGED_ACTIVE_DIRECTORY if the mode is
    # not specified to maintain backward compatibility.
    ACTIVE_DIRECTORY_MODE_UNSPECIFIED = 0

    # Managed Active Directory mode.
    MANAGED_ACTIVE_DIRECTORY = 1

    # Deprecated: Use CUSTOMER_MANAGED_ACTIVE_DIRECTORY instead.
    SELF_MANAGED_ACTIVE_DIRECTORY = 2

    # Customer-managed Active Directory mode.
    CUSTOMER_MANAGED_ACTIVE_DIRECTORY = 3
  end
end