Class: Google::Cloud::Sql::V1::SqlBackupRunsListRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_backup_runs.rb

Overview

Backup runs list request.

Instance Attribute Summary collapse

Instance Attribute Details

#instance::String

Returns Cloud SQL instance ID, or "-" for all instances. This does not include the project ID.

Returns:

  • (::String)

    Cloud SQL instance ID, or "-" for all instances. This does not include the project ID.



85
86
87
88
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backup_runs.rb', line 85

class SqlBackupRunsListRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#max_results::Integer

Returns Maximum number of backup runs per response.

Returns:

  • (::Integer)

    Maximum number of backup runs per response.



85
86
87
88
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backup_runs.rb', line 85

class SqlBackupRunsListRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns A previously-returned page token representing part of the larger set of results to view.

Returns:

  • (::String)

    A previously-returned page token representing part of the larger set of results to view.



85
86
87
88
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backup_runs.rb', line 85

class SqlBackupRunsListRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#project::String

Returns Project ID of the project that contains the instance.

Returns:

  • (::String)

    Project ID of the project that contains the instance.



85
86
87
88
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backup_runs.rb', line 85

class SqlBackupRunsListRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end