Module: Google::Cloud::Sql::V1::SqlDataDiskType

Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb

Overview

The type of disk that is used for a v2 instance to use.

Constant Summary collapse

SQL_DATA_DISK_TYPE_UNSPECIFIED =

This is an unknown data disk type.

0
PD_SSD =

An SSD data disk.

1
PD_HDD =

An HDD data disk.

2
OBSOLETE_LOCAL_SSD =

This field is deprecated and will be removed from a future version of the API.

3
HYPERDISK_BALANCED =

A Hyperdisk Balanced data disk.

4