Class: Google::Cloud::Sql::V1::SqlDatabasesUpdateRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::SqlDatabasesUpdateRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_databases.rb
Overview
Database update request.
Instance Attribute Summary collapse
- #body ⇒ ::Google::Cloud::Sql::V1::Database
-
#database ⇒ ::String
Name of the database to be updated in the instance.
-
#instance ⇒ ::String
Database instance ID.
-
#project ⇒ ::String
Project ID of the project that contains the instance.
Instance Attribute Details
#body ⇒ ::Google::Cloud::Sql::V1::Database
92 93 94 95 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_databases.rb', line 92 class SqlDatabasesUpdateRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#database ⇒ ::String
Returns Name of the database to be updated in the instance.
92 93 94 95 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_databases.rb', line 92 class SqlDatabasesUpdateRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#instance ⇒ ::String
Returns Database instance ID. This does not include the project ID.
92 93 94 95 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_databases.rb', line 92 class SqlDatabasesUpdateRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#project ⇒ ::String
Returns Project ID of the project that contains the instance.
92 93 94 95 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_databases.rb', line 92 class SqlDatabasesUpdateRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |