Class: Google::Cloud::Sql::V1::SqlInstancesAcquireSsrsLeaseRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb

Overview

Request to acquire a lease for SSRS.

Instance Attribute Summary collapse

Instance Attribute Details

#body::Google::Cloud::Sql::V1::InstancesAcquireSsrsLeaseRequest

Returns Required. The request body.

Returns:



2244
2245
2246
2247
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 2244

class SqlInstancesAcquireSsrsLeaseRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#instance::String

Returns Required. Cloud SQL instance ID. This doesn't include the project ID. It's composed of lowercase letters, numbers, and hyphens, and it must start with a letter. The total length must be 98 characters or less (Example: instance-id).

Returns:

  • (::String)

    Required. Cloud SQL instance ID. This doesn't include the project ID. It's composed of lowercase letters, numbers, and hyphens, and it must start with a letter. The total length must be 98 characters or less (Example: instance-id).



2244
2245
2246
2247
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 2244

class SqlInstancesAcquireSsrsLeaseRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#project::String

Returns Required. Project ID of the project that contains the instance (Example: project-id).

Returns:

  • (::String)

    Required. Project ID of the project that contains the instance (Example: project-id).



2244
2245
2246
2247
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 2244

class SqlInstancesAcquireSsrsLeaseRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end