Class: Google::Cloud::Sql::V1::SqlInstancesExecuteSqlResponse::Message

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb

Overview

Represents a notice or warning message from the database.

Instance Attribute Summary collapse

Instance Attribute Details

#message::String

Returns The full message string. For PostgreSQL, this is a formatted string that may include severity, code, and the notice/warning message. For MySQL, this contains the warning message.

Returns:

  • (::String)

    The full message string. For PostgreSQL, this is a formatted string that may include severity, code, and the notice/warning message. For MySQL, this contains the warning message.



2158
2159
2160
2161
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 2158

class Message
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#severity::String

Returns The severity of the message (e.g., "NOTICE" for PostgreSQL, "WARNING" for MySQL).

Returns:

  • (::String)

    The severity of the message (e.g., "NOTICE" for PostgreSQL, "WARNING" for MySQL).



2158
2159
2160
2161
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 2158

class Message
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end