Class: Google::Cloud::Sql::V1::SqlInstancesExportRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::SqlInstancesExportRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb
Overview
Instance export request.
Instance Attribute Summary collapse
- #body ⇒ ::Google::Cloud::Sql::V1::InstancesExportRequest
-
#instance ⇒ ::String
Cloud SQL instance ID.
-
#project ⇒ ::String
Project ID of the project that contains the instance to be exported.
Instance Attribute Details
#body ⇒ ::Google::Cloud::Sql::V1::InstancesExportRequest
142 143 144 145 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 142 class SqlInstancesExportRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#instance ⇒ ::String
Returns Cloud SQL instance ID. This does not include the project ID.
142 143 144 145 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 142 class SqlInstancesExportRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#project ⇒ ::String
Returns Project ID of the project that contains the instance to be exported.
142 143 144 145 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 142 class SqlInstancesExportRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |