Class: Google::Cloud::Sql::V1::SqlInstancesGetLatestRecoveryTimeRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb

Overview

Instance get latest recovery time request.

Instance Attribute Summary collapse

Instance Attribute Details

#instance::String

Returns Cloud SQL instance ID. This does not include the project ID.

Returns:

  • (::String)

    Cloud SQL instance ID. This does not include the project ID.



969
970
971
972
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 969

class SqlInstancesGetLatestRecoveryTimeRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#project::String

Returns Project ID of the project that contains the instance.

Returns:

  • (::String)

    Project ID of the project that contains the instance.



969
970
971
972
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 969

class SqlInstancesGetLatestRecoveryTimeRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#source_instance_deletion_time::Google::Protobuf::Timestamp

Returns The timestamp used to identify the time when the source instance is deleted. If this instance is deleted, then you must set the timestamp.

Returns:

  • (::Google::Protobuf::Timestamp)

    The timestamp used to identify the time when the source instance is deleted. If this instance is deleted, then you must set the timestamp.



969
970
971
972
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 969

class SqlInstancesGetLatestRecoveryTimeRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end