Class: Google::Cloud::Sql::V1::SqlInstancesInsertRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb

Overview

Instance insert request.

Instance Attribute Summary collapse

Instance Attribute Details

#body::Google::Cloud::Sql::V1::DatabaseInstance



194
195
196
197
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 194

class SqlInstancesInsertRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#project::String

Returns Project ID of the project to which the newly created Cloud SQL instances should belong.

Returns:

  • (::String)

    Project ID of the project to which the newly created Cloud SQL instances should belong.



194
195
196
197
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 194

class SqlInstancesInsertRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end