Class: Google::Cloud::Sql::V1::SqlInstancesListRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb

Overview

Instance list request.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns A filter expression that filters resources listed in the response. The expression is in the form of field:value. For example, 'instanceType:CLOUD_SQL_INSTANCE'. Fields can be nested as needed as per their JSON representation, such as 'settings.userLabels.auto_start:true'.

Multiple filter queries are space-separated. For example. 'state:RUNNABLE instanceType:CLOUD_SQL_INSTANCE'. By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly.

Returns:

  • (::String)

    A filter expression that filters resources listed in the response. The expression is in the form of field:value. For example, 'instanceType:CLOUD_SQL_INSTANCE'. Fields can be nested as needed as per their JSON representation, such as 'settings.userLabels.auto_start:true'.

    Multiple filter queries are space-separated. For example. 'state:RUNNABLE instanceType:CLOUD_SQL_INSTANCE'. By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly.



224
225
226
227
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 224

class SqlInstancesListRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#max_results::Integer

Returns The maximum number of instances to return. The service may return fewer than this value. If unspecified, at most 500 instances are returned. The maximum value is 1000; values above 1000 are coerced to 1000.

Returns:

  • (::Integer)

    The maximum number of instances to return. The service may return fewer than this value. If unspecified, at most 500 instances are returned. The maximum value is 1000; values above 1000 are coerced to 1000.



224
225
226
227
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 224

class SqlInstancesListRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns A previously-returned page token representing part of the larger set of results to view.

Returns:

  • (::String)

    A previously-returned page token representing part of the larger set of results to view.



224
225
226
227
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 224

class SqlInstancesListRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#project::String

Returns Project ID of the project for which to list Cloud SQL instances.

Returns:

  • (::String)

    Project ID of the project for which to list Cloud SQL instances.



224
225
226
227
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 224

class SqlInstancesListRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end