Class: Google::Cloud::Sql::V1::SqlInstancesPointInTimeRestoreRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::SqlInstancesPointInTimeRestoreRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb
Overview
Request to perform a point in time restore on a Google Cloud Backup and Disaster Recovery managed instance.
Instance Attribute Summary collapse
-
#context ⇒ ::Google::Cloud::Sql::V1::PointInTimeRestoreContext
Required.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#context ⇒ ::Google::Cloud::Sql::V1::PointInTimeRestoreContext
Returns Required. The context for request to perform a PITR on a Google Cloud Backup and Disaster Recovery managed instance.
2292 2293 2294 2295 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 2292 class SqlInstancesPointInTimeRestoreRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The parent resource where you created this instance. Format: projects/{project}.
2292 2293 2294 2295 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 2292 class SqlInstancesPointInTimeRestoreRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |