Class: Google::Cloud::Sql::V1::SqlInstancesReleaseSsrsLeaseRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb

Overview

Request to release a lease for SSRS.

Instance Attribute Summary collapse

Instance Attribute Details

#instance::String

Returns Required. The Cloud SQL instance ID. This doesn't include the project ID. The instance ID contains lowercase letters, numbers, and hyphens, and it must start with a letter. This ID can have a maximum length of 98 characters.

Returns:

  • (::String)

    Required. The Cloud SQL instance ID. This doesn't include the project ID. The instance ID contains lowercase letters, numbers, and hyphens, and it must start with a letter. This ID can have a maximum length of 98 characters.



2268
2269
2270
2271
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 2268

class SqlInstancesReleaseSsrsLeaseRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#project::String

Returns Required. The project ID that contains the instance.

Returns:

  • (::String)

    Required. The project ID that contains the instance.



2268
2269
2270
2271
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 2268

class SqlInstancesReleaseSsrsLeaseRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end