Class: Google::Cloud::Sql::V1::SqlInstancesRescheduleMaintenanceRequestBody

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb

Overview

Reschedule options for maintenance windows.

Defined Under Namespace

Modules: RescheduleType Classes: Reschedule

Instance Attribute Summary collapse

Instance Attribute Details

#reschedule::Google::Cloud::Sql::V1::SqlInstancesRescheduleMaintenanceRequestBody::Reschedule

Returns Required. The type of the reschedule the user wants.

Returns:



1575
1576
1577
1578
1579
1580
1581
1582
1583
1584
1585
1586
1587
1588
1589
1590
1591
1592
1593
1594
1595
1596
1597
1598
1599
1600
1601
1602
1603
1604
1605
1606
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1575

class SqlInstancesRescheduleMaintenanceRequestBody
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] reschedule_type
  #   @return [::Google::Cloud::Sql::V1::SqlInstancesRescheduleMaintenanceRequestBody::RescheduleType]
  #     Required. The type of the reschedule.
  # @!attribute [rw] schedule_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. Timestamp when the maintenance shall be rescheduled to if
  #     reschedule_type=SPECIFIC_TIME, in
  #     [RFC 3339](https://tools.ietf.org/html/rfc3339) format, for example
  #     `2012-11-15T16:19:00.094Z`.
  class Reschedule
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  module RescheduleType
    RESCHEDULE_TYPE_UNSPECIFIED = 0

    # Reschedules maintenance to happen now (within 5 minutes).
    IMMEDIATE = 1

    # Reschedules maintenance to occur within one week from the originally
    # scheduled day and time.
    NEXT_AVAILABLE_WINDOW = 2

    # Reschedules maintenance to a specific time and day.
    SPECIFIC_TIME = 3
  end
end