Class: Google::Cloud::Sql::V1::SqlInstancesResetReplicaSizeRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::SqlInstancesResetReplicaSizeRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb
Overview
Instance reset replica size request.
Instance Attribute Summary collapse
-
#instance ⇒ ::String
Cloud SQL read replica instance name.
-
#project ⇒ ::String
ID of the project that contains the read replica.
Instance Attribute Details
#instance ⇒ ::String
Returns Cloud SQL read replica instance name.
671 672 673 674 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 671 class SqlInstancesResetReplicaSizeRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#project ⇒ ::String
Returns ID of the project that contains the read replica.
671 672 673 674 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 671 class SqlInstancesResetReplicaSizeRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |