Class: Google::Cloud::Sql::V1::SqlInstancesRestartRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::SqlInstancesRestartRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb
Overview
Instance restart request.
Instance Attribute Summary collapse
-
#instance ⇒ ::String
Cloud SQL instance ID.
-
#project ⇒ ::String
Project ID of the project that contains the instance to be restarted.
Instance Attribute Details
#instance ⇒ ::String
Returns Cloud SQL instance ID. This does not include the project ID.
352 353 354 355 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 352 class SqlInstancesRestartRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#project ⇒ ::String
Returns Project ID of the project that contains the instance to be restarted.
352 353 354 355 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 352 class SqlInstancesRestartRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |