Class: Google::Cloud::Sql::V1::SqlInstancesStartExternalSyncRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb

Overview

Instance start external sync request.

Instance Attribute Summary collapse

Instance Attribute Details

#instance::String

Returns Cloud SQL instance ID. This does not include the project ID.

Returns:

  • (::String)

    Cloud SQL instance ID. This does not include the project ID.



667
668
669
670
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 667

class SqlInstancesStartExternalSyncRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#migration_type::Google::Cloud::Sql::V1::SqlInstancesVerifyExternalSyncSettingsRequest::MigrationType

Returns Optional. MigrationType configures the migration to use physical files or logical dump files. If not set, then the logical dump file configuration is used. Valid values are LOGICAL or PHYSICAL. Only applicable to MySQL.

Returns:



667
668
669
670
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 667

class SqlInstancesStartExternalSyncRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#mysql_sync_config::Google::Cloud::Sql::V1::MySqlSyncConfig

Returns MySQL-specific settings for start external sync.

Returns:



667
668
669
670
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 667

class SqlInstancesStartExternalSyncRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#project::String

Returns ID of the project that contains the instance.

Returns:

  • (::String)

    ID of the project that contains the instance.



667
668
669
670
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 667

class SqlInstancesStartExternalSyncRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#replica_overwrite_enabled::Boolean

Returns Optional. MySQL only. True if end-user has confirmed that this SES call will wipe replica databases overlapping with the proposed selected_objects. If this field is not set and there are both overlapping and additional databases proposed, an error will be returned.

Returns:

  • (::Boolean)

    Optional. MySQL only. True if end-user has confirmed that this SES call will wipe replica databases overlapping with the proposed selected_objects. If this field is not set and there are both overlapping and additional databases proposed, an error will be returned.



667
668
669
670
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 667

class SqlInstancesStartExternalSyncRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#skip_verification::Boolean

Returns Whether to skip the verification step (VESS).

Returns:

  • (::Boolean)

    Whether to skip the verification step (VESS).



667
668
669
670
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 667

class SqlInstancesStartExternalSyncRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#sync_mode::Google::Cloud::Sql::V1::SqlInstancesVerifyExternalSyncSettingsRequest::ExternalSyncMode

Returns External sync mode.



667
668
669
670
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 667

class SqlInstancesStartExternalSyncRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#sync_parallel_level::Google::Cloud::Sql::V1::ExternalSyncParallelLevel

Returns Optional. Parallel level for initial data sync. Currently only applicable for MySQL.

Returns:



667
668
669
670
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 667

class SqlInstancesStartExternalSyncRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end