Class: Google::Cloud::Sql::V1::SqlInstancesStartReplicaRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::SqlInstancesStartReplicaRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb
Overview
Instance start replica request.
Instance Attribute Summary collapse
-
#instance ⇒ ::String
Cloud SQL read replica instance name.
-
#project ⇒ ::String
ID of the project that contains the read replica.
Instance Attribute Details
#instance ⇒ ::String
Returns Cloud SQL read replica instance name.
422 423 424 425 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 422 class SqlInstancesStartReplicaRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#project ⇒ ::String
Returns ID of the project that contains the read replica.
422 423 424 425 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 422 class SqlInstancesStartReplicaRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |