Class: Google::Cloud::Sql::V1::SqlInstancesSwitchoverRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb

Overview

Instance switchover request.

Instance Attribute Summary collapse

Instance Attribute Details

#db_timeout::Google::Protobuf::Duration

Returns Optional. (MySQL and PostgreSQL only) Cloud SQL instance operations timeout, which is a sum of all database operations. Default value is 10 minutes and can be modified to a maximum value of 24 hours.

Returns:

  • (::Google::Protobuf::Duration)

    Optional. (MySQL and PostgreSQL only) Cloud SQL instance operations timeout, which is a sum of all database operations. Default value is 10 minutes and can be modified to a maximum value of 24 hours.



311
312
313
314
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 311

class SqlInstancesSwitchoverRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#instance::String

Returns Cloud SQL read replica instance name.

Returns:

  • (::String)

    Cloud SQL read replica instance name.



311
312
313
314
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 311

class SqlInstancesSwitchoverRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#project::String

Returns ID of the project that contains the replica.

Returns:

  • (::String)

    ID of the project that contains the replica.



311
312
313
314
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 311

class SqlInstancesSwitchoverRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end