Module: Google::Cloud::Sql::V1::SqlMaintenanceType

Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb

Overview

The type of maintenance to be performed on the instance.

Constant Summary collapse

SQL_MAINTENANCE_TYPE_UNSPECIFIED =

Maintenance type is unspecified.

0
INSTANCE_MAINTENANCE =

Indicates that a standalone instance is undergoing maintenance. The instance can be either a primary instance or a replica.

1
REPLICA_INCLUDED_MAINTENANCE =

Indicates that the primary instance and all of its replicas, including cascading replicas, are undergoing maintenance. Maintenance is performed on groups of replicas first, followed by the primary instance.

2
INSTANCE_SELF_SERVICE_MAINTENANCE =

Indicates that the standalone instance is undergoing maintenance, initiated by self-service. The instance can be either a primary instance or a replica.

3
REPLICA_INCLUDED_SELF_SERVICE_MAINTENANCE =

Indicates that the primary instance and all of its replicas are undergoing maintenance, initiated by self-service. Maintenance is performed on groups of replicas first, followed by the primary instance.

4