Class: Google::Cloud::Sql::V1::SqlSubOperationType

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb

Overview

The sub operation type based on the operation type.

Instance Attribute Summary collapse

Instance Attribute Details

#maintenance_type::Google::Cloud::Sql::V1::SqlMaintenanceType

Returns The type of maintenance to be performed on the instance.

Returns:



1212
1213
1214
1215
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1212

class SqlSubOperationType
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end