Module: Google::Cloud::Sql::V1::SqlSuspensionReason

Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb

Overview

The suspension reason of the database instance if the state is SUSPENDED.

Constant Summary collapse

SQL_SUSPENSION_REASON_UNSPECIFIED =

This is an unknown suspension reason.

0
BILLING_ISSUE =

The instance is suspended due to billing issues (for example:, account issue)

2
3
OPERATIONAL_ISSUE =

The instance is causing operational issues (for example:, causing the database to crash).

4
KMS_KEY_ISSUE =

The KMS key used by the instance is either revoked or denied access to

5
PROJECT_ABUSE =

The project is suspended due to abuse detected by Ares.

8