Class: Google::Cloud::Sql::V1::SslCert

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb

Overview

SslCerts Resource

Instance Attribute Summary collapse

Instance Attribute Details

#cert::String

Returns PEM representation.

Returns:

  • (::String)

    PEM representation.



2007
2008
2009
2010
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2007

class SslCert
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#cert_serial_number::String

Returns Serial number, as extracted from the certificate.

Returns:

  • (::String)

    Serial number, as extracted from the certificate.



2007
2008
2009
2010
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2007

class SslCert
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#common_name::String

Returns User supplied name. Constrained to [a-zA-Z.-_ ]+.

Returns:

  • (::String)

    User supplied name. Constrained to [a-zA-Z.-_ ]+.



2007
2008
2009
2010
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2007

class SslCert
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#create_time::Google::Protobuf::Timestamp

Returns The time when the certificate was created in RFC 3339 format, for example 2012-11-15T16:19:00.094Z.

Returns:



2007
2008
2009
2010
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2007

class SslCert
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#expiration_time::Google::Protobuf::Timestamp

Returns The time when the certificate expires in RFC 3339 format, for example 2012-11-15T16:19:00.094Z.

Returns:



2007
2008
2009
2010
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2007

class SslCert
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#instance::String

Returns Name of the database instance.

Returns:

  • (::String)

    Name of the database instance.



2007
2008
2009
2010
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2007

class SslCert
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#kind::String

Returns This is always sql#sslCert.

Returns:

  • (::String)

    This is always sql#sslCert.



2007
2008
2009
2010
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2007

class SslCert
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

Returns The URI of this resource.

Returns:

  • (::String)

    The URI of this resource.



2007
2008
2009
2010
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2007

class SslCert
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#sha1_fingerprint::String

Returns Sha1 Fingerprint.

Returns:

  • (::String)

    Sha1 Fingerprint.



2007
2008
2009
2010
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2007

class SslCert
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end