Class: Google::Cloud::Sql::V1::SslCertDetail

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb

Overview

SslCertDetail.

Instance Attribute Summary collapse

Instance Attribute Details

#cert_info::Google::Cloud::Sql::V1::SslCert

Returns The public information about the cert.

Returns:



2020
2021
2022
2023
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2020

class SslCertDetail
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#cert_private_key::String

Returns The private key for the client cert, in pem format. Keep private in order to protect your security.

Returns:

  • (::String)

    The private key for the client cert, in pem format. Keep private in order to protect your security.



2020
2021
2022
2023
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2020

class SslCertDetail
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end