Class: Google::Cloud::Sql::V1::SslCertsInsertRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_ssl_certs.rb

Overview

SslCerts insert request.

Instance Attribute Summary collapse

Instance Attribute Details

#common_name::String

Returns User supplied name. Must be a distinct name from the other certificates for this instance.

Returns:

  • (::String)

    User supplied name. Must be a distinct name from the other certificates for this instance.



81
82
83
84
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_ssl_certs.rb', line 81

class SslCertsInsertRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end