Class: Google::Cloud::Sql::V1::SyncFlags

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb

Overview

Initial sync flags for certain Cloud SQL APIs. Currently used for the MySQL external server initial dump.

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns The name of the flag.

Returns:

  • (::String)

    The name of the flag.



343
344
345
346
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 343

class SyncFlags
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#value::String

Returns The value of the flag. This field must be omitted if the flag doesn't take a value.

Returns:

  • (::String)

    The value of the flag. This field must be omitted if the flag doesn't take a value.



343
344
345
346
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 343

class SyncFlags
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end