Class: Google::Cloud::Sql::V1::UpdateBackupRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_backups.rb

Overview

The request payload to update the backup.

Instance Attribute Summary collapse

Instance Attribute Details

#backup::Google::Cloud::Sql::V1::Backup

Returns Required. The backup to update. The backup’s name field is used to identify the backup to update. Format: projects/{project}/backups/{backup}.

Returns:

  • (::Google::Cloud::Sql::V1::Backup)

    Required. The backup to update. The backup’s name field is used to identify the backup to update. Format: projects/{project}/backups/{backup}



104
105
106
107
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backups.rb', line 104

class UpdateBackupRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_mask::Google::Protobuf::FieldMask

Returns The list of fields that you can update. You can update only the description and retention period of the final backup.

Returns:

  • (::Google::Protobuf::FieldMask)

    The list of fields that you can update. You can update only the description and retention period of the final backup.



104
105
106
107
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backups.rb', line 104

class UpdateBackupRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end