Class: Google::Cloud::Sql::V1::User

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_users.rb

Overview

A Cloud SQL user resource.

Defined Under Namespace

Modules: DualPasswordType, IamStatus, SqlUserType

Instance Attribute Summary collapse

Instance Attribute Details

#database_roles::Array<::String>

Returns Optional. Role memberships of the user.

Returns:

  • (::Array<::String>)

    Optional. Role memberships of the user



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_users.rb', line 199

class User
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The user type.
  module SqlUserType
    # The database's built-in user type.
    BUILT_IN = 0

    # Cloud IAM user.
    CLOUD_IAM_USER = 1

    # Cloud IAM service account.
    CLOUD_IAM_SERVICE_ACCOUNT = 2

    # Cloud IAM group. Not used for login.
    CLOUD_IAM_GROUP = 3

    # Read-only. Login for a user that belongs to the Cloud IAM group.
    CLOUD_IAM_GROUP_USER = 4

    # Read-only. Login for a service account that belongs to the
    # Cloud IAM group.
    CLOUD_IAM_GROUP_SERVICE_ACCOUNT = 5

    # Microsoft Entra ID user.
    ENTRAID_USER = 7
  end

  # The type of retained password.
  module DualPasswordType
    # The default value.
    DUAL_PASSWORD_TYPE_UNSPECIFIED = 0

    # Do not update the user's dual password status.
    NO_MODIFY_DUAL_PASSWORD = 1

    # No dual password usable for connecting using this user.
    NO_DUAL_PASSWORD = 2

    # Dual password usable for connecting using this user.
    DUAL_PASSWORD = 3
  end

  # Indicates if a group is available for IAM database authentication.
  module IamStatus
    # The default value for users that are not of type CLOUD_IAM_GROUP.
    # Only CLOUD_IAM_GROUP users will be inactive or active.
    # Users with an IamStatus of IAM_STATUS_UNSPECIFIED will not
    # display whether they are active or inactive as that is not applicable to
    # them.
    IAM_STATUS_UNSPECIFIED = 0

    # INACTIVE indicates a group is not available for IAM database
    # authentication.
    INACTIVE = 1

    # ACTIVE indicates a group is available for IAM database authentication.
    ACTIVE = 2
  end
end

#dual_password_type::Google::Cloud::Sql::V1::User::DualPasswordType

Returns Dual password status for the user.

Returns:



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_users.rb', line 199

class User
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The user type.
  module SqlUserType
    # The database's built-in user type.
    BUILT_IN = 0

    # Cloud IAM user.
    CLOUD_IAM_USER = 1

    # Cloud IAM service account.
    CLOUD_IAM_SERVICE_ACCOUNT = 2

    # Cloud IAM group. Not used for login.
    CLOUD_IAM_GROUP = 3

    # Read-only. Login for a user that belongs to the Cloud IAM group.
    CLOUD_IAM_GROUP_USER = 4

    # Read-only. Login for a service account that belongs to the
    # Cloud IAM group.
    CLOUD_IAM_GROUP_SERVICE_ACCOUNT = 5

    # Microsoft Entra ID user.
    ENTRAID_USER = 7
  end

  # The type of retained password.
  module DualPasswordType
    # The default value.
    DUAL_PASSWORD_TYPE_UNSPECIFIED = 0

    # Do not update the user's dual password status.
    NO_MODIFY_DUAL_PASSWORD = 1

    # No dual password usable for connecting using this user.
    NO_DUAL_PASSWORD = 2

    # Dual password usable for connecting using this user.
    DUAL_PASSWORD = 3
  end

  # Indicates if a group is available for IAM database authentication.
  module IamStatus
    # The default value for users that are not of type CLOUD_IAM_GROUP.
    # Only CLOUD_IAM_GROUP users will be inactive or active.
    # Users with an IamStatus of IAM_STATUS_UNSPECIFIED will not
    # display whether they are active or inactive as that is not applicable to
    # them.
    IAM_STATUS_UNSPECIFIED = 0

    # INACTIVE indicates a group is not available for IAM database
    # authentication.
    INACTIVE = 1

    # ACTIVE indicates a group is available for IAM database authentication.
    ACTIVE = 2
  end
end

#etag::String

Returns This field is deprecated and will be removed from a future version of the API.

Returns:

  • (::String)

    This field is deprecated and will be removed from a future version of the API.



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_users.rb', line 199

class User
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The user type.
  module SqlUserType
    # The database's built-in user type.
    BUILT_IN = 0

    # Cloud IAM user.
    CLOUD_IAM_USER = 1

    # Cloud IAM service account.
    CLOUD_IAM_SERVICE_ACCOUNT = 2

    # Cloud IAM group. Not used for login.
    CLOUD_IAM_GROUP = 3

    # Read-only. Login for a user that belongs to the Cloud IAM group.
    CLOUD_IAM_GROUP_USER = 4

    # Read-only. Login for a service account that belongs to the
    # Cloud IAM group.
    CLOUD_IAM_GROUP_SERVICE_ACCOUNT = 5

    # Microsoft Entra ID user.
    ENTRAID_USER = 7
  end

  # The type of retained password.
  module DualPasswordType
    # The default value.
    DUAL_PASSWORD_TYPE_UNSPECIFIED = 0

    # Do not update the user's dual password status.
    NO_MODIFY_DUAL_PASSWORD = 1

    # No dual password usable for connecting using this user.
    NO_DUAL_PASSWORD = 2

    # Dual password usable for connecting using this user.
    DUAL_PASSWORD = 3
  end

  # Indicates if a group is available for IAM database authentication.
  module IamStatus
    # The default value for users that are not of type CLOUD_IAM_GROUP.
    # Only CLOUD_IAM_GROUP users will be inactive or active.
    # Users with an IamStatus of IAM_STATUS_UNSPECIFIED will not
    # display whether they are active or inactive as that is not applicable to
    # them.
    IAM_STATUS_UNSPECIFIED = 0

    # INACTIVE indicates a group is not available for IAM database
    # authentication.
    INACTIVE = 1

    # ACTIVE indicates a group is available for IAM database authentication.
    ACTIVE = 2
  end
end

#host::String

Returns Optional. The host from which the user can connect. For insert operations, host defaults to an empty string. For update operations, host is specified as part of the request URL. The host name cannot be updated after insertion. For a MySQL instance, it's required; for a PostgreSQL or SQL Server instance, it's optional.

Returns:

  • (::String)

    Optional. The host from which the user can connect. For insert operations, host defaults to an empty string. For update operations, host is specified as part of the request URL. The host name cannot be updated after insertion. For a MySQL instance, it's required; for a PostgreSQL or SQL Server instance, it's optional.



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_users.rb', line 199

class User
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The user type.
  module SqlUserType
    # The database's built-in user type.
    BUILT_IN = 0

    # Cloud IAM user.
    CLOUD_IAM_USER = 1

    # Cloud IAM service account.
    CLOUD_IAM_SERVICE_ACCOUNT = 2

    # Cloud IAM group. Not used for login.
    CLOUD_IAM_GROUP = 3

    # Read-only. Login for a user that belongs to the Cloud IAM group.
    CLOUD_IAM_GROUP_USER = 4

    # Read-only. Login for a service account that belongs to the
    # Cloud IAM group.
    CLOUD_IAM_GROUP_SERVICE_ACCOUNT = 5

    # Microsoft Entra ID user.
    ENTRAID_USER = 7
  end

  # The type of retained password.
  module DualPasswordType
    # The default value.
    DUAL_PASSWORD_TYPE_UNSPECIFIED = 0

    # Do not update the user's dual password status.
    NO_MODIFY_DUAL_PASSWORD = 1

    # No dual password usable for connecting using this user.
    NO_DUAL_PASSWORD = 2

    # Dual password usable for connecting using this user.
    DUAL_PASSWORD = 3
  end

  # Indicates if a group is available for IAM database authentication.
  module IamStatus
    # The default value for users that are not of type CLOUD_IAM_GROUP.
    # Only CLOUD_IAM_GROUP users will be inactive or active.
    # Users with an IamStatus of IAM_STATUS_UNSPECIFIED will not
    # display whether they are active or inactive as that is not applicable to
    # them.
    IAM_STATUS_UNSPECIFIED = 0

    # INACTIVE indicates a group is not available for IAM database
    # authentication.
    INACTIVE = 1

    # ACTIVE indicates a group is available for IAM database authentication.
    ACTIVE = 2
  end
end

#iam_email::String

Returns Optional. The full email for an IAM user. For normal database users, this will not be filled. Only applicable to MySQL database users.

Returns:

  • (::String)

    Optional. The full email for an IAM user. For normal database users, this will not be filled. Only applicable to MySQL database users.



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_users.rb', line 199

class User
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The user type.
  module SqlUserType
    # The database's built-in user type.
    BUILT_IN = 0

    # Cloud IAM user.
    CLOUD_IAM_USER = 1

    # Cloud IAM service account.
    CLOUD_IAM_SERVICE_ACCOUNT = 2

    # Cloud IAM group. Not used for login.
    CLOUD_IAM_GROUP = 3

    # Read-only. Login for a user that belongs to the Cloud IAM group.
    CLOUD_IAM_GROUP_USER = 4

    # Read-only. Login for a service account that belongs to the
    # Cloud IAM group.
    CLOUD_IAM_GROUP_SERVICE_ACCOUNT = 5

    # Microsoft Entra ID user.
    ENTRAID_USER = 7
  end

  # The type of retained password.
  module DualPasswordType
    # The default value.
    DUAL_PASSWORD_TYPE_UNSPECIFIED = 0

    # Do not update the user's dual password status.
    NO_MODIFY_DUAL_PASSWORD = 1

    # No dual password usable for connecting using this user.
    NO_DUAL_PASSWORD = 2

    # Dual password usable for connecting using this user.
    DUAL_PASSWORD = 3
  end

  # Indicates if a group is available for IAM database authentication.
  module IamStatus
    # The default value for users that are not of type CLOUD_IAM_GROUP.
    # Only CLOUD_IAM_GROUP users will be inactive or active.
    # Users with an IamStatus of IAM_STATUS_UNSPECIFIED will not
    # display whether they are active or inactive as that is not applicable to
    # them.
    IAM_STATUS_UNSPECIFIED = 0

    # INACTIVE indicates a group is not available for IAM database
    # authentication.
    INACTIVE = 1

    # ACTIVE indicates a group is available for IAM database authentication.
    ACTIVE = 2
  end
end

#iam_status::Google::Cloud::Sql::V1::User::IamStatus

Returns Indicates if a group is active or inactive for IAM database authentication.

Returns:



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_users.rb', line 199

class User
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The user type.
  module SqlUserType
    # The database's built-in user type.
    BUILT_IN = 0

    # Cloud IAM user.
    CLOUD_IAM_USER = 1

    # Cloud IAM service account.
    CLOUD_IAM_SERVICE_ACCOUNT = 2

    # Cloud IAM group. Not used for login.
    CLOUD_IAM_GROUP = 3

    # Read-only. Login for a user that belongs to the Cloud IAM group.
    CLOUD_IAM_GROUP_USER = 4

    # Read-only. Login for a service account that belongs to the
    # Cloud IAM group.
    CLOUD_IAM_GROUP_SERVICE_ACCOUNT = 5

    # Microsoft Entra ID user.
    ENTRAID_USER = 7
  end

  # The type of retained password.
  module DualPasswordType
    # The default value.
    DUAL_PASSWORD_TYPE_UNSPECIFIED = 0

    # Do not update the user's dual password status.
    NO_MODIFY_DUAL_PASSWORD = 1

    # No dual password usable for connecting using this user.
    NO_DUAL_PASSWORD = 2

    # Dual password usable for connecting using this user.
    DUAL_PASSWORD = 3
  end

  # Indicates if a group is available for IAM database authentication.
  module IamStatus
    # The default value for users that are not of type CLOUD_IAM_GROUP.
    # Only CLOUD_IAM_GROUP users will be inactive or active.
    # Users with an IamStatus of IAM_STATUS_UNSPECIFIED will not
    # display whether they are active or inactive as that is not applicable to
    # them.
    IAM_STATUS_UNSPECIFIED = 0

    # INACTIVE indicates a group is not available for IAM database
    # authentication.
    INACTIVE = 1

    # ACTIVE indicates a group is available for IAM database authentication.
    ACTIVE = 2
  end
end

#instance::String

Returns The name of the Cloud SQL instance. This does not include the project ID. Can be omitted for update because it is already specified on the URL.

Returns:

  • (::String)

    The name of the Cloud SQL instance. This does not include the project ID. Can be omitted for update because it is already specified on the URL.



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_users.rb', line 199

class User
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The user type.
  module SqlUserType
    # The database's built-in user type.
    BUILT_IN = 0

    # Cloud IAM user.
    CLOUD_IAM_USER = 1

    # Cloud IAM service account.
    CLOUD_IAM_SERVICE_ACCOUNT = 2

    # Cloud IAM group. Not used for login.
    CLOUD_IAM_GROUP = 3

    # Read-only. Login for a user that belongs to the Cloud IAM group.
    CLOUD_IAM_GROUP_USER = 4

    # Read-only. Login for a service account that belongs to the
    # Cloud IAM group.
    CLOUD_IAM_GROUP_SERVICE_ACCOUNT = 5

    # Microsoft Entra ID user.
    ENTRAID_USER = 7
  end

  # The type of retained password.
  module DualPasswordType
    # The default value.
    DUAL_PASSWORD_TYPE_UNSPECIFIED = 0

    # Do not update the user's dual password status.
    NO_MODIFY_DUAL_PASSWORD = 1

    # No dual password usable for connecting using this user.
    NO_DUAL_PASSWORD = 2

    # Dual password usable for connecting using this user.
    DUAL_PASSWORD = 3
  end

  # Indicates if a group is available for IAM database authentication.
  module IamStatus
    # The default value for users that are not of type CLOUD_IAM_GROUP.
    # Only CLOUD_IAM_GROUP users will be inactive or active.
    # Users with an IamStatus of IAM_STATUS_UNSPECIFIED will not
    # display whether they are active or inactive as that is not applicable to
    # them.
    IAM_STATUS_UNSPECIFIED = 0

    # INACTIVE indicates a group is not available for IAM database
    # authentication.
    INACTIVE = 1

    # ACTIVE indicates a group is available for IAM database authentication.
    ACTIVE = 2
  end
end

#kind::String

Returns This is always sql#user.

Returns:

  • (::String)

    This is always sql#user.



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_users.rb', line 199

class User
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The user type.
  module SqlUserType
    # The database's built-in user type.
    BUILT_IN = 0

    # Cloud IAM user.
    CLOUD_IAM_USER = 1

    # Cloud IAM service account.
    CLOUD_IAM_SERVICE_ACCOUNT = 2

    # Cloud IAM group. Not used for login.
    CLOUD_IAM_GROUP = 3

    # Read-only. Login for a user that belongs to the Cloud IAM group.
    CLOUD_IAM_GROUP_USER = 4

    # Read-only. Login for a service account that belongs to the
    # Cloud IAM group.
    CLOUD_IAM_GROUP_SERVICE_ACCOUNT = 5

    # Microsoft Entra ID user.
    ENTRAID_USER = 7
  end

  # The type of retained password.
  module DualPasswordType
    # The default value.
    DUAL_PASSWORD_TYPE_UNSPECIFIED = 0

    # Do not update the user's dual password status.
    NO_MODIFY_DUAL_PASSWORD = 1

    # No dual password usable for connecting using this user.
    NO_DUAL_PASSWORD = 2

    # Dual password usable for connecting using this user.
    DUAL_PASSWORD = 3
  end

  # Indicates if a group is available for IAM database authentication.
  module IamStatus
    # The default value for users that are not of type CLOUD_IAM_GROUP.
    # Only CLOUD_IAM_GROUP users will be inactive or active.
    # Users with an IamStatus of IAM_STATUS_UNSPECIFIED will not
    # display whether they are active or inactive as that is not applicable to
    # them.
    IAM_STATUS_UNSPECIFIED = 0

    # INACTIVE indicates a group is not available for IAM database
    # authentication.
    INACTIVE = 1

    # ACTIVE indicates a group is available for IAM database authentication.
    ACTIVE = 2
  end
end

#name::String

Returns The name of the user in the Cloud SQL instance. Can be omitted for update because it is already specified in the URL.

Returns:

  • (::String)

    The name of the user in the Cloud SQL instance. Can be omitted for update because it is already specified in the URL.



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_users.rb', line 199

class User
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The user type.
  module SqlUserType
    # The database's built-in user type.
    BUILT_IN = 0

    # Cloud IAM user.
    CLOUD_IAM_USER = 1

    # Cloud IAM service account.
    CLOUD_IAM_SERVICE_ACCOUNT = 2

    # Cloud IAM group. Not used for login.
    CLOUD_IAM_GROUP = 3

    # Read-only. Login for a user that belongs to the Cloud IAM group.
    CLOUD_IAM_GROUP_USER = 4

    # Read-only. Login for a service account that belongs to the
    # Cloud IAM group.
    CLOUD_IAM_GROUP_SERVICE_ACCOUNT = 5

    # Microsoft Entra ID user.
    ENTRAID_USER = 7
  end

  # The type of retained password.
  module DualPasswordType
    # The default value.
    DUAL_PASSWORD_TYPE_UNSPECIFIED = 0

    # Do not update the user's dual password status.
    NO_MODIFY_DUAL_PASSWORD = 1

    # No dual password usable for connecting using this user.
    NO_DUAL_PASSWORD = 2

    # Dual password usable for connecting using this user.
    DUAL_PASSWORD = 3
  end

  # Indicates if a group is available for IAM database authentication.
  module IamStatus
    # The default value for users that are not of type CLOUD_IAM_GROUP.
    # Only CLOUD_IAM_GROUP users will be inactive or active.
    # Users with an IamStatus of IAM_STATUS_UNSPECIFIED will not
    # display whether they are active or inactive as that is not applicable to
    # them.
    IAM_STATUS_UNSPECIFIED = 0

    # INACTIVE indicates a group is not available for IAM database
    # authentication.
    INACTIVE = 1

    # ACTIVE indicates a group is available for IAM database authentication.
    ACTIVE = 2
  end
end

#password::String

Returns The password for the user.

Returns:

  • (::String)

    The password for the user.



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_users.rb', line 199

class User
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The user type.
  module SqlUserType
    # The database's built-in user type.
    BUILT_IN = 0

    # Cloud IAM user.
    CLOUD_IAM_USER = 1

    # Cloud IAM service account.
    CLOUD_IAM_SERVICE_ACCOUNT = 2

    # Cloud IAM group. Not used for login.
    CLOUD_IAM_GROUP = 3

    # Read-only. Login for a user that belongs to the Cloud IAM group.
    CLOUD_IAM_GROUP_USER = 4

    # Read-only. Login for a service account that belongs to the
    # Cloud IAM group.
    CLOUD_IAM_GROUP_SERVICE_ACCOUNT = 5

    # Microsoft Entra ID user.
    ENTRAID_USER = 7
  end

  # The type of retained password.
  module DualPasswordType
    # The default value.
    DUAL_PASSWORD_TYPE_UNSPECIFIED = 0

    # Do not update the user's dual password status.
    NO_MODIFY_DUAL_PASSWORD = 1

    # No dual password usable for connecting using this user.
    NO_DUAL_PASSWORD = 2

    # Dual password usable for connecting using this user.
    DUAL_PASSWORD = 3
  end

  # Indicates if a group is available for IAM database authentication.
  module IamStatus
    # The default value for users that are not of type CLOUD_IAM_GROUP.
    # Only CLOUD_IAM_GROUP users will be inactive or active.
    # Users with an IamStatus of IAM_STATUS_UNSPECIFIED will not
    # display whether they are active or inactive as that is not applicable to
    # them.
    IAM_STATUS_UNSPECIFIED = 0

    # INACTIVE indicates a group is not available for IAM database
    # authentication.
    INACTIVE = 1

    # ACTIVE indicates a group is available for IAM database authentication.
    ACTIVE = 2
  end
end

#password_policy::Google::Cloud::Sql::V1::UserPasswordValidationPolicy

Returns User level password validation policy.

Returns:



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_users.rb', line 199

class User
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The user type.
  module SqlUserType
    # The database's built-in user type.
    BUILT_IN = 0

    # Cloud IAM user.
    CLOUD_IAM_USER = 1

    # Cloud IAM service account.
    CLOUD_IAM_SERVICE_ACCOUNT = 2

    # Cloud IAM group. Not used for login.
    CLOUD_IAM_GROUP = 3

    # Read-only. Login for a user that belongs to the Cloud IAM group.
    CLOUD_IAM_GROUP_USER = 4

    # Read-only. Login for a service account that belongs to the
    # Cloud IAM group.
    CLOUD_IAM_GROUP_SERVICE_ACCOUNT = 5

    # Microsoft Entra ID user.
    ENTRAID_USER = 7
  end

  # The type of retained password.
  module DualPasswordType
    # The default value.
    DUAL_PASSWORD_TYPE_UNSPECIFIED = 0

    # Do not update the user's dual password status.
    NO_MODIFY_DUAL_PASSWORD = 1

    # No dual password usable for connecting using this user.
    NO_DUAL_PASSWORD = 2

    # Dual password usable for connecting using this user.
    DUAL_PASSWORD = 3
  end

  # Indicates if a group is available for IAM database authentication.
  module IamStatus
    # The default value for users that are not of type CLOUD_IAM_GROUP.
    # Only CLOUD_IAM_GROUP users will be inactive or active.
    # Users with an IamStatus of IAM_STATUS_UNSPECIFIED will not
    # display whether they are active or inactive as that is not applicable to
    # them.
    IAM_STATUS_UNSPECIFIED = 0

    # INACTIVE indicates a group is not available for IAM database
    # authentication.
    INACTIVE = 1

    # ACTIVE indicates a group is available for IAM database authentication.
    ACTIVE = 2
  end
end

#project::String

Returns The project ID of the project containing the Cloud SQL database. The Google apps domain is prefixed if applicable. Can be omitted for update because it is already specified on the URL.

Returns:

  • (::String)

    The project ID of the project containing the Cloud SQL database. The Google apps domain is prefixed if applicable. Can be omitted for update because it is already specified on the URL.



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_users.rb', line 199

class User
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The user type.
  module SqlUserType
    # The database's built-in user type.
    BUILT_IN = 0

    # Cloud IAM user.
    CLOUD_IAM_USER = 1

    # Cloud IAM service account.
    CLOUD_IAM_SERVICE_ACCOUNT = 2

    # Cloud IAM group. Not used for login.
    CLOUD_IAM_GROUP = 3

    # Read-only. Login for a user that belongs to the Cloud IAM group.
    CLOUD_IAM_GROUP_USER = 4

    # Read-only. Login for a service account that belongs to the
    # Cloud IAM group.
    CLOUD_IAM_GROUP_SERVICE_ACCOUNT = 5

    # Microsoft Entra ID user.
    ENTRAID_USER = 7
  end

  # The type of retained password.
  module DualPasswordType
    # The default value.
    DUAL_PASSWORD_TYPE_UNSPECIFIED = 0

    # Do not update the user's dual password status.
    NO_MODIFY_DUAL_PASSWORD = 1

    # No dual password usable for connecting using this user.
    NO_DUAL_PASSWORD = 2

    # Dual password usable for connecting using this user.
    DUAL_PASSWORD = 3
  end

  # Indicates if a group is available for IAM database authentication.
  module IamStatus
    # The default value for users that are not of type CLOUD_IAM_GROUP.
    # Only CLOUD_IAM_GROUP users will be inactive or active.
    # Users with an IamStatus of IAM_STATUS_UNSPECIFIED will not
    # display whether they are active or inactive as that is not applicable to
    # them.
    IAM_STATUS_UNSPECIFIED = 0

    # INACTIVE indicates a group is not available for IAM database
    # authentication.
    INACTIVE = 1

    # ACTIVE indicates a group is available for IAM database authentication.
    ACTIVE = 2
  end
end

#sqlserver_user_details::Google::Cloud::Sql::V1::SqlServerUserDetails



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_users.rb', line 199

class User
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The user type.
  module SqlUserType
    # The database's built-in user type.
    BUILT_IN = 0

    # Cloud IAM user.
    CLOUD_IAM_USER = 1

    # Cloud IAM service account.
    CLOUD_IAM_SERVICE_ACCOUNT = 2

    # Cloud IAM group. Not used for login.
    CLOUD_IAM_GROUP = 3

    # Read-only. Login for a user that belongs to the Cloud IAM group.
    CLOUD_IAM_GROUP_USER = 4

    # Read-only. Login for a service account that belongs to the
    # Cloud IAM group.
    CLOUD_IAM_GROUP_SERVICE_ACCOUNT = 5

    # Microsoft Entra ID user.
    ENTRAID_USER = 7
  end

  # The type of retained password.
  module DualPasswordType
    # The default value.
    DUAL_PASSWORD_TYPE_UNSPECIFIED = 0

    # Do not update the user's dual password status.
    NO_MODIFY_DUAL_PASSWORD = 1

    # No dual password usable for connecting using this user.
    NO_DUAL_PASSWORD = 2

    # Dual password usable for connecting using this user.
    DUAL_PASSWORD = 3
  end

  # Indicates if a group is available for IAM database authentication.
  module IamStatus
    # The default value for users that are not of type CLOUD_IAM_GROUP.
    # Only CLOUD_IAM_GROUP users will be inactive or active.
    # Users with an IamStatus of IAM_STATUS_UNSPECIFIED will not
    # display whether they are active or inactive as that is not applicable to
    # them.
    IAM_STATUS_UNSPECIFIED = 0

    # INACTIVE indicates a group is not available for IAM database
    # authentication.
    INACTIVE = 1

    # ACTIVE indicates a group is available for IAM database authentication.
    ACTIVE = 2
  end
end

#type::Google::Cloud::Sql::V1::User::SqlUserType

Returns The user type. It determines the method to authenticate the user during login. The default is the database's built-in user type.

Returns:



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_users.rb', line 199

class User
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The user type.
  module SqlUserType
    # The database's built-in user type.
    BUILT_IN = 0

    # Cloud IAM user.
    CLOUD_IAM_USER = 1

    # Cloud IAM service account.
    CLOUD_IAM_SERVICE_ACCOUNT = 2

    # Cloud IAM group. Not used for login.
    CLOUD_IAM_GROUP = 3

    # Read-only. Login for a user that belongs to the Cloud IAM group.
    CLOUD_IAM_GROUP_USER = 4

    # Read-only. Login for a service account that belongs to the
    # Cloud IAM group.
    CLOUD_IAM_GROUP_SERVICE_ACCOUNT = 5

    # Microsoft Entra ID user.
    ENTRAID_USER = 7
  end

  # The type of retained password.
  module DualPasswordType
    # The default value.
    DUAL_PASSWORD_TYPE_UNSPECIFIED = 0

    # Do not update the user's dual password status.
    NO_MODIFY_DUAL_PASSWORD = 1

    # No dual password usable for connecting using this user.
    NO_DUAL_PASSWORD = 2

    # Dual password usable for connecting using this user.
    DUAL_PASSWORD = 3
  end

  # Indicates if a group is available for IAM database authentication.
  module IamStatus
    # The default value for users that are not of type CLOUD_IAM_GROUP.
    # Only CLOUD_IAM_GROUP users will be inactive or active.
    # Users with an IamStatus of IAM_STATUS_UNSPECIFIED will not
    # display whether they are active or inactive as that is not applicable to
    # them.
    IAM_STATUS_UNSPECIFIED = 0

    # INACTIVE indicates a group is not available for IAM database
    # authentication.
    INACTIVE = 1

    # ACTIVE indicates a group is available for IAM database authentication.
    ACTIVE = 2
  end
end