Module: Google::Cloud::Sql::V1::User::IamStatus

Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_users.rb

Overview

Indicates if a group is available for IAM database authentication.

Constant Summary collapse

IAM_STATUS_UNSPECIFIED =

The default value for users that are not of type CLOUD_IAM_GROUP. Only CLOUD_IAM_GROUP users will be inactive or active. Users with an IamStatus of IAM_STATUS_UNSPECIFIED will not display whether they are active or inactive as that is not applicable to them.

0
INACTIVE =

INACTIVE indicates a group is not available for IAM database authentication.

1
ACTIVE =

ACTIVE indicates a group is available for IAM database authentication.

2