Class: Google::Cloud::Sql::V1::UserPasswordValidationPolicy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_users.rb

Overview

User level password validation policy.

Instance Attribute Summary collapse

Instance Attribute Details

#allowed_failed_attempts ⇒ ::Integer

Returns Number of failed login attempts allowed before user get locked.

Returns:

  • (::Integer) —

    Number of failed login attempts allowed before user get locked.



128
129
130
131
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_users.rb', line 128

class UserPasswordValidationPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#enable_failed_attempts_check ⇒ ::Boolean

Returns If true, failed login attempts check will be enabled.

Returns:

  • (::Boolean) —

    If true, failed login attempts check will be enabled.



128
129
130
131
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_users.rb', line 128

class UserPasswordValidationPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#enable_password_verification ⇒ ::Boolean

Returns If true, the user must specify the current password before changing the password. This flag is supported only for MySQL.

Returns:

  • (::Boolean) —

    If true, the user must specify the current password before changing the password. This flag is supported only for MySQL.



128
129
130
131
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_users.rb', line 128

class UserPasswordValidationPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#password_expiration_duration ⇒ ::Google::Protobuf::Duration

Returns Expiration duration after password is updated.

Returns:



128
129
130
131
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_users.rb', line 128

class UserPasswordValidationPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#status ⇒ ::Google::Cloud::Sql::V1::PasswordStatus (readonly)

Returns Output only. Read-only password status.

Returns:



128
129
130
131
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_users.rb', line 128

class UserPasswordValidationPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end