Class: Google::Cloud::Sql::V1::Value

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb

Overview

The cell value of the table.

Instance Attribute Summary collapse

Instance Attribute Details

#null_value::Boolean

Returns If cell value is null, then this flag will be set to true.

Returns:

  • (::Boolean)

    If cell value is null, then this flag will be set to true.



2215
2216
2217
2218
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 2215

class Value
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#value::String

Returns The cell value in string format.

Returns:

  • (::String)

    The cell value in string format.



2215
2216
2217
2218
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 2215

class Value
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end