Class: Google::Cloud::Sql::V1::ApiWarning
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::ApiWarning
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb
Overview
An Admin API warning message.
Defined Under Namespace
Modules: SqlApiWarningCode
Instance Attribute Summary collapse
-
#code ⇒ ::Google::Cloud::Sql::V1::ApiWarning::SqlApiWarningCode
Code to uniquely identify the warning type.
-
#message ⇒ ::String
The warning message.
-
#region ⇒ ::String
The region name for REGION_UNREACHABLE warning.
Instance Attribute Details
#code ⇒ ::Google::Cloud::Sql::V1::ApiWarning::SqlApiWarningCode
Returns Code to uniquely identify the warning type.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 54 class ApiWarning include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module SqlApiWarningCode # An unknown or unset warning type from Cloud SQL API. SQL_API_WARNING_CODE_UNSPECIFIED = 0 # Warning when one or more regions are not reachable. The returned result # set may be incomplete. REGION_UNREACHABLE = 1 # Warning when user provided maxResults parameter exceeds the limit. The # returned result set may be incomplete. MAX_RESULTS_EXCEEDS_LIMIT = 2 # Warning when user tries to create/update a user with credentials that # have previously been compromised by a public data breach. COMPROMISED_CREDENTIALS = 3 # Warning when the operation succeeds but some non-critical workflow state # failed. INTERNAL_STATE_FAILURE = 4 end end |
#message ⇒ ::String
Returns The warning message.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 54 class ApiWarning include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module SqlApiWarningCode # An unknown or unset warning type from Cloud SQL API. SQL_API_WARNING_CODE_UNSPECIFIED = 0 # Warning when one or more regions are not reachable. The returned result # set may be incomplete. REGION_UNREACHABLE = 1 # Warning when user provided maxResults parameter exceeds the limit. The # returned result set may be incomplete. MAX_RESULTS_EXCEEDS_LIMIT = 2 # Warning when user tries to create/update a user with credentials that # have previously been compromised by a public data breach. COMPROMISED_CREDENTIALS = 3 # Warning when the operation succeeds but some non-critical workflow state # failed. INTERNAL_STATE_FAILURE = 4 end end |
#region ⇒ ::String
Returns The region name for REGION_UNREACHABLE warning.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 54 class ApiWarning include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module SqlApiWarningCode # An unknown or unset warning type from Cloud SQL API. SQL_API_WARNING_CODE_UNSPECIFIED = 0 # Warning when one or more regions are not reachable. The returned result # set may be incomplete. REGION_UNREACHABLE = 1 # Warning when user provided maxResults parameter exceeds the limit. The # returned result set may be incomplete. MAX_RESULTS_EXCEEDS_LIMIT = 2 # Warning when user tries to create/update a user with credentials that # have previously been compromised by a public data breach. COMPROMISED_CREDENTIALS = 3 # Warning when the operation succeeds but some non-critical workflow state # failed. INTERNAL_STATE_FAILURE = 4 end end |