Module: Google::Cloud::Sql::V1::ApiWarning::SqlApiWarningCode
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb
Constant Summary collapse
- SQL_API_WARNING_CODE_UNSPECIFIED =
An unknown or unset warning type from Cloud SQL API.
0- REGION_UNREACHABLE =
Warning when one or more regions are not reachable. The returned result set may be incomplete.
1- MAX_RESULTS_EXCEEDS_LIMIT =
Warning when user provided maxResults parameter exceeds the limit. The returned result set may be incomplete.
2- COMPROMISED_CREDENTIALS =
Warning when user tries to create/update a user with credentials that have previously been compromised by a public data breach.
3- INTERNAL_STATE_FAILURE =
Warning when the operation succeeds but some non-critical workflow state failed.
4