Class: Google::Cloud::Sql::V1::BackupConfiguration

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb

Overview

Database instance backup configuration.

Defined Under Namespace

Modules: BackupTier, TransactionalLogStorageState

Instance Attribute Summary collapse

Instance Attribute Details

#backup_retention_settings::Google::Cloud::Sql::V1::BackupRetentionSettings

Returns Backup retention settings.

Returns:



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 142

class BackupConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This value contains the storage location of the transactional logs
  # used to perform point-in-time recovery (PITR) for the database.
  module TransactionalLogStorageState
    # Unspecified.
    TRANSACTIONAL_LOG_STORAGE_STATE_UNSPECIFIED = 0

    # The transaction logs used for PITR for the instance are stored
    # on a data disk.
    DISK = 1

    # The transaction logs used for PITR for the instance are switching from
    # being stored on a data disk to being stored in Cloud Storage.
    # Only applicable to MySQL.
    SWITCHING_TO_CLOUD_STORAGE = 2

    # The transaction logs used for PITR for the instance are now stored
    # in Cloud Storage. Previously, they were stored on a data disk.
    # Only applicable to MySQL.
    SWITCHED_TO_CLOUD_STORAGE = 3

    # The transaction logs used for PITR for the instance are stored in
    # Cloud Storage. Only applicable to MySQL and PostgreSQL.
    CLOUD_STORAGE = 4
  end

  # Backup tier that manages the backups for the instance.
  module BackupTier
    # Unspecified.
    BACKUP_TIER_UNSPECIFIED = 0

    # Instance is managed by Cloud SQL.
    STANDARD = 1

    # Deprecated: ADVANCED is deprecated. Please use ENHANCED instead.
    ADVANCED = 2

    # Instance is managed by Google Cloud Backup and DR Service.
    ENHANCED = 3
  end
end

#backup_tier::Google::Cloud::Sql::V1::BackupConfiguration::BackupTier (readonly)

Returns Output only. Backup tier that manages the backups for the instance.

Returns:



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 142

class BackupConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This value contains the storage location of the transactional logs
  # used to perform point-in-time recovery (PITR) for the database.
  module TransactionalLogStorageState
    # Unspecified.
    TRANSACTIONAL_LOG_STORAGE_STATE_UNSPECIFIED = 0

    # The transaction logs used for PITR for the instance are stored
    # on a data disk.
    DISK = 1

    # The transaction logs used for PITR for the instance are switching from
    # being stored on a data disk to being stored in Cloud Storage.
    # Only applicable to MySQL.
    SWITCHING_TO_CLOUD_STORAGE = 2

    # The transaction logs used for PITR for the instance are now stored
    # in Cloud Storage. Previously, they were stored on a data disk.
    # Only applicable to MySQL.
    SWITCHED_TO_CLOUD_STORAGE = 3

    # The transaction logs used for PITR for the instance are stored in
    # Cloud Storage. Only applicable to MySQL and PostgreSQL.
    CLOUD_STORAGE = 4
  end

  # Backup tier that manages the backups for the instance.
  module BackupTier
    # Unspecified.
    BACKUP_TIER_UNSPECIFIED = 0

    # Instance is managed by Cloud SQL.
    STANDARD = 1

    # Deprecated: ADVANCED is deprecated. Please use ENHANCED instead.
    ADVANCED = 2

    # Instance is managed by Google Cloud Backup and DR Service.
    ENHANCED = 3
  end
end

#binary_log_enabled::Google::Protobuf::BoolValue

Returns (MySQL only) Whether binary log is enabled. If backup configuration is disabled, binarylog must be disabled as well.

Returns:

  • (::Google::Protobuf::BoolValue)

    (MySQL only) Whether binary log is enabled. If backup configuration is disabled, binarylog must be disabled as well.



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 142

class BackupConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This value contains the storage location of the transactional logs
  # used to perform point-in-time recovery (PITR) for the database.
  module TransactionalLogStorageState
    # Unspecified.
    TRANSACTIONAL_LOG_STORAGE_STATE_UNSPECIFIED = 0

    # The transaction logs used for PITR for the instance are stored
    # on a data disk.
    DISK = 1

    # The transaction logs used for PITR for the instance are switching from
    # being stored on a data disk to being stored in Cloud Storage.
    # Only applicable to MySQL.
    SWITCHING_TO_CLOUD_STORAGE = 2

    # The transaction logs used for PITR for the instance are now stored
    # in Cloud Storage. Previously, they were stored on a data disk.
    # Only applicable to MySQL.
    SWITCHED_TO_CLOUD_STORAGE = 3

    # The transaction logs used for PITR for the instance are stored in
    # Cloud Storage. Only applicable to MySQL and PostgreSQL.
    CLOUD_STORAGE = 4
  end

  # Backup tier that manages the backups for the instance.
  module BackupTier
    # Unspecified.
    BACKUP_TIER_UNSPECIFIED = 0

    # Instance is managed by Cloud SQL.
    STANDARD = 1

    # Deprecated: ADVANCED is deprecated. Please use ENHANCED instead.
    ADVANCED = 2

    # Instance is managed by Google Cloud Backup and DR Service.
    ENHANCED = 3
  end
end

#enabled::Google::Protobuf::BoolValue

Returns Whether this configuration is enabled.

Returns:



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 142

class BackupConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This value contains the storage location of the transactional logs
  # used to perform point-in-time recovery (PITR) for the database.
  module TransactionalLogStorageState
    # Unspecified.
    TRANSACTIONAL_LOG_STORAGE_STATE_UNSPECIFIED = 0

    # The transaction logs used for PITR for the instance are stored
    # on a data disk.
    DISK = 1

    # The transaction logs used for PITR for the instance are switching from
    # being stored on a data disk to being stored in Cloud Storage.
    # Only applicable to MySQL.
    SWITCHING_TO_CLOUD_STORAGE = 2

    # The transaction logs used for PITR for the instance are now stored
    # in Cloud Storage. Previously, they were stored on a data disk.
    # Only applicable to MySQL.
    SWITCHED_TO_CLOUD_STORAGE = 3

    # The transaction logs used for PITR for the instance are stored in
    # Cloud Storage. Only applicable to MySQL and PostgreSQL.
    CLOUD_STORAGE = 4
  end

  # Backup tier that manages the backups for the instance.
  module BackupTier
    # Unspecified.
    BACKUP_TIER_UNSPECIFIED = 0

    # Instance is managed by Cloud SQL.
    STANDARD = 1

    # Deprecated: ADVANCED is deprecated. Please use ENHANCED instead.
    ADVANCED = 2

    # Instance is managed by Google Cloud Backup and DR Service.
    ENHANCED = 3
  end
end

#kind::String

Returns This is always sql#backupConfiguration.

Returns:

  • (::String)

    This is always sql#backupConfiguration.



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 142

class BackupConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This value contains the storage location of the transactional logs
  # used to perform point-in-time recovery (PITR) for the database.
  module TransactionalLogStorageState
    # Unspecified.
    TRANSACTIONAL_LOG_STORAGE_STATE_UNSPECIFIED = 0

    # The transaction logs used for PITR for the instance are stored
    # on a data disk.
    DISK = 1

    # The transaction logs used for PITR for the instance are switching from
    # being stored on a data disk to being stored in Cloud Storage.
    # Only applicable to MySQL.
    SWITCHING_TO_CLOUD_STORAGE = 2

    # The transaction logs used for PITR for the instance are now stored
    # in Cloud Storage. Previously, they were stored on a data disk.
    # Only applicable to MySQL.
    SWITCHED_TO_CLOUD_STORAGE = 3

    # The transaction logs used for PITR for the instance are stored in
    # Cloud Storage. Only applicable to MySQL and PostgreSQL.
    CLOUD_STORAGE = 4
  end

  # Backup tier that manages the backups for the instance.
  module BackupTier
    # Unspecified.
    BACKUP_TIER_UNSPECIFIED = 0

    # Instance is managed by Cloud SQL.
    STANDARD = 1

    # Deprecated: ADVANCED is deprecated. Please use ENHANCED instead.
    ADVANCED = 2

    # Instance is managed by Google Cloud Backup and DR Service.
    ENHANCED = 3
  end
end

#location::String

Returns Location of the backup.

Returns:

  • (::String)

    Location of the backup



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 142

class BackupConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This value contains the storage location of the transactional logs
  # used to perform point-in-time recovery (PITR) for the database.
  module TransactionalLogStorageState
    # Unspecified.
    TRANSACTIONAL_LOG_STORAGE_STATE_UNSPECIFIED = 0

    # The transaction logs used for PITR for the instance are stored
    # on a data disk.
    DISK = 1

    # The transaction logs used for PITR for the instance are switching from
    # being stored on a data disk to being stored in Cloud Storage.
    # Only applicable to MySQL.
    SWITCHING_TO_CLOUD_STORAGE = 2

    # The transaction logs used for PITR for the instance are now stored
    # in Cloud Storage. Previously, they were stored on a data disk.
    # Only applicable to MySQL.
    SWITCHED_TO_CLOUD_STORAGE = 3

    # The transaction logs used for PITR for the instance are stored in
    # Cloud Storage. Only applicable to MySQL and PostgreSQL.
    CLOUD_STORAGE = 4
  end

  # Backup tier that manages the backups for the instance.
  module BackupTier
    # Unspecified.
    BACKUP_TIER_UNSPECIFIED = 0

    # Instance is managed by Cloud SQL.
    STANDARD = 1

    # Deprecated: ADVANCED is deprecated. Please use ENHANCED instead.
    ADVANCED = 2

    # Instance is managed by Google Cloud Backup and DR Service.
    ENHANCED = 3
  end
end

#point_in_time_recovery_enabled::Google::Protobuf::BoolValue

Returns Whether point in time recovery is enabled.

Returns:



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 142

class BackupConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This value contains the storage location of the transactional logs
  # used to perform point-in-time recovery (PITR) for the database.
  module TransactionalLogStorageState
    # Unspecified.
    TRANSACTIONAL_LOG_STORAGE_STATE_UNSPECIFIED = 0

    # The transaction logs used for PITR for the instance are stored
    # on a data disk.
    DISK = 1

    # The transaction logs used for PITR for the instance are switching from
    # being stored on a data disk to being stored in Cloud Storage.
    # Only applicable to MySQL.
    SWITCHING_TO_CLOUD_STORAGE = 2

    # The transaction logs used for PITR for the instance are now stored
    # in Cloud Storage. Previously, they were stored on a data disk.
    # Only applicable to MySQL.
    SWITCHED_TO_CLOUD_STORAGE = 3

    # The transaction logs used for PITR for the instance are stored in
    # Cloud Storage. Only applicable to MySQL and PostgreSQL.
    CLOUD_STORAGE = 4
  end

  # Backup tier that manages the backups for the instance.
  module BackupTier
    # Unspecified.
    BACKUP_TIER_UNSPECIFIED = 0

    # Instance is managed by Cloud SQL.
    STANDARD = 1

    # Deprecated: ADVANCED is deprecated. Please use ENHANCED instead.
    ADVANCED = 2

    # Instance is managed by Google Cloud Backup and DR Service.
    ENHANCED = 3
  end
end

#replication_log_archiving_enabled::Google::Protobuf::BoolValue

Returns Reserved for future use.

Returns:



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 142

class BackupConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This value contains the storage location of the transactional logs
  # used to perform point-in-time recovery (PITR) for the database.
  module TransactionalLogStorageState
    # Unspecified.
    TRANSACTIONAL_LOG_STORAGE_STATE_UNSPECIFIED = 0

    # The transaction logs used for PITR for the instance are stored
    # on a data disk.
    DISK = 1

    # The transaction logs used for PITR for the instance are switching from
    # being stored on a data disk to being stored in Cloud Storage.
    # Only applicable to MySQL.
    SWITCHING_TO_CLOUD_STORAGE = 2

    # The transaction logs used for PITR for the instance are now stored
    # in Cloud Storage. Previously, they were stored on a data disk.
    # Only applicable to MySQL.
    SWITCHED_TO_CLOUD_STORAGE = 3

    # The transaction logs used for PITR for the instance are stored in
    # Cloud Storage. Only applicable to MySQL and PostgreSQL.
    CLOUD_STORAGE = 4
  end

  # Backup tier that manages the backups for the instance.
  module BackupTier
    # Unspecified.
    BACKUP_TIER_UNSPECIFIED = 0

    # Instance is managed by Cloud SQL.
    STANDARD = 1

    # Deprecated: ADVANCED is deprecated. Please use ENHANCED instead.
    ADVANCED = 2

    # Instance is managed by Google Cloud Backup and DR Service.
    ENHANCED = 3
  end
end

#start_time::String

Returns Start time for the daily backup configuration in UTC timezone in the 24 hour format - HH:MM.

Returns:

  • (::String)

    Start time for the daily backup configuration in UTC timezone in the 24 hour format - HH:MM.



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 142

class BackupConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This value contains the storage location of the transactional logs
  # used to perform point-in-time recovery (PITR) for the database.
  module TransactionalLogStorageState
    # Unspecified.
    TRANSACTIONAL_LOG_STORAGE_STATE_UNSPECIFIED = 0

    # The transaction logs used for PITR for the instance are stored
    # on a data disk.
    DISK = 1

    # The transaction logs used for PITR for the instance are switching from
    # being stored on a data disk to being stored in Cloud Storage.
    # Only applicable to MySQL.
    SWITCHING_TO_CLOUD_STORAGE = 2

    # The transaction logs used for PITR for the instance are now stored
    # in Cloud Storage. Previously, they were stored on a data disk.
    # Only applicable to MySQL.
    SWITCHED_TO_CLOUD_STORAGE = 3

    # The transaction logs used for PITR for the instance are stored in
    # Cloud Storage. Only applicable to MySQL and PostgreSQL.
    CLOUD_STORAGE = 4
  end

  # Backup tier that manages the backups for the instance.
  module BackupTier
    # Unspecified.
    BACKUP_TIER_UNSPECIFIED = 0

    # Instance is managed by Cloud SQL.
    STANDARD = 1

    # Deprecated: ADVANCED is deprecated. Please use ENHANCED instead.
    ADVANCED = 2

    # Instance is managed by Google Cloud Backup and DR Service.
    ENHANCED = 3
  end
end

#transaction_log_retention_days::Google::Protobuf::Int32Value

Returns The number of days of transaction logs we retain for point in time restore, from 1-7.

Returns:



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 142

class BackupConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This value contains the storage location of the transactional logs
  # used to perform point-in-time recovery (PITR) for the database.
  module TransactionalLogStorageState
    # Unspecified.
    TRANSACTIONAL_LOG_STORAGE_STATE_UNSPECIFIED = 0

    # The transaction logs used for PITR for the instance are stored
    # on a data disk.
    DISK = 1

    # The transaction logs used for PITR for the instance are switching from
    # being stored on a data disk to being stored in Cloud Storage.
    # Only applicable to MySQL.
    SWITCHING_TO_CLOUD_STORAGE = 2

    # The transaction logs used for PITR for the instance are now stored
    # in Cloud Storage. Previously, they were stored on a data disk.
    # Only applicable to MySQL.
    SWITCHED_TO_CLOUD_STORAGE = 3

    # The transaction logs used for PITR for the instance are stored in
    # Cloud Storage. Only applicable to MySQL and PostgreSQL.
    CLOUD_STORAGE = 4
  end

  # Backup tier that manages the backups for the instance.
  module BackupTier
    # Unspecified.
    BACKUP_TIER_UNSPECIFIED = 0

    # Instance is managed by Cloud SQL.
    STANDARD = 1

    # Deprecated: ADVANCED is deprecated. Please use ENHANCED instead.
    ADVANCED = 2

    # Instance is managed by Google Cloud Backup and DR Service.
    ENHANCED = 3
  end
end

#transactional_log_storage_state::Google::Cloud::Sql::V1::BackupConfiguration::TransactionalLogStorageState (readonly)

Returns Output only. This value contains the storage location of transactional logs used to perform point-in-time recovery (PITR) for the database.

Returns:



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 142

class BackupConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This value contains the storage location of the transactional logs
  # used to perform point-in-time recovery (PITR) for the database.
  module TransactionalLogStorageState
    # Unspecified.
    TRANSACTIONAL_LOG_STORAGE_STATE_UNSPECIFIED = 0

    # The transaction logs used for PITR for the instance are stored
    # on a data disk.
    DISK = 1

    # The transaction logs used for PITR for the instance are switching from
    # being stored on a data disk to being stored in Cloud Storage.
    # Only applicable to MySQL.
    SWITCHING_TO_CLOUD_STORAGE = 2

    # The transaction logs used for PITR for the instance are now stored
    # in Cloud Storage. Previously, they were stored on a data disk.
    # Only applicable to MySQL.
    SWITCHED_TO_CLOUD_STORAGE = 3

    # The transaction logs used for PITR for the instance are stored in
    # Cloud Storage. Only applicable to MySQL and PostgreSQL.
    CLOUD_STORAGE = 4
  end

  # Backup tier that manages the backups for the instance.
  module BackupTier
    # Unspecified.
    BACKUP_TIER_UNSPECIFIED = 0

    # Instance is managed by Cloud SQL.
    STANDARD = 1

    # Deprecated: ADVANCED is deprecated. Please use ENHANCED instead.
    ADVANCED = 2

    # Instance is managed by Google Cloud Backup and DR Service.
    ENHANCED = 3
  end
end