Module: Google::Cloud::Sql::V1::BackupConfiguration::TransactionalLogStorageState
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb
Overview
This value contains the storage location of the transactional logs used to perform point-in-time recovery (PITR) for the database.
Constant Summary collapse
- TRANSACTIONAL_LOG_STORAGE_STATE_UNSPECIFIED =
Unspecified.
0- DISK =
The transaction logs used for PITR for the instance are stored on a data disk.
1- SWITCHING_TO_CLOUD_STORAGE =
The transaction logs used for PITR for the instance are switching from being stored on a data disk to being stored in Cloud Storage. Only applicable to MySQL.
2- SWITCHED_TO_CLOUD_STORAGE =
The transaction logs used for PITR for the instance are now stored in Cloud Storage. Previously, they were stored on a data disk. Only applicable to MySQL.
3- CLOUD_STORAGE =
The transaction logs used for PITR for the instance are stored in Cloud Storage. Only applicable to MySQL and PostgreSQL.
4