Class: Google::Cloud::Sql::V1::BackupRun
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::BackupRun
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_backup_runs.rb
Overview
A BackupRun resource.
Instance Attribute Summary collapse
-
#backup_kind ⇒ ::Google::Cloud::Sql::V1::SqlBackupKind
Specifies the kind of backup, PHYSICAL or DEFAULT_SNAPSHOT.
-
#database_version ⇒ ::Google::Cloud::Sql::V1::SqlDatabaseVersion
readonly
Output only.
-
#description ⇒ ::String
The description of this run, only applicable to on-demand backups.
-
#disk_encryption_configuration ⇒ ::Google::Cloud::Sql::V1::DiskEncryptionConfiguration
Encryption configuration specific to a backup.
-
#disk_encryption_status ⇒ ::Google::Cloud::Sql::V1::DiskEncryptionStatus
Encryption status specific to a backup.
-
#end_time ⇒ ::Google::Protobuf::Timestamp
The time the backup operation completed in UTC timezone in RFC 3339 format, for example
2012-11-15T16:19:00.094Z. -
#enqueued_time ⇒ ::Google::Protobuf::Timestamp
The time the run was enqueued in UTC timezone in RFC 3339 format, for example
2012-11-15T16:19:00.094Z. -
#error ⇒ ::Google::Cloud::Sql::V1::OperationError
Information about why the backup operation failed.
-
#id ⇒ ::Integer
The identifier for this backup run.
-
#instance ⇒ ::String
Name of the database instance.
-
#kind ⇒ ::String
This is always
sql#backupRun. -
#location ⇒ ::String
Location of the backups.
-
#max_chargeable_bytes ⇒ ::Integer
readonly
Output only.
-
#self_link ⇒ ::String
The URI of this resource.
-
#start_time ⇒ ::Google::Protobuf::Timestamp
The time the backup operation actually started in UTC timezone in RFC 3339 format, for example
2012-11-15T16:19:00.094Z. -
#status ⇒ ::Google::Cloud::Sql::V1::SqlBackupRunStatus
The status of this run.
-
#time_zone ⇒ ::String
Backup time zone to prevent restores to an instance with a different time zone.
-
#type ⇒ ::Google::Cloud::Sql::V1::SqlBackupRunType
The type of this run; can be either "AUTOMATED" or "ON_DEMAND" or "FINAL".
-
#window_start_time ⇒ ::Google::Protobuf::Timestamp
The start time of the backup window during which this the backup was attempted in RFC 3339 format, for example
2012-11-15T16:19:00.094Z.
Instance Attribute Details
#backup_kind ⇒ ::Google::Cloud::Sql::V1::SqlBackupKind
Returns Specifies the kind of backup, PHYSICAL or DEFAULT_SNAPSHOT.
162 163 164 165 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backup_runs.rb', line 162 class BackupRun include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#database_version ⇒ ::Google::Cloud::Sql::V1::SqlDatabaseVersion (readonly)
Returns Output only. The instance database version at the time this backup was made.
162 163 164 165 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backup_runs.rb', line 162 class BackupRun include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#description ⇒ ::String
Returns The description of this run, only applicable to on-demand backups.
162 163 164 165 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backup_runs.rb', line 162 class BackupRun include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#disk_encryption_configuration ⇒ ::Google::Cloud::Sql::V1::DiskEncryptionConfiguration
Returns Encryption configuration specific to a backup.
162 163 164 165 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backup_runs.rb', line 162 class BackupRun include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#disk_encryption_status ⇒ ::Google::Cloud::Sql::V1::DiskEncryptionStatus
Returns Encryption status specific to a backup.
162 163 164 165 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backup_runs.rb', line 162 class BackupRun include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#end_time ⇒ ::Google::Protobuf::Timestamp
Returns The time the backup operation completed in UTC timezone in
RFC 3339 format, for example
2012-11-15T16:19:00.094Z.
162 163 164 165 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backup_runs.rb', line 162 class BackupRun include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#enqueued_time ⇒ ::Google::Protobuf::Timestamp
Returns The time the run was enqueued in UTC timezone in
RFC 3339 format, for example
2012-11-15T16:19:00.094Z.
162 163 164 165 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backup_runs.rb', line 162 class BackupRun include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#error ⇒ ::Google::Cloud::Sql::V1::OperationError
Returns Information about why the backup operation failed. This is only present if the run has the FAILED status.
162 163 164 165 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backup_runs.rb', line 162 class BackupRun include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#id ⇒ ::Integer
Returns The identifier for this backup run. Unique only for a specific Cloud SQL instance.
162 163 164 165 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backup_runs.rb', line 162 class BackupRun include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#instance ⇒ ::String
Returns Name of the database instance.
162 163 164 165 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backup_runs.rb', line 162 class BackupRun include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#kind ⇒ ::String
Returns This is always sql#backupRun.
162 163 164 165 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backup_runs.rb', line 162 class BackupRun include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#location ⇒ ::String
Returns Location of the backups.
162 163 164 165 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backup_runs.rb', line 162 class BackupRun include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#max_chargeable_bytes ⇒ ::Integer (readonly)
Returns Output only. The maximum chargeable bytes for the backup.
162 163 164 165 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backup_runs.rb', line 162 class BackupRun include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#self_link ⇒ ::String
Returns The URI of this resource.
162 163 164 165 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backup_runs.rb', line 162 class BackupRun include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#start_time ⇒ ::Google::Protobuf::Timestamp
Returns The time the backup operation actually started in UTC timezone in
RFC 3339 format, for example
2012-11-15T16:19:00.094Z.
162 163 164 165 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backup_runs.rb', line 162 class BackupRun include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#status ⇒ ::Google::Cloud::Sql::V1::SqlBackupRunStatus
Returns The status of this run.
162 163 164 165 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backup_runs.rb', line 162 class BackupRun include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#time_zone ⇒ ::String
Returns Backup time zone to prevent restores to an instance with a different time zone. Now relevant only for SQL Server.
162 163 164 165 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backup_runs.rb', line 162 class BackupRun include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#type ⇒ ::Google::Cloud::Sql::V1::SqlBackupRunType
Returns The type of this run; can be either "AUTOMATED" or "ON_DEMAND" or "FINAL". This field defaults to "ON_DEMAND" and is ignored, when specified for insert requests.
162 163 164 165 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backup_runs.rb', line 162 class BackupRun include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#window_start_time ⇒ ::Google::Protobuf::Timestamp
Returns The start time of the backup window during which this the backup was
attempted in RFC 3339 format, for
example 2012-11-15T16:19:00.094Z.
162 163 164 165 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backup_runs.rb', line 162 class BackupRun include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |