Class: Google::Cloud::Sql::V1::CloneContext
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::CloneContext
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb
Overview
Database instance clone context.
Instance Attribute Summary collapse
-
#allocated_ip_range ⇒ ::String
The name of the allocated ip range for the private ip Cloud SQL instance.
-
#bin_log_coordinates ⇒ ::Google::Cloud::Sql::V1::BinLogCoordinates
Binary log coordinates, if specified, identify the position up to which the source instance is cloned.
-
#database_names ⇒ ::Array<::String>
(SQL Server only) Clone only the specified databases from the source instance.
-
#destination_instance_name ⇒ ::String
Required.
-
#destination_network ⇒ ::String
Optional.
-
#destination_project ⇒ ::String
Optional.
-
#kind ⇒ ::String
This is always
sql#cloneContext. -
#pitr_timestamp_ms ⇒ ::Integer
Reserved for future use.
-
#point_in_time ⇒ ::Google::Protobuf::Timestamp
Timestamp, if specified, identifies the time to which the source instance is cloned.
-
#preferred_secondary_zone ⇒ ::String
Optional.
-
#preferred_zone ⇒ ::String
Optional.
-
#source_instance_deletion_time ⇒ ::Google::Protobuf::Timestamp
The timestamp used to identify the time when the source instance is deleted.
Instance Attribute Details
#allocated_ip_range ⇒ ::String
Returns The name of the allocated ip range for the private ip Cloud SQL instance. For example: "google-managed-services-default". If set, the cloned instance ip will be created in the allocated range. The range name must comply with RFC 1035. Specifically, the name must be 1-63 characters long and match the regular expression a-z?. Reserved for future use.
1048 1049 1050 1051 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1048 class CloneContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#bin_log_coordinates ⇒ ::Google::Cloud::Sql::V1::BinLogCoordinates
Returns Binary log coordinates, if specified, identify the position up to which the source instance is cloned. If not specified, the source instance is cloned up to the most recent binary log coordinates.
1048 1049 1050 1051 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1048 class CloneContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#database_names ⇒ ::Array<::String>
Returns (SQL Server only) Clone only the specified databases from the source instance. Clone all databases if empty.
1048 1049 1050 1051 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1048 class CloneContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#destination_instance_name ⇒ ::String
Returns Required. Name of the Cloud SQL instance to be created as a clone.
1048 1049 1050 1051 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1048 class CloneContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#destination_network ⇒ ::String
Returns Optional. The fully qualified URI of the VPC network to which the cloned
instance will be connected via Private Services Access for private IP. For
example:projects/my-network-project/global/networks/my-network. This
field is only required for cross-project cloning.
1048 1049 1050 1051 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1048 class CloneContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#destination_project ⇒ ::String
Returns Optional. The project ID of the destination project where the cloned instance will be created. To perform a cross-project clone, this field is required. If not specified, the clone is created in the same project as the source instance.
1048 1049 1050 1051 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1048 class CloneContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#kind ⇒ ::String
Returns This is always sql#cloneContext.
1048 1049 1050 1051 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1048 class CloneContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#pitr_timestamp_ms ⇒ ::Integer
Returns Reserved for future use.
1048 1049 1050 1051 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1048 class CloneContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#point_in_time ⇒ ::Google::Protobuf::Timestamp
Returns Timestamp, if specified, identifies the time to which the source instance is cloned.
1048 1049 1050 1051 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1048 class CloneContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#preferred_secondary_zone ⇒ ::String
Returns Optional. Copy clone and point-in-time recovery clone of a regional instance in the specified zones. If not specified, clone to the same secondary zone as the source instance. This value cannot be the same as the preferred_zone field. This field applies to all DB types.
1048 1049 1050 1051 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1048 class CloneContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#preferred_zone ⇒ ::String
Returns Optional. Copy clone and point-in-time recovery clone of an instance to the specified zone. If no zone is specified, clone to the same primary zone as the source instance. This field applies to all DB types.
1048 1049 1050 1051 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1048 class CloneContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#source_instance_deletion_time ⇒ ::Google::Protobuf::Timestamp
Returns The timestamp used to identify the time when the source instance is deleted. If this instance is deleted, then you must set the timestamp.
1048 1049 1050 1051 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1048 class CloneContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |