Class: Google::Cloud::Sql::V1::ConnectSettings
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::ConnectSettings
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_connect.rb
Overview
Connect settings retrieval response.
Defined Under Namespace
Modules: CaMode, MdxProtocolSupport Classes: ConnectPoolNodeConfig
Instance Attribute Summary collapse
-
#backend_type ⇒ ::Google::Cloud::Sql::V1::SqlBackendType
SECOND_GEN: Cloud SQL database instance. -
#custom_subject_alternative_names ⇒ ::Array<::String>
Custom subject alternative names for the server certificate.
-
#database_version ⇒ ::Google::Cloud::Sql::V1::SqlDatabaseVersion
The database engine type and version.
-
#dns_name ⇒ ::String
The dns name of the instance.
-
#dns_names ⇒ ::Array<::Google::Cloud::Sql::V1::DnsNameMapping>
readonly
Output only.
-
#ip_addresses ⇒ ::Array<::Google::Cloud::Sql::V1::IpMapping>
The assigned IP addresses for the instance.
-
#kind ⇒ ::String
This is always
sql#connectSettings. -
#mdx_protocol_support ⇒ ::Array<::Google::Cloud::Sql::V1::ConnectSettings::MdxProtocolSupport>
readonly
Optional.
-
#node_count ⇒ ::Integer
The number of read pool nodes in a read pool.
-
#nodes ⇒ ::Array<::Google::Cloud::Sql::V1::ConnectSettings::ConnectPoolNodeConfig>
readonly
Output only.
-
#psc_enabled ⇒ ::Boolean
Whether PSC connectivity is enabled for this instance.
-
#region ⇒ ::String
The cloud region for the instance.
-
#server_ca_cert ⇒ ::Google::Cloud::Sql::V1::SslCert
SSL configuration.
-
#server_ca_mode ⇒ ::Google::Cloud::Sql::V1::ConnectSettings::CaMode
Specify what type of CA is used for the server certificate.
Instance Attribute Details
#backend_type ⇒ ::Google::Cloud::Sql::V1::SqlBackendType
Returns SECOND_GEN: Cloud SQL database instance.
EXTERNAL: A database server that is not managed by Google.
This property is read-only; use the tier property in the settings
object to determine the database type.
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_connect.rb', line 102 class ConnectSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Details of a single read pool node of a read pool. # @!attribute [r] name # @return [::String] # Output only. The name of the read pool node. Doesn't include the project # ID. # @!attribute [r] ip_addresses # @return [::Array<::Google::Cloud::Sql::V1::IpMapping>] # Output only. Mappings containing IP addresses that can be used to connect # to the read pool node. # @!attribute [r] dns_name # @return [::String] # Output only. The DNS name of the read pool node. # @!attribute [r] dns_names # @return [::Array<::Google::Cloud::Sql::V1::DnsNameMapping>] # Output only. The list of DNS names used by this read pool node. class ConnectPoolNodeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Various Certificate Authority (CA) modes for certificate signing. module CaMode # CA mode is unknown. CA_MODE_UNSPECIFIED = 0 # Google-managed self-signed internal CA. GOOGLE_MANAGED_INTERNAL_CA = 1 # Google-managed regional CA part of root CA hierarchy hosted on Google # Cloud's Certificate Authority Service (CAS). GOOGLE_MANAGED_CAS_CA = 2 # Customer-managed CA hosted on Google Cloud's Certificate Authority # Service (CAS). CUSTOMER_MANAGED_CAS_CA = 3 end # MdxProtocolSupport describes parts of the MDX protocol supported by this # instance. module MdxProtocolSupport # Not specified. MDX_PROTOCOL_SUPPORT_UNSPECIFIED = 0 # Client should send the client protocol type in the MDX request. CLIENT_PROTOCOL_TYPE = 1 end end |
#custom_subject_alternative_names ⇒ ::Array<::String>
Returns Custom subject alternative names for the server certificate.
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_connect.rb', line 102 class ConnectSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Details of a single read pool node of a read pool. # @!attribute [r] name # @return [::String] # Output only. The name of the read pool node. Doesn't include the project # ID. # @!attribute [r] ip_addresses # @return [::Array<::Google::Cloud::Sql::V1::IpMapping>] # Output only. Mappings containing IP addresses that can be used to connect # to the read pool node. # @!attribute [r] dns_name # @return [::String] # Output only. The DNS name of the read pool node. # @!attribute [r] dns_names # @return [::Array<::Google::Cloud::Sql::V1::DnsNameMapping>] # Output only. The list of DNS names used by this read pool node. class ConnectPoolNodeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Various Certificate Authority (CA) modes for certificate signing. module CaMode # CA mode is unknown. CA_MODE_UNSPECIFIED = 0 # Google-managed self-signed internal CA. GOOGLE_MANAGED_INTERNAL_CA = 1 # Google-managed regional CA part of root CA hierarchy hosted on Google # Cloud's Certificate Authority Service (CAS). GOOGLE_MANAGED_CAS_CA = 2 # Customer-managed CA hosted on Google Cloud's Certificate Authority # Service (CAS). CUSTOMER_MANAGED_CAS_CA = 3 end # MdxProtocolSupport describes parts of the MDX protocol supported by this # instance. module MdxProtocolSupport # Not specified. MDX_PROTOCOL_SUPPORT_UNSPECIFIED = 0 # Client should send the client protocol type in the MDX request. CLIENT_PROTOCOL_TYPE = 1 end end |
#database_version ⇒ ::Google::Cloud::Sql::V1::SqlDatabaseVersion
Returns The database engine type and version. The databaseVersion
field cannot be changed after instance creation.
MySQL instances: MYSQL_8_0, MYSQL_5_7 (default),
or MYSQL_5_6.
PostgreSQL instances: POSTGRES_9_6, POSTGRES_10,
POSTGRES_11, POSTGRES_12 (default), POSTGRES_13, or POSTGRES_14.
SQL Server instances: SQLSERVER_2017_STANDARD (default),
SQLSERVER_2017_ENTERPRISE, SQLSERVER_2017_EXPRESS,
SQLSERVER_2017_WEB, SQLSERVER_2019_STANDARD,
SQLSERVER_2019_ENTERPRISE, SQLSERVER_2019_EXPRESS, or
SQLSERVER_2019_WEB.
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_connect.rb', line 102 class ConnectSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Details of a single read pool node of a read pool. # @!attribute [r] name # @return [::String] # Output only. The name of the read pool node. Doesn't include the project # ID. # @!attribute [r] ip_addresses # @return [::Array<::Google::Cloud::Sql::V1::IpMapping>] # Output only. Mappings containing IP addresses that can be used to connect # to the read pool node. # @!attribute [r] dns_name # @return [::String] # Output only. The DNS name of the read pool node. # @!attribute [r] dns_names # @return [::Array<::Google::Cloud::Sql::V1::DnsNameMapping>] # Output only. The list of DNS names used by this read pool node. class ConnectPoolNodeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Various Certificate Authority (CA) modes for certificate signing. module CaMode # CA mode is unknown. CA_MODE_UNSPECIFIED = 0 # Google-managed self-signed internal CA. GOOGLE_MANAGED_INTERNAL_CA = 1 # Google-managed regional CA part of root CA hierarchy hosted on Google # Cloud's Certificate Authority Service (CAS). GOOGLE_MANAGED_CAS_CA = 2 # Customer-managed CA hosted on Google Cloud's Certificate Authority # Service (CAS). CUSTOMER_MANAGED_CAS_CA = 3 end # MdxProtocolSupport describes parts of the MDX protocol supported by this # instance. module MdxProtocolSupport # Not specified. MDX_PROTOCOL_SUPPORT_UNSPECIFIED = 0 # Client should send the client protocol type in the MDX request. CLIENT_PROTOCOL_TYPE = 1 end end |
#dns_name ⇒ ::String
Returns The dns name of the instance.
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_connect.rb', line 102 class ConnectSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Details of a single read pool node of a read pool. # @!attribute [r] name # @return [::String] # Output only. The name of the read pool node. Doesn't include the project # ID. # @!attribute [r] ip_addresses # @return [::Array<::Google::Cloud::Sql::V1::IpMapping>] # Output only. Mappings containing IP addresses that can be used to connect # to the read pool node. # @!attribute [r] dns_name # @return [::String] # Output only. The DNS name of the read pool node. # @!attribute [r] dns_names # @return [::Array<::Google::Cloud::Sql::V1::DnsNameMapping>] # Output only. The list of DNS names used by this read pool node. class ConnectPoolNodeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Various Certificate Authority (CA) modes for certificate signing. module CaMode # CA mode is unknown. CA_MODE_UNSPECIFIED = 0 # Google-managed self-signed internal CA. GOOGLE_MANAGED_INTERNAL_CA = 1 # Google-managed regional CA part of root CA hierarchy hosted on Google # Cloud's Certificate Authority Service (CAS). GOOGLE_MANAGED_CAS_CA = 2 # Customer-managed CA hosted on Google Cloud's Certificate Authority # Service (CAS). CUSTOMER_MANAGED_CAS_CA = 3 end # MdxProtocolSupport describes parts of the MDX protocol supported by this # instance. module MdxProtocolSupport # Not specified. MDX_PROTOCOL_SUPPORT_UNSPECIFIED = 0 # Client should send the client protocol type in the MDX request. CLIENT_PROTOCOL_TYPE = 1 end end |
#dns_names ⇒ ::Array<::Google::Cloud::Sql::V1::DnsNameMapping> (readonly)
Returns Output only. The list of DNS names used by this instance.
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_connect.rb', line 102 class ConnectSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Details of a single read pool node of a read pool. # @!attribute [r] name # @return [::String] # Output only. The name of the read pool node. Doesn't include the project # ID. # @!attribute [r] ip_addresses # @return [::Array<::Google::Cloud::Sql::V1::IpMapping>] # Output only. Mappings containing IP addresses that can be used to connect # to the read pool node. # @!attribute [r] dns_name # @return [::String] # Output only. The DNS name of the read pool node. # @!attribute [r] dns_names # @return [::Array<::Google::Cloud::Sql::V1::DnsNameMapping>] # Output only. The list of DNS names used by this read pool node. class ConnectPoolNodeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Various Certificate Authority (CA) modes for certificate signing. module CaMode # CA mode is unknown. CA_MODE_UNSPECIFIED = 0 # Google-managed self-signed internal CA. GOOGLE_MANAGED_INTERNAL_CA = 1 # Google-managed regional CA part of root CA hierarchy hosted on Google # Cloud's Certificate Authority Service (CAS). GOOGLE_MANAGED_CAS_CA = 2 # Customer-managed CA hosted on Google Cloud's Certificate Authority # Service (CAS). CUSTOMER_MANAGED_CAS_CA = 3 end # MdxProtocolSupport describes parts of the MDX protocol supported by this # instance. module MdxProtocolSupport # Not specified. MDX_PROTOCOL_SUPPORT_UNSPECIFIED = 0 # Client should send the client protocol type in the MDX request. CLIENT_PROTOCOL_TYPE = 1 end end |
#ip_addresses ⇒ ::Array<::Google::Cloud::Sql::V1::IpMapping>
Returns The assigned IP addresses for the instance.
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_connect.rb', line 102 class ConnectSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Details of a single read pool node of a read pool. # @!attribute [r] name # @return [::String] # Output only. The name of the read pool node. Doesn't include the project # ID. # @!attribute [r] ip_addresses # @return [::Array<::Google::Cloud::Sql::V1::IpMapping>] # Output only. Mappings containing IP addresses that can be used to connect # to the read pool node. # @!attribute [r] dns_name # @return [::String] # Output only. The DNS name of the read pool node. # @!attribute [r] dns_names # @return [::Array<::Google::Cloud::Sql::V1::DnsNameMapping>] # Output only. The list of DNS names used by this read pool node. class ConnectPoolNodeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Various Certificate Authority (CA) modes for certificate signing. module CaMode # CA mode is unknown. CA_MODE_UNSPECIFIED = 0 # Google-managed self-signed internal CA. GOOGLE_MANAGED_INTERNAL_CA = 1 # Google-managed regional CA part of root CA hierarchy hosted on Google # Cloud's Certificate Authority Service (CAS). GOOGLE_MANAGED_CAS_CA = 2 # Customer-managed CA hosted on Google Cloud's Certificate Authority # Service (CAS). CUSTOMER_MANAGED_CAS_CA = 3 end # MdxProtocolSupport describes parts of the MDX protocol supported by this # instance. module MdxProtocolSupport # Not specified. MDX_PROTOCOL_SUPPORT_UNSPECIFIED = 0 # Client should send the client protocol type in the MDX request. CLIENT_PROTOCOL_TYPE = 1 end end |
#kind ⇒ ::String
Returns This is always sql#connectSettings.
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_connect.rb', line 102 class ConnectSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Details of a single read pool node of a read pool. # @!attribute [r] name # @return [::String] # Output only. The name of the read pool node. Doesn't include the project # ID. # @!attribute [r] ip_addresses # @return [::Array<::Google::Cloud::Sql::V1::IpMapping>] # Output only. Mappings containing IP addresses that can be used to connect # to the read pool node. # @!attribute [r] dns_name # @return [::String] # Output only. The DNS name of the read pool node. # @!attribute [r] dns_names # @return [::Array<::Google::Cloud::Sql::V1::DnsNameMapping>] # Output only. The list of DNS names used by this read pool node. class ConnectPoolNodeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Various Certificate Authority (CA) modes for certificate signing. module CaMode # CA mode is unknown. CA_MODE_UNSPECIFIED = 0 # Google-managed self-signed internal CA. GOOGLE_MANAGED_INTERNAL_CA = 1 # Google-managed regional CA part of root CA hierarchy hosted on Google # Cloud's Certificate Authority Service (CAS). GOOGLE_MANAGED_CAS_CA = 2 # Customer-managed CA hosted on Google Cloud's Certificate Authority # Service (CAS). CUSTOMER_MANAGED_CAS_CA = 3 end # MdxProtocolSupport describes parts of the MDX protocol supported by this # instance. module MdxProtocolSupport # Not specified. MDX_PROTOCOL_SUPPORT_UNSPECIFIED = 0 # Client should send the client protocol type in the MDX request. CLIENT_PROTOCOL_TYPE = 1 end end |
#mdx_protocol_support ⇒ ::Array<::Google::Cloud::Sql::V1::ConnectSettings::MdxProtocolSupport> (readonly)
Returns Optional. Output only. mdx_protocol_support controls how the client uses metadata exchange when connecting to the instance. The values in the list representing parts of the MDX protocol that are supported by this instance. When the list is empty, the instance does not support MDX, so the client must not send an MDX request. The default is empty.
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_connect.rb', line 102 class ConnectSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Details of a single read pool node of a read pool. # @!attribute [r] name # @return [::String] # Output only. The name of the read pool node. Doesn't include the project # ID. # @!attribute [r] ip_addresses # @return [::Array<::Google::Cloud::Sql::V1::IpMapping>] # Output only. Mappings containing IP addresses that can be used to connect # to the read pool node. # @!attribute [r] dns_name # @return [::String] # Output only. The DNS name of the read pool node. # @!attribute [r] dns_names # @return [::Array<::Google::Cloud::Sql::V1::DnsNameMapping>] # Output only. The list of DNS names used by this read pool node. class ConnectPoolNodeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Various Certificate Authority (CA) modes for certificate signing. module CaMode # CA mode is unknown. CA_MODE_UNSPECIFIED = 0 # Google-managed self-signed internal CA. GOOGLE_MANAGED_INTERNAL_CA = 1 # Google-managed regional CA part of root CA hierarchy hosted on Google # Cloud's Certificate Authority Service (CAS). GOOGLE_MANAGED_CAS_CA = 2 # Customer-managed CA hosted on Google Cloud's Certificate Authority # Service (CAS). CUSTOMER_MANAGED_CAS_CA = 3 end # MdxProtocolSupport describes parts of the MDX protocol supported by this # instance. module MdxProtocolSupport # Not specified. MDX_PROTOCOL_SUPPORT_UNSPECIFIED = 0 # Client should send the client protocol type in the MDX request. CLIENT_PROTOCOL_TYPE = 1 end end |
#node_count ⇒ ::Integer
Returns The number of read pool nodes in a read pool.
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_connect.rb', line 102 class ConnectSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Details of a single read pool node of a read pool. # @!attribute [r] name # @return [::String] # Output only. The name of the read pool node. Doesn't include the project # ID. # @!attribute [r] ip_addresses # @return [::Array<::Google::Cloud::Sql::V1::IpMapping>] # Output only. Mappings containing IP addresses that can be used to connect # to the read pool node. # @!attribute [r] dns_name # @return [::String] # Output only. The DNS name of the read pool node. # @!attribute [r] dns_names # @return [::Array<::Google::Cloud::Sql::V1::DnsNameMapping>] # Output only. The list of DNS names used by this read pool node. class ConnectPoolNodeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Various Certificate Authority (CA) modes for certificate signing. module CaMode # CA mode is unknown. CA_MODE_UNSPECIFIED = 0 # Google-managed self-signed internal CA. GOOGLE_MANAGED_INTERNAL_CA = 1 # Google-managed regional CA part of root CA hierarchy hosted on Google # Cloud's Certificate Authority Service (CAS). GOOGLE_MANAGED_CAS_CA = 2 # Customer-managed CA hosted on Google Cloud's Certificate Authority # Service (CAS). CUSTOMER_MANAGED_CAS_CA = 3 end # MdxProtocolSupport describes parts of the MDX protocol supported by this # instance. module MdxProtocolSupport # Not specified. MDX_PROTOCOL_SUPPORT_UNSPECIFIED = 0 # Client should send the client protocol type in the MDX request. CLIENT_PROTOCOL_TYPE = 1 end end |
#nodes ⇒ ::Array<::Google::Cloud::Sql::V1::ConnectSettings::ConnectPoolNodeConfig> (readonly)
Returns Output only. Entries containing information about each read pool node of the read pool.
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_connect.rb', line 102 class ConnectSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Details of a single read pool node of a read pool. # @!attribute [r] name # @return [::String] # Output only. The name of the read pool node. Doesn't include the project # ID. # @!attribute [r] ip_addresses # @return [::Array<::Google::Cloud::Sql::V1::IpMapping>] # Output only. Mappings containing IP addresses that can be used to connect # to the read pool node. # @!attribute [r] dns_name # @return [::String] # Output only. The DNS name of the read pool node. # @!attribute [r] dns_names # @return [::Array<::Google::Cloud::Sql::V1::DnsNameMapping>] # Output only. The list of DNS names used by this read pool node. class ConnectPoolNodeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Various Certificate Authority (CA) modes for certificate signing. module CaMode # CA mode is unknown. CA_MODE_UNSPECIFIED = 0 # Google-managed self-signed internal CA. GOOGLE_MANAGED_INTERNAL_CA = 1 # Google-managed regional CA part of root CA hierarchy hosted on Google # Cloud's Certificate Authority Service (CAS). GOOGLE_MANAGED_CAS_CA = 2 # Customer-managed CA hosted on Google Cloud's Certificate Authority # Service (CAS). CUSTOMER_MANAGED_CAS_CA = 3 end # MdxProtocolSupport describes parts of the MDX protocol supported by this # instance. module MdxProtocolSupport # Not specified. MDX_PROTOCOL_SUPPORT_UNSPECIFIED = 0 # Client should send the client protocol type in the MDX request. CLIENT_PROTOCOL_TYPE = 1 end end |
#psc_enabled ⇒ ::Boolean
Returns Whether PSC connectivity is enabled for this instance.
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_connect.rb', line 102 class ConnectSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Details of a single read pool node of a read pool. # @!attribute [r] name # @return [::String] # Output only. The name of the read pool node. Doesn't include the project # ID. # @!attribute [r] ip_addresses # @return [::Array<::Google::Cloud::Sql::V1::IpMapping>] # Output only. Mappings containing IP addresses that can be used to connect # to the read pool node. # @!attribute [r] dns_name # @return [::String] # Output only. The DNS name of the read pool node. # @!attribute [r] dns_names # @return [::Array<::Google::Cloud::Sql::V1::DnsNameMapping>] # Output only. The list of DNS names used by this read pool node. class ConnectPoolNodeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Various Certificate Authority (CA) modes for certificate signing. module CaMode # CA mode is unknown. CA_MODE_UNSPECIFIED = 0 # Google-managed self-signed internal CA. GOOGLE_MANAGED_INTERNAL_CA = 1 # Google-managed regional CA part of root CA hierarchy hosted on Google # Cloud's Certificate Authority Service (CAS). GOOGLE_MANAGED_CAS_CA = 2 # Customer-managed CA hosted on Google Cloud's Certificate Authority # Service (CAS). CUSTOMER_MANAGED_CAS_CA = 3 end # MdxProtocolSupport describes parts of the MDX protocol supported by this # instance. module MdxProtocolSupport # Not specified. MDX_PROTOCOL_SUPPORT_UNSPECIFIED = 0 # Client should send the client protocol type in the MDX request. CLIENT_PROTOCOL_TYPE = 1 end end |
#region ⇒ ::String
Returns The cloud region for the instance. For example, us-central1,
europe-west1. The region cannot be changed after instance creation.
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_connect.rb', line 102 class ConnectSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Details of a single read pool node of a read pool. # @!attribute [r] name # @return [::String] # Output only. The name of the read pool node. Doesn't include the project # ID. # @!attribute [r] ip_addresses # @return [::Array<::Google::Cloud::Sql::V1::IpMapping>] # Output only. Mappings containing IP addresses that can be used to connect # to the read pool node. # @!attribute [r] dns_name # @return [::String] # Output only. The DNS name of the read pool node. # @!attribute [r] dns_names # @return [::Array<::Google::Cloud::Sql::V1::DnsNameMapping>] # Output only. The list of DNS names used by this read pool node. class ConnectPoolNodeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Various Certificate Authority (CA) modes for certificate signing. module CaMode # CA mode is unknown. CA_MODE_UNSPECIFIED = 0 # Google-managed self-signed internal CA. GOOGLE_MANAGED_INTERNAL_CA = 1 # Google-managed regional CA part of root CA hierarchy hosted on Google # Cloud's Certificate Authority Service (CAS). GOOGLE_MANAGED_CAS_CA = 2 # Customer-managed CA hosted on Google Cloud's Certificate Authority # Service (CAS). CUSTOMER_MANAGED_CAS_CA = 3 end # MdxProtocolSupport describes parts of the MDX protocol supported by this # instance. module MdxProtocolSupport # Not specified. MDX_PROTOCOL_SUPPORT_UNSPECIFIED = 0 # Client should send the client protocol type in the MDX request. CLIENT_PROTOCOL_TYPE = 1 end end |
#server_ca_cert ⇒ ::Google::Cloud::Sql::V1::SslCert
Returns SSL configuration.
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_connect.rb', line 102 class ConnectSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Details of a single read pool node of a read pool. # @!attribute [r] name # @return [::String] # Output only. The name of the read pool node. Doesn't include the project # ID. # @!attribute [r] ip_addresses # @return [::Array<::Google::Cloud::Sql::V1::IpMapping>] # Output only. Mappings containing IP addresses that can be used to connect # to the read pool node. # @!attribute [r] dns_name # @return [::String] # Output only. The DNS name of the read pool node. # @!attribute [r] dns_names # @return [::Array<::Google::Cloud::Sql::V1::DnsNameMapping>] # Output only. The list of DNS names used by this read pool node. class ConnectPoolNodeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Various Certificate Authority (CA) modes for certificate signing. module CaMode # CA mode is unknown. CA_MODE_UNSPECIFIED = 0 # Google-managed self-signed internal CA. GOOGLE_MANAGED_INTERNAL_CA = 1 # Google-managed regional CA part of root CA hierarchy hosted on Google # Cloud's Certificate Authority Service (CAS). GOOGLE_MANAGED_CAS_CA = 2 # Customer-managed CA hosted on Google Cloud's Certificate Authority # Service (CAS). CUSTOMER_MANAGED_CAS_CA = 3 end # MdxProtocolSupport describes parts of the MDX protocol supported by this # instance. module MdxProtocolSupport # Not specified. MDX_PROTOCOL_SUPPORT_UNSPECIFIED = 0 # Client should send the client protocol type in the MDX request. CLIENT_PROTOCOL_TYPE = 1 end end |
#server_ca_mode ⇒ ::Google::Cloud::Sql::V1::ConnectSettings::CaMode
Returns Specify what type of CA is used for the server certificate.
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_connect.rb', line 102 class ConnectSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Details of a single read pool node of a read pool. # @!attribute [r] name # @return [::String] # Output only. The name of the read pool node. Doesn't include the project # ID. # @!attribute [r] ip_addresses # @return [::Array<::Google::Cloud::Sql::V1::IpMapping>] # Output only. Mappings containing IP addresses that can be used to connect # to the read pool node. # @!attribute [r] dns_name # @return [::String] # Output only. The DNS name of the read pool node. # @!attribute [r] dns_names # @return [::Array<::Google::Cloud::Sql::V1::DnsNameMapping>] # Output only. The list of DNS names used by this read pool node. class ConnectPoolNodeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Various Certificate Authority (CA) modes for certificate signing. module CaMode # CA mode is unknown. CA_MODE_UNSPECIFIED = 0 # Google-managed self-signed internal CA. GOOGLE_MANAGED_INTERNAL_CA = 1 # Google-managed regional CA part of root CA hierarchy hosted on Google # Cloud's Certificate Authority Service (CAS). GOOGLE_MANAGED_CAS_CA = 2 # Customer-managed CA hosted on Google Cloud's Certificate Authority # Service (CAS). CUSTOMER_MANAGED_CAS_CA = 3 end # MdxProtocolSupport describes parts of the MDX protocol supported by this # instance. module MdxProtocolSupport # Not specified. MDX_PROTOCOL_SUPPORT_UNSPECIFIED = 0 # Client should send the client protocol type in the MDX request. CLIENT_PROTOCOL_TYPE = 1 end end |