Class: Google::Cloud::Sql::V1::ConnectSettings::ConnectPoolNodeConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::ConnectSettings::ConnectPoolNodeConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_connect.rb
Overview
Details of a single read pool node of a read pool.
Instance Attribute Summary collapse
-
#dns_name ⇒ ::String
readonly
Output only.
-
#dns_names ⇒ ::Array<::Google::Cloud::Sql::V1::DnsNameMapping>
readonly
Output only.
-
#ip_addresses ⇒ ::Array<::Google::Cloud::Sql::V1::IpMapping>
readonly
Output only.
-
#name ⇒ ::String
readonly
Output only.
Instance Attribute Details
#dns_name ⇒ ::String (readonly)
Returns Output only. The DNS name of the read pool node.
121 122 123 124 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_connect.rb', line 121 class ConnectPoolNodeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#dns_names ⇒ ::Array<::Google::Cloud::Sql::V1::DnsNameMapping> (readonly)
Returns Output only. The list of DNS names used by this read pool node.
121 122 123 124 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_connect.rb', line 121 class ConnectPoolNodeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#ip_addresses ⇒ ::Array<::Google::Cloud::Sql::V1::IpMapping> (readonly)
Returns Output only. Mappings containing IP addresses that can be used to connect to the read pool node.
121 122 123 124 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_connect.rb', line 121 class ConnectPoolNodeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String (readonly)
Returns Output only. The name of the read pool node. Doesn't include the project ID.
121 122 123 124 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_connect.rb', line 121 class ConnectPoolNodeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |