Class: Google::Cloud::Sql::V1::Database
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::Database
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb
Overview
Represents a SQL database on the Cloud SQL instance.
Instance Attribute Summary collapse
-
#charset ⇒ ::String
The Cloud SQL charset value.
-
#collation ⇒ ::String
The Cloud SQL collation value.
-
#etag ⇒ ::String
This field is deprecated and will be removed from a future version of the API.
-
#instance ⇒ ::String
The name of the Cloud SQL instance.
-
#kind ⇒ ::String
This is always
sql#database. -
#name ⇒ ::String
The name of the database in the Cloud SQL instance.
-
#project ⇒ ::String
The project ID of the project containing the Cloud SQL database.
-
#self_link ⇒ ::String
The URI of this resource.
- #sqlserver_database_details ⇒ ::Google::Cloud::Sql::V1::SqlServerDatabaseDetails
Instance Attribute Details
#charset ⇒ ::String
Returns The Cloud SQL charset value.
290 291 292 293 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 290 class Database include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#collation ⇒ ::String
Returns The Cloud SQL collation value.
290 291 292 293 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 290 class Database include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#etag ⇒ ::String
Returns This field is deprecated and will be removed from a future version of the API.
290 291 292 293 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 290 class Database include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#instance ⇒ ::String
Returns The name of the Cloud SQL instance. This does not include the project ID.
290 291 292 293 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 290 class Database include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#kind ⇒ ::String
Returns This is always sql#database.
290 291 292 293 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 290 class Database include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns The name of the database in the Cloud SQL instance. This does not include the project ID or instance name.
290 291 292 293 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 290 class Database include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#project ⇒ ::String
Returns The project ID of the project containing the Cloud SQL database. The Google apps domain is prefixed if applicable.
290 291 292 293 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 290 class Database include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |