Class: Google::Cloud::Sql::V1::DatabaseFlags
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::DatabaseFlags
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb
Overview
Database flags for Cloud SQL instances.
Instance Attribute Summary collapse
-
#name ⇒ ::String
The name of the flag.
-
#value ⇒ ::String
The value of the flag.
Instance Attribute Details
#name ⇒ ::String
Returns The name of the flag. These flags are passed at instance startup, so include both server options and system variables. Flags are specified with underscores, not hyphens. For more information, see Configuring Database Flags in the Cloud SQL documentation.
320 321 322 323 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 320 class DatabaseFlags include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#value ⇒ ::String
Returns The value of the flag. Boolean flags are set to on for true
and off for false. This field must be omitted if the flag
doesn't take a value.
320 321 322 323 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 320 class DatabaseFlags include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |