Class: Google::Cloud::Sql::V1::DatabaseInstance::PoolNodeConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::DatabaseInstance::PoolNodeConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb
Overview
Details of a single read pool node of a read pool.
Instance Attribute Summary collapse
-
#dns_name ⇒ ::String
readonly
Output only.
-
#dns_names ⇒ ::Array<::Google::Cloud::Sql::V1::DnsNameMapping>
readonly
Output only.
-
#gce_zone ⇒ ::String
readonly
Output only.
-
#ip_addresses ⇒ ::Array<::Google::Cloud::Sql::V1::IpMapping>
readonly
Output only.
-
#name ⇒ ::String
readonly
Output only.
-
#psc_auto_connections ⇒ ::Array<::Google::Cloud::Sql::V1::PscAutoConnectionConfig>
readonly
Output only.
-
#psc_service_attachment_link ⇒ ::String
readonly
Output only.
-
#state ⇒ ::Google::Cloud::Sql::V1::DatabaseInstance::SqlInstanceState
readonly
Output only.
Instance Attribute Details
#dns_name ⇒ ::String (readonly)
Returns Output only. The DNS name of the read pool node.
1442 1443 1444 1445 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1442 class PoolNodeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#dns_names ⇒ ::Array<::Google::Cloud::Sql::V1::DnsNameMapping> (readonly)
Returns Output only. The list of DNS names used by this read pool node.
1442 1443 1444 1445 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1442 class PoolNodeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#gce_zone ⇒ ::String (readonly)
Returns Output only. The zone of the read pool node.
1442 1443 1444 1445 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1442 class PoolNodeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#ip_addresses ⇒ ::Array<::Google::Cloud::Sql::V1::IpMapping> (readonly)
Returns Output only. Mappings containing IP addresses that can be used to connect to the read pool node.
1442 1443 1444 1445 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1442 class PoolNodeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String (readonly)
Returns Output only. The name of the read pool node, to be used for retrieving metrics and logs.
1442 1443 1444 1445 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1442 class PoolNodeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#psc_auto_connections ⇒ ::Array<::Google::Cloud::Sql::V1::PscAutoConnectionConfig> (readonly)
Returns Output only. The list of settings for requested automatically-setup Private Service Connect (PSC) consumer endpoints that can be used to connect to this read pool node.
1442 1443 1444 1445 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1442 class PoolNodeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#psc_service_attachment_link ⇒ ::String (readonly)
Returns Output only. The Private Service Connect (PSC) service attachment of the read pool node.
1442 1443 1444 1445 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1442 class PoolNodeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#state ⇒ ::Google::Cloud::Sql::V1::DatabaseInstance::SqlInstanceState (readonly)
Returns Output only. The current state of the read pool node.
1442 1443 1444 1445 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1442 class PoolNodeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |