Module: Google::Cloud::Sql::V1::DatabaseInstance::SqlInstanceState
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb
Overview
The current serving state of the database instance.
Constant Summary collapse
- SQL_INSTANCE_STATE_UNSPECIFIED =
The state of the instance is unknown.
0- RUNNABLE =
The instance is running, or has been stopped by owner.
1- SUSPENDED =
The instance is not available, for example due to problems with billing.
2- PENDING_DELETE =
The instance is being deleted.
3- PENDING_CREATE =
The instance is being created.
4- MAINTENANCE =
The instance is down for maintenance.
5- FAILED =
The creation of the instance failed or a fatal error occurred during maintenance.
6- ONLINE_MAINTENANCE =
Deprecated
7- REPAIRING =
(Applicable to read pool nodes only.) The read pool node needs to be repaired. The database might be unavailable.
8