Class: Google::Cloud::Sql::V1::DemoteContext
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::DemoteContext
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb
Overview
This context is used to demote an existing standalone instance to be a Cloud SQL read replica for an external database server.
Instance Attribute Summary collapse
-
#kind ⇒ ::String
This is always
sql#demoteContext. -
#source_representative_instance_name ⇒ ::String
Required.
Instance Attribute Details
#kind ⇒ ::String
Returns This is always sql#demoteContext.
1646 1647 1648 1649 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1646 class DemoteContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#source_representative_instance_name ⇒ ::String
Returns Required. The name of the instance which acts as the on-premises primary instance in the replication setup.
1646 1647 1648 1649 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1646 class DemoteContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |