Class: Google::Cloud::Sql::V1::DnsNameMapping
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::DnsNameMapping
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb
Overview
DNS metadata.
Defined Under Namespace
Modules: ConnectionType, DnsScope, RecordManager
Instance Attribute Summary collapse
-
#connection_type ⇒ ::Google::Cloud::Sql::V1::DnsNameMapping::ConnectionType
readonly
Output only.
-
#dns_scope ⇒ ::Google::Cloud::Sql::V1::DnsNameMapping::DnsScope
readonly
Output only.
-
#name ⇒ ::String
readonly
Output only.
-
#record_manager ⇒ ::Google::Cloud::Sql::V1::DnsNameMapping::RecordManager
readonly
Output only.
Instance Attribute Details
#connection_type ⇒ ::Google::Cloud::Sql::V1::DnsNameMapping::ConnectionType (readonly)
Returns Output only. The connection type of the DNS name.
2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2228 class DnsNameMapping include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The connection type of the DNS name. # This enum is not frozen, and new values may be added in the future. module ConnectionType # Unknown connection type. CONNECTION_TYPE_UNSPECIFIED = 0 # Public IP. PUBLIC = 1 # Private services access (private IP). PRIVATE_SERVICES_ACCESS = 2 # Private Service Connect. PRIVATE_SERVICE_CONNECT = 3 end # The scope that the DNS name applies to. module DnsScope # DNS scope not set. This value should not be used. DNS_SCOPE_UNSPECIFIED = 0 # Indicates an instance-level DNS name. INSTANCE = 1 # Indicates a cluster-level DNS name. CLUSTER = 2 end # The system responsible for managing the DNS record. module RecordManager # Record manager not set. This value should not be used. RECORD_MANAGER_UNSPECIFIED = 0 # The record may be managed by the customer. It is not automatically # managed by Cloud SQL automation. CUSTOMER = 1 # The record is managed by Cloud SQL, which will create, update, # and delete the DNS records for the zone automatically when # the Cloud SQL database instance is created or updated. CLOUD_SQL_AUTOMATION = 2 end end |
#dns_scope ⇒ ::Google::Cloud::Sql::V1::DnsNameMapping::DnsScope (readonly)
Returns Output only. The scope that the DNS name applies to.
2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2228 class DnsNameMapping include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The connection type of the DNS name. # This enum is not frozen, and new values may be added in the future. module ConnectionType # Unknown connection type. CONNECTION_TYPE_UNSPECIFIED = 0 # Public IP. PUBLIC = 1 # Private services access (private IP). PRIVATE_SERVICES_ACCESS = 2 # Private Service Connect. PRIVATE_SERVICE_CONNECT = 3 end # The scope that the DNS name applies to. module DnsScope # DNS scope not set. This value should not be used. DNS_SCOPE_UNSPECIFIED = 0 # Indicates an instance-level DNS name. INSTANCE = 1 # Indicates a cluster-level DNS name. CLUSTER = 2 end # The system responsible for managing the DNS record. module RecordManager # Record manager not set. This value should not be used. RECORD_MANAGER_UNSPECIFIED = 0 # The record may be managed by the customer. It is not automatically # managed by Cloud SQL automation. CUSTOMER = 1 # The record is managed by Cloud SQL, which will create, update, # and delete the DNS records for the zone automatically when # the Cloud SQL database instance is created or updated. CLOUD_SQL_AUTOMATION = 2 end end |
#name ⇒ ::String (readonly)
Returns Output only. The DNS name.
2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2228 class DnsNameMapping include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The connection type of the DNS name. # This enum is not frozen, and new values may be added in the future. module ConnectionType # Unknown connection type. CONNECTION_TYPE_UNSPECIFIED = 0 # Public IP. PUBLIC = 1 # Private services access (private IP). PRIVATE_SERVICES_ACCESS = 2 # Private Service Connect. PRIVATE_SERVICE_CONNECT = 3 end # The scope that the DNS name applies to. module DnsScope # DNS scope not set. This value should not be used. DNS_SCOPE_UNSPECIFIED = 0 # Indicates an instance-level DNS name. INSTANCE = 1 # Indicates a cluster-level DNS name. CLUSTER = 2 end # The system responsible for managing the DNS record. module RecordManager # Record manager not set. This value should not be used. RECORD_MANAGER_UNSPECIFIED = 0 # The record may be managed by the customer. It is not automatically # managed by Cloud SQL automation. CUSTOMER = 1 # The record is managed by Cloud SQL, which will create, update, # and delete the DNS records for the zone automatically when # the Cloud SQL database instance is created or updated. CLOUD_SQL_AUTOMATION = 2 end end |
#record_manager ⇒ ::Google::Cloud::Sql::V1::DnsNameMapping::RecordManager (readonly)
Returns Output only. The manager for this DNS record.
2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2228 class DnsNameMapping include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The connection type of the DNS name. # This enum is not frozen, and new values may be added in the future. module ConnectionType # Unknown connection type. CONNECTION_TYPE_UNSPECIFIED = 0 # Public IP. PUBLIC = 1 # Private services access (private IP). PRIVATE_SERVICES_ACCESS = 2 # Private Service Connect. PRIVATE_SERVICE_CONNECT = 3 end # The scope that the DNS name applies to. module DnsScope # DNS scope not set. This value should not be used. DNS_SCOPE_UNSPECIFIED = 0 # Indicates an instance-level DNS name. INSTANCE = 1 # Indicates a cluster-level DNS name. CLUSTER = 2 end # The system responsible for managing the DNS record. module RecordManager # Record manager not set. This value should not be used. RECORD_MANAGER_UNSPECIFIED = 0 # The record may be managed by the customer. It is not automatically # managed by Cloud SQL automation. CUSTOMER = 1 # The record is managed by Cloud SQL, which will create, update, # and delete the DNS records for the zone automatically when # the Cloud SQL database instance is created or updated. CLOUD_SQL_AUTOMATION = 2 end end |