Class: Google::Cloud::Sql::V1::DnsNameMapping

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb

Overview

DNS metadata.

Defined Under Namespace

Modules: ConnectionType, DnsScope, RecordManager

Instance Attribute Summary collapse

Instance Attribute Details

#connection_type::Google::Cloud::Sql::V1::DnsNameMapping::ConnectionType (readonly)

Returns Output only. The connection type of the DNS name.

Returns:



2134
2135
2136
2137
2138
2139
2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
2159
2160
2161
2162
2163
2164
2165
2166
2167
2168
2169
2170
2171
2172
2173
2174
2175
2176
2177
2178
2179
2180
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2134

class DnsNameMapping
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The connection type of the DNS name.
  # This enum is not frozen, and new values may be added in the future.
  module ConnectionType
    # Unknown connection type.
    CONNECTION_TYPE_UNSPECIFIED = 0

    # Public IP.
    PUBLIC = 1

    # Private services access (private IP).
    PRIVATE_SERVICES_ACCESS = 2

    # Private Service Connect.
    PRIVATE_SERVICE_CONNECT = 3
  end

  # The scope that the DNS name applies to.
  module DnsScope
    # DNS scope not set. This value should not be used.
    DNS_SCOPE_UNSPECIFIED = 0

    # Indicates an instance-level DNS name.
    INSTANCE = 1

    # Indicates a cluster-level DNS name.
    CLUSTER = 2
  end

  # The system responsible for managing the DNS record.
  module RecordManager
    # Record manager not set. This value should not be used.
    RECORD_MANAGER_UNSPECIFIED = 0

    # The record may be managed by the customer. It is not automatically
    # managed by Cloud SQL automation.
    CUSTOMER = 1

    # The record is managed by Cloud SQL, which will create, update,
    # and delete the DNS records for the zone automatically when
    # the Cloud SQL database instance is created or updated.
    CLOUD_SQL_AUTOMATION = 2
  end
end

#dns_scope::Google::Cloud::Sql::V1::DnsNameMapping::DnsScope (readonly)

Returns Output only. The scope that the DNS name applies to.

Returns:



2134
2135
2136
2137
2138
2139
2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
2159
2160
2161
2162
2163
2164
2165
2166
2167
2168
2169
2170
2171
2172
2173
2174
2175
2176
2177
2178
2179
2180
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2134

class DnsNameMapping
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The connection type of the DNS name.
  # This enum is not frozen, and new values may be added in the future.
  module ConnectionType
    # Unknown connection type.
    CONNECTION_TYPE_UNSPECIFIED = 0

    # Public IP.
    PUBLIC = 1

    # Private services access (private IP).
    PRIVATE_SERVICES_ACCESS = 2

    # Private Service Connect.
    PRIVATE_SERVICE_CONNECT = 3
  end

  # The scope that the DNS name applies to.
  module DnsScope
    # DNS scope not set. This value should not be used.
    DNS_SCOPE_UNSPECIFIED = 0

    # Indicates an instance-level DNS name.
    INSTANCE = 1

    # Indicates a cluster-level DNS name.
    CLUSTER = 2
  end

  # The system responsible for managing the DNS record.
  module RecordManager
    # Record manager not set. This value should not be used.
    RECORD_MANAGER_UNSPECIFIED = 0

    # The record may be managed by the customer. It is not automatically
    # managed by Cloud SQL automation.
    CUSTOMER = 1

    # The record is managed by Cloud SQL, which will create, update,
    # and delete the DNS records for the zone automatically when
    # the Cloud SQL database instance is created or updated.
    CLOUD_SQL_AUTOMATION = 2
  end
end

#name::String (readonly)

Returns Output only. The DNS name.

Returns:

  • (::String)

    Output only. The DNS name.



2134
2135
2136
2137
2138
2139
2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
2159
2160
2161
2162
2163
2164
2165
2166
2167
2168
2169
2170
2171
2172
2173
2174
2175
2176
2177
2178
2179
2180
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2134

class DnsNameMapping
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The connection type of the DNS name.
  # This enum is not frozen, and new values may be added in the future.
  module ConnectionType
    # Unknown connection type.
    CONNECTION_TYPE_UNSPECIFIED = 0

    # Public IP.
    PUBLIC = 1

    # Private services access (private IP).
    PRIVATE_SERVICES_ACCESS = 2

    # Private Service Connect.
    PRIVATE_SERVICE_CONNECT = 3
  end

  # The scope that the DNS name applies to.
  module DnsScope
    # DNS scope not set. This value should not be used.
    DNS_SCOPE_UNSPECIFIED = 0

    # Indicates an instance-level DNS name.
    INSTANCE = 1

    # Indicates a cluster-level DNS name.
    CLUSTER = 2
  end

  # The system responsible for managing the DNS record.
  module RecordManager
    # Record manager not set. This value should not be used.
    RECORD_MANAGER_UNSPECIFIED = 0

    # The record may be managed by the customer. It is not automatically
    # managed by Cloud SQL automation.
    CUSTOMER = 1

    # The record is managed by Cloud SQL, which will create, update,
    # and delete the DNS records for the zone automatically when
    # the Cloud SQL database instance is created or updated.
    CLOUD_SQL_AUTOMATION = 2
  end
end

#record_manager::Google::Cloud::Sql::V1::DnsNameMapping::RecordManager (readonly)

Returns Output only. The manager for this DNS record.

Returns:



2134
2135
2136
2137
2138
2139
2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
2159
2160
2161
2162
2163
2164
2165
2166
2167
2168
2169
2170
2171
2172
2173
2174
2175
2176
2177
2178
2179
2180
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2134

class DnsNameMapping
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The connection type of the DNS name.
  # This enum is not frozen, and new values may be added in the future.
  module ConnectionType
    # Unknown connection type.
    CONNECTION_TYPE_UNSPECIFIED = 0

    # Public IP.
    PUBLIC = 1

    # Private services access (private IP).
    PRIVATE_SERVICES_ACCESS = 2

    # Private Service Connect.
    PRIVATE_SERVICE_CONNECT = 3
  end

  # The scope that the DNS name applies to.
  module DnsScope
    # DNS scope not set. This value should not be used.
    DNS_SCOPE_UNSPECIFIED = 0

    # Indicates an instance-level DNS name.
    INSTANCE = 1

    # Indicates a cluster-level DNS name.
    CLUSTER = 2
  end

  # The system responsible for managing the DNS record.
  module RecordManager
    # Record manager not set. This value should not be used.
    RECORD_MANAGER_UNSPECIFIED = 0

    # The record may be managed by the customer. It is not automatically
    # managed by Cloud SQL automation.
    CUSTOMER = 1

    # The record is managed by Cloud SQL, which will create, update,
    # and delete the DNS records for the zone automatically when
    # the Cloud SQL database instance is created or updated.
    CLOUD_SQL_AUTOMATION = 2
  end
end