Module: Google::Cloud::Sql::V1::DnsNameMapping::RecordManager
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb
Overview
The system responsible for managing the DNS record.
Constant Summary collapse
- RECORD_MANAGER_UNSPECIFIED =
Record manager not set. This value should not be used.
0- CUSTOMER =
The record may be managed by the customer. It is not automatically managed by Cloud SQL automation.
1- CLOUD_SQL_AUTOMATION =
The record is managed by Cloud SQL, which will create, update, and delete the DNS records for the zone automatically when the Cloud SQL database instance is created or updated.
2