Class: Google::Cloud::Sql::V1::ExportContext::SqlExportOptions
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::ExportContext::SqlExportOptions
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb
Defined Under Namespace
Classes: MysqlExportOptions, PostgresExportOptions
Instance Attribute Summary collapse
- #mysql_export_options ⇒ ::Google::Cloud::Sql::V1::ExportContext::SqlExportOptions::MysqlExportOptions
-
#parallel ⇒ ::Google::Protobuf::BoolValue
Optional.
-
#postgres_export_options ⇒ ::Google::Cloud::Sql::V1::ExportContext::SqlExportOptions::PostgresExportOptions
Optional.
-
#schema_only ⇒ ::Google::Protobuf::BoolValue
Export only schemas.
-
#tables ⇒ ::Array<::String>
Tables to export, or that were exported, from the specified database.
-
#threads ⇒ ::Google::Protobuf::Int32Value
Optional.
Instance Attribute Details
#mysql_export_options ⇒ ::Google::Cloud::Sql::V1::ExportContext::SqlExportOptions::MysqlExportOptions
502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 502 class SqlExportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Options for exporting from MySQL. # @!attribute [rw] master_data # @return [::Google::Protobuf::Int32Value] # Option to include SQL statement required to set up replication. If set # to `1`, the dump file includes a CHANGE MASTER TO statement with the # binary log coordinates, and --set-gtid-purged is set to ON. If set to # `2`, the CHANGE MASTER TO statement is written as a SQL comment and # has no effect. If set to any value other than `1`, --set-gtid-purged # is set to OFF. class MysqlExportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Options for exporting from a Cloud SQL for PostgreSQL instance. # @!attribute [rw] clean # @return [::Google::Protobuf::BoolValue] # Optional. Use this option to include DROP <code><object></code> # SQL statements. Use these statements to delete database objects before # running the import operation. # @!attribute [rw] if_exists # @return [::Google::Protobuf::BoolValue] # Optional. Option to include an IF EXISTS SQL statement with each DROP # statement produced by clean. class PostgresExportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#parallel ⇒ ::Google::Protobuf::BoolValue
Returns Optional. Whether or not the export should be parallel.
502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 502 class SqlExportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Options for exporting from MySQL. # @!attribute [rw] master_data # @return [::Google::Protobuf::Int32Value] # Option to include SQL statement required to set up replication. If set # to `1`, the dump file includes a CHANGE MASTER TO statement with the # binary log coordinates, and --set-gtid-purged is set to ON. If set to # `2`, the CHANGE MASTER TO statement is written as a SQL comment and # has no effect. If set to any value other than `1`, --set-gtid-purged # is set to OFF. class MysqlExportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Options for exporting from a Cloud SQL for PostgreSQL instance. # @!attribute [rw] clean # @return [::Google::Protobuf::BoolValue] # Optional. Use this option to include DROP <code><object></code> # SQL statements. Use these statements to delete database objects before # running the import operation. # @!attribute [rw] if_exists # @return [::Google::Protobuf::BoolValue] # Optional. Option to include an IF EXISTS SQL statement with each DROP # statement produced by clean. class PostgresExportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#postgres_export_options ⇒ ::Google::Cloud::Sql::V1::ExportContext::SqlExportOptions::PostgresExportOptions
Returns Optional. Options for exporting from a Cloud SQL for PostgreSQL instance.
502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 502 class SqlExportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Options for exporting from MySQL. # @!attribute [rw] master_data # @return [::Google::Protobuf::Int32Value] # Option to include SQL statement required to set up replication. If set # to `1`, the dump file includes a CHANGE MASTER TO statement with the # binary log coordinates, and --set-gtid-purged is set to ON. If set to # `2`, the CHANGE MASTER TO statement is written as a SQL comment and # has no effect. If set to any value other than `1`, --set-gtid-purged # is set to OFF. class MysqlExportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Options for exporting from a Cloud SQL for PostgreSQL instance. # @!attribute [rw] clean # @return [::Google::Protobuf::BoolValue] # Optional. Use this option to include DROP <code><object></code> # SQL statements. Use these statements to delete database objects before # running the import operation. # @!attribute [rw] if_exists # @return [::Google::Protobuf::BoolValue] # Optional. Option to include an IF EXISTS SQL statement with each DROP # statement produced by clean. class PostgresExportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#schema_only ⇒ ::Google::Protobuf::BoolValue
Returns Export only schemas.
502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 502 class SqlExportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Options for exporting from MySQL. # @!attribute [rw] master_data # @return [::Google::Protobuf::Int32Value] # Option to include SQL statement required to set up replication. If set # to `1`, the dump file includes a CHANGE MASTER TO statement with the # binary log coordinates, and --set-gtid-purged is set to ON. If set to # `2`, the CHANGE MASTER TO statement is written as a SQL comment and # has no effect. If set to any value other than `1`, --set-gtid-purged # is set to OFF. class MysqlExportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Options for exporting from a Cloud SQL for PostgreSQL instance. # @!attribute [rw] clean # @return [::Google::Protobuf::BoolValue] # Optional. Use this option to include DROP <code><object></code> # SQL statements. Use these statements to delete database objects before # running the import operation. # @!attribute [rw] if_exists # @return [::Google::Protobuf::BoolValue] # Optional. Option to include an IF EXISTS SQL statement with each DROP # statement produced by clean. class PostgresExportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#tables ⇒ ::Array<::String>
Returns Tables to export, or that were exported, from the specified database. If you specify tables, specify one and only one database. For PostgreSQL instances, you can specify only one table.
502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 502 class SqlExportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Options for exporting from MySQL. # @!attribute [rw] master_data # @return [::Google::Protobuf::Int32Value] # Option to include SQL statement required to set up replication. If set # to `1`, the dump file includes a CHANGE MASTER TO statement with the # binary log coordinates, and --set-gtid-purged is set to ON. If set to # `2`, the CHANGE MASTER TO statement is written as a SQL comment and # has no effect. If set to any value other than `1`, --set-gtid-purged # is set to OFF. class MysqlExportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Options for exporting from a Cloud SQL for PostgreSQL instance. # @!attribute [rw] clean # @return [::Google::Protobuf::BoolValue] # Optional. Use this option to include DROP <code><object></code> # SQL statements. Use these statements to delete database objects before # running the import operation. # @!attribute [rw] if_exists # @return [::Google::Protobuf::BoolValue] # Optional. Option to include an IF EXISTS SQL statement with each DROP # statement produced by clean. class PostgresExportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#threads ⇒ ::Google::Protobuf::Int32Value
Returns Optional. The number of threads to use for parallel export.
502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 502 class SqlExportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Options for exporting from MySQL. # @!attribute [rw] master_data # @return [::Google::Protobuf::Int32Value] # Option to include SQL statement required to set up replication. If set # to `1`, the dump file includes a CHANGE MASTER TO statement with the # binary log coordinates, and --set-gtid-purged is set to ON. If set to # `2`, the CHANGE MASTER TO statement is written as a SQL comment and # has no effect. If set to any value other than `1`, --set-gtid-purged # is set to OFF. class MysqlExportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Options for exporting from a Cloud SQL for PostgreSQL instance. # @!attribute [rw] clean # @return [::Google::Protobuf::BoolValue] # Optional. Use this option to include DROP <code><object></code> # SQL statements. Use these statements to delete database objects before # running the import operation. # @!attribute [rw] if_exists # @return [::Google::Protobuf::BoolValue] # Optional. Option to include an IF EXISTS SQL statement with each DROP # statement produced by clean. class PostgresExportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |