Class: Google::Cloud::Sql::V1::ExportContext::SqlTdeExportOptions
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::ExportContext::SqlTdeExportOptions
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb
Instance Attribute Summary collapse
-
#certificate_path ⇒ ::String
Required.
-
#name ⇒ ::String
Required.
-
#private_key_password ⇒ ::String
Required.
-
#private_key_path ⇒ ::String
Required.
Instance Attribute Details
#certificate_path ⇒ ::String
Returns Required. Path to the TDE certificate public key in the form gs://bucketName/fileName. The instance must have write access to the bucket. Applicable only for SQL Server instances.
594 595 596 597 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 594 class SqlTdeExportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. Certificate name. Applicable only for SQL Server instances.
594 595 596 597 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 594 class SqlTdeExportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#private_key_password ⇒ ::String
Returns Required. Password that encrypts the private key.
594 595 596 597 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 594 class SqlTdeExportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#private_key_path ⇒ ::String
Returns Required. Path to the TDE certificate private key in the form gs://bucketName/fileName. The instance must have write access to the location. Applicable only for SQL Server instances.
594 595 596 597 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 594 class SqlTdeExportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |