Class: Google::Cloud::Sql::V1::Flag
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::Flag
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_flags.rb
Overview
A flag resource.
Instance Attribute Summary collapse
-
#allowed_int_values ⇒ ::Array<::Integer>
Use this field if only certain integers are accepted.
-
#allowed_string_values ⇒ ::Array<::String>
For
STRINGflags, a list of strings that the value can be set to. -
#applies_to ⇒ ::Array<::Google::Cloud::Sql::V1::SqlDatabaseVersion>
The database version this flag applies to.
-
#flag_scope ⇒ ::Google::Cloud::Sql::V1::SqlFlagScope
Scope of flag.
-
#in_beta ⇒ ::Google::Protobuf::BoolValue
Whether or not the flag is considered in beta.
-
#kind ⇒ ::String
This is always
sql#flag. -
#max_value ⇒ ::Google::Protobuf::Int64Value
For
INTEGERflags, the maximum allowed value. -
#min_value ⇒ ::Google::Protobuf::Int64Value
For
INTEGERflags, the minimum allowed value. -
#name ⇒ ::String
This is the name of the flag.
-
#recommended_int_value ⇒ ::Google::Protobuf::Int64Value
Recommended int value in integer format for UI display.
-
#recommended_string_value ⇒ ::String
Recommended string value in string format for UI display.
-
#requires_restart ⇒ ::Google::Protobuf::BoolValue
Indicates whether changing this flag will trigger a database restart.
-
#type ⇒ ::Google::Cloud::Sql::V1::SqlFlagType
The type of the flag.
Instance Attribute Details
#allowed_int_values ⇒ ::Array<::Integer>
Returns Use this field if only certain integers are accepted. Can be combined with min_value and max_value to add additional values.
108 109 110 111 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_flags.rb', line 108 class Flag include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#allowed_string_values ⇒ ::Array<::String>
Returns For STRING flags, a list of strings that the value can be set to.
108 109 110 111 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_flags.rb', line 108 class Flag include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#applies_to ⇒ ::Array<::Google::Cloud::Sql::V1::SqlDatabaseVersion>
Returns The database version this flag applies to. Can be
MySQL instances: MYSQL_8_0, MYSQL_8_0_18, MYSQL_8_0_26, MYSQL_5_7,
or MYSQL_5_6. PostgreSQL instances: POSTGRES_9_6, POSTGRES_10,
POSTGRES_11 or POSTGRES_12. SQL Server instances:
SQLSERVER_2017_STANDARD, SQLSERVER_2017_ENTERPRISE,
SQLSERVER_2017_EXPRESS, SQLSERVER_2017_WEB, SQLSERVER_2019_STANDARD,
SQLSERVER_2019_ENTERPRISE, SQLSERVER_2019_EXPRESS, or
SQLSERVER_2019_WEB.
See the complete
list.
108 109 110 111 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_flags.rb', line 108 class Flag include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#flag_scope ⇒ ::Google::Cloud::Sql::V1::SqlFlagScope
Returns Scope of flag.
108 109 110 111 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_flags.rb', line 108 class Flag include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#in_beta ⇒ ::Google::Protobuf::BoolValue
Returns Whether or not the flag is considered in beta.
108 109 110 111 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_flags.rb', line 108 class Flag include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#kind ⇒ ::String
Returns This is always sql#flag.
108 109 110 111 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_flags.rb', line 108 class Flag include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#max_value ⇒ ::Google::Protobuf::Int64Value
Returns For INTEGER flags, the maximum allowed value.
108 109 110 111 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_flags.rb', line 108 class Flag include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#min_value ⇒ ::Google::Protobuf::Int64Value
Returns For INTEGER flags, the minimum allowed value.
108 109 110 111 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_flags.rb', line 108 class Flag include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns This is the name of the flag. Flag names always use underscores, not
hyphens, for example: max_allowed_packet.
108 109 110 111 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_flags.rb', line 108 class Flag include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#recommended_int_value ⇒ ::Google::Protobuf::Int64Value
Returns Recommended int value in integer format for UI display.
Note: The following fields are mutually exclusive: recommended_int_value, recommended_string_value. If a field in that set is populated, all other fields in the set will automatically be cleared.
108 109 110 111 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_flags.rb', line 108 class Flag include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#recommended_string_value ⇒ ::String
Returns Recommended string value in string format for UI display.
Note: The following fields are mutually exclusive: recommended_string_value, recommended_int_value. If a field in that set is populated, all other fields in the set will automatically be cleared.
108 109 110 111 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_flags.rb', line 108 class Flag include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#requires_restart ⇒ ::Google::Protobuf::BoolValue
Returns Indicates whether changing this flag will trigger a database restart. Only applicable to Second Generation instances.
108 109 110 111 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_flags.rb', line 108 class Flag include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#type ⇒ ::Google::Cloud::Sql::V1::SqlFlagType
Returns The type of the flag. Flags are typed to being BOOLEAN, STRING,
INTEGER or NONE. NONE is used for flags that do not take a
value, such as skip_grant_tables.
108 109 110 111 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_flags.rb', line 108 class Flag include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |