Class: Google::Cloud::Sql::V1::GenerateEphemeralCertRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::GenerateEphemeralCertRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_connect.rb
Overview
Ephemeral certificate creation request.
Instance Attribute Summary collapse
-
#access_token ⇒ ::String
Optional.
-
#instance ⇒ ::String
Cloud SQL instance ID.
-
#project ⇒ ::String
Project ID of the project that contains the instance.
-
#public_key ⇒ ::String
PEM encoded public key to include in the signed certificate.
-
#read_time ⇒ ::Google::Protobuf::Timestamp
Optional.
-
#valid_duration ⇒ ::Google::Protobuf::Duration
Optional.
Instance Attribute Details
#access_token ⇒ ::String
Returns Optional. Access token to include in the signed certificate.
174 175 176 177 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_connect.rb', line 174 class GenerateEphemeralCertRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#instance ⇒ ::String
Returns Cloud SQL instance ID. This does not include the project ID.
174 175 176 177 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_connect.rb', line 174 class GenerateEphemeralCertRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#project ⇒ ::String
Returns Project ID of the project that contains the instance.
174 175 176 177 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_connect.rb', line 174 class GenerateEphemeralCertRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#public_key ⇒ ::String
Returns PEM encoded public key to include in the signed certificate.
174 175 176 177 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_connect.rb', line 174 class GenerateEphemeralCertRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#read_time ⇒ ::Google::Protobuf::Timestamp
Returns Optional. Optional snapshot read timestamp to trade freshness for performance.
174 175 176 177 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_connect.rb', line 174 class GenerateEphemeralCertRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#valid_duration ⇒ ::Google::Protobuf::Duration
Returns Optional. If set, it will contain the cert valid duration.
174 175 176 177 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_connect.rb', line 174 class GenerateEphemeralCertRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |