Class: Google::Cloud::Sql::V1::ImportContext::SqlBakImportOptions
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::ImportContext::SqlBakImportOptions
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb
Defined Under Namespace
Classes: EncryptionOptions
Instance Attribute Summary collapse
-
#bak_type ⇒ ::Google::Cloud::Sql::V1::BakType
Type of the bak content, FULL or DIFF.
- #encryption_options ⇒ ::Google::Cloud::Sql::V1::ImportContext::SqlBakImportOptions::EncryptionOptions
-
#no_recovery ⇒ ::Google::Protobuf::BoolValue
Whether or not the backup importing will restore database with NORECOVERY option.
-
#recovery_only ⇒ ::Google::Protobuf::BoolValue
Whether or not the backup importing request will just bring database online without downloading Bak content only one of "no_recovery" and "recovery_only" can be true otherwise error will return.
-
#stop_at ⇒ ::Google::Protobuf::Timestamp
Optional.
-
#stop_at_mark ⇒ ::String
Optional.
-
#striped ⇒ ::Google::Protobuf::BoolValue
Whether or not the backup set being restored is striped.
Instance Attribute Details
#bak_type ⇒ ::Google::Cloud::Sql::V1::BakType
Returns Type of the bak content, FULL or DIFF.
726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 726 class SqlBakImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] cert_path # @return [::String] # Path to the Certificate (.cer) in Cloud Storage, in the form # `gs://bucketName/fileName`. The instance must have # write permissions to the bucket and read access to the file. # @!attribute [rw] pvk_path # @return [::String] # Path to the Certificate Private Key (.pvk) in Cloud Storage, in the # form `gs://bucketName/fileName`. The instance must have # write permissions to the bucket and read access to the file. # @!attribute [rw] pvk_password # @return [::String] # Password that encrypts the private key # @!attribute [rw] keep_encrypted # @return [::Google::Protobuf::BoolValue] # Optional. Whether the imported file remains encrypted. class EncryptionOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#encryption_options ⇒ ::Google::Cloud::Sql::V1::ImportContext::SqlBakImportOptions::EncryptionOptions
726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 726 class SqlBakImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] cert_path # @return [::String] # Path to the Certificate (.cer) in Cloud Storage, in the form # `gs://bucketName/fileName`. The instance must have # write permissions to the bucket and read access to the file. # @!attribute [rw] pvk_path # @return [::String] # Path to the Certificate Private Key (.pvk) in Cloud Storage, in the # form `gs://bucketName/fileName`. The instance must have # write permissions to the bucket and read access to the file. # @!attribute [rw] pvk_password # @return [::String] # Password that encrypts the private key # @!attribute [rw] keep_encrypted # @return [::Google::Protobuf::BoolValue] # Optional. Whether the imported file remains encrypted. class EncryptionOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#no_recovery ⇒ ::Google::Protobuf::BoolValue
Returns Whether or not the backup importing will restore database with NORECOVERY option. Applies only to Cloud SQL for SQL Server.
726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 726 class SqlBakImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] cert_path # @return [::String] # Path to the Certificate (.cer) in Cloud Storage, in the form # `gs://bucketName/fileName`. The instance must have # write permissions to the bucket and read access to the file. # @!attribute [rw] pvk_path # @return [::String] # Path to the Certificate Private Key (.pvk) in Cloud Storage, in the # form `gs://bucketName/fileName`. The instance must have # write permissions to the bucket and read access to the file. # @!attribute [rw] pvk_password # @return [::String] # Password that encrypts the private key # @!attribute [rw] keep_encrypted # @return [::Google::Protobuf::BoolValue] # Optional. Whether the imported file remains encrypted. class EncryptionOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#recovery_only ⇒ ::Google::Protobuf::BoolValue
Returns Whether or not the backup importing request will just bring database online without downloading Bak content only one of "no_recovery" and "recovery_only" can be true otherwise error will return. Applies only to Cloud SQL for SQL Server.
726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 726 class SqlBakImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] cert_path # @return [::String] # Path to the Certificate (.cer) in Cloud Storage, in the form # `gs://bucketName/fileName`. The instance must have # write permissions to the bucket and read access to the file. # @!attribute [rw] pvk_path # @return [::String] # Path to the Certificate Private Key (.pvk) in Cloud Storage, in the # form `gs://bucketName/fileName`. The instance must have # write permissions to the bucket and read access to the file. # @!attribute [rw] pvk_password # @return [::String] # Password that encrypts the private key # @!attribute [rw] keep_encrypted # @return [::Google::Protobuf::BoolValue] # Optional. Whether the imported file remains encrypted. class EncryptionOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#stop_at ⇒ ::Google::Protobuf::Timestamp
Returns Optional. The timestamp when the import should stop. This timestamp is in
the RFC 3339 format (for example,
2023-10-01T16:19:00.094). This field is equivalent to the STOPAT
keyword and applies to Cloud SQL for SQL Server only.
726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 726 class SqlBakImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] cert_path # @return [::String] # Path to the Certificate (.cer) in Cloud Storage, in the form # `gs://bucketName/fileName`. The instance must have # write permissions to the bucket and read access to the file. # @!attribute [rw] pvk_path # @return [::String] # Path to the Certificate Private Key (.pvk) in Cloud Storage, in the # form `gs://bucketName/fileName`. The instance must have # write permissions to the bucket and read access to the file. # @!attribute [rw] pvk_password # @return [::String] # Password that encrypts the private key # @!attribute [rw] keep_encrypted # @return [::Google::Protobuf::BoolValue] # Optional. Whether the imported file remains encrypted. class EncryptionOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#stop_at_mark ⇒ ::String
Returns Optional. The marked transaction where the import should stop. This field is equivalent to the STOPATMARK keyword and applies to Cloud SQL for SQL Server only.
726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 726 class SqlBakImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] cert_path # @return [::String] # Path to the Certificate (.cer) in Cloud Storage, in the form # `gs://bucketName/fileName`. The instance must have # write permissions to the bucket and read access to the file. # @!attribute [rw] pvk_path # @return [::String] # Path to the Certificate Private Key (.pvk) in Cloud Storage, in the # form `gs://bucketName/fileName`. The instance must have # write permissions to the bucket and read access to the file. # @!attribute [rw] pvk_password # @return [::String] # Password that encrypts the private key # @!attribute [rw] keep_encrypted # @return [::Google::Protobuf::BoolValue] # Optional. Whether the imported file remains encrypted. class EncryptionOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#striped ⇒ ::Google::Protobuf::BoolValue
Returns Whether or not the backup set being restored is striped. Applies only to Cloud SQL for SQL Server.
726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 726 class SqlBakImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] cert_path # @return [::String] # Path to the Certificate (.cer) in Cloud Storage, in the form # `gs://bucketName/fileName`. The instance must have # write permissions to the bucket and read access to the file. # @!attribute [rw] pvk_path # @return [::String] # Path to the Certificate Private Key (.pvk) in Cloud Storage, in the # form `gs://bucketName/fileName`. The instance must have # write permissions to the bucket and read access to the file. # @!attribute [rw] pvk_password # @return [::String] # Password that encrypts the private key # @!attribute [rw] keep_encrypted # @return [::Google::Protobuf::BoolValue] # Optional. Whether the imported file remains encrypted. class EncryptionOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |