Class: Google::Cloud::Sql::V1::ImportContext::SqlImportOptions::PostgresImportOptions
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::ImportContext::SqlImportOptions::PostgresImportOptions
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb
Instance Attribute Summary collapse
-
#clean ⇒ ::Google::Protobuf::BoolValue
Optional.
-
#if_exists ⇒ ::Google::Protobuf::BoolValue
Optional.
Instance Attribute Details
#clean ⇒ ::Google::Protobuf::BoolValue
Returns Optional. The --clean flag for the pg_restore utility. This flag applies only if you enabled Cloud SQL to import files in parallel.
662 663 664 665 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 662 class PostgresImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#if_exists ⇒ ::Google::Protobuf::BoolValue
Returns Optional. The --if-exists flag for the pg_restore utility. This flag applies only if you enabled Cloud SQL to import files in parallel.
662 663 664 665 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 662 class PostgresImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |