Class: Google::Cloud::Sql::V1::InstancesRestoreBackupRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::InstancesRestoreBackupRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb
Overview
Database instance restore backup request.
Instance Attribute Summary collapse
-
#backup ⇒ ::String
The name of the backup that's used to restore a Cloud SQL instance: Format: projects/{project-id}/backups/{backup-uid}.
-
#backupdr_backup ⇒ ::String
The name of the backup that's used to restore a Cloud SQL instance: Format: "projects/{project-id}/locations/{location}/backupVaults/{backupvault}/dataSources/{datasource}/backups/{backup-uid}".
-
#restore_backup_context ⇒ ::Google::Cloud::Sql::V1::RestoreBackupContext
Parameters required to perform the restore backup operation.
-
#restore_instance_clear_overrides_field_names ⇒ ::Array<::String>
Optional.
-
#restore_instance_settings ⇒ ::Google::Cloud::Sql::V1::DatabaseInstance
Optional.
Instance Attribute Details
#backup ⇒ ::String
Returns The name of the backup that's used to restore a Cloud SQL instance: Format: projects/{project-id}/backups/{backup-uid}. Only one of restore_backup_context, backup, backupdr_backup can be passed to the input.
862 863 864 865 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 862 class InstancesRestoreBackupRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#backupdr_backup ⇒ ::String
Returns The name of the backup that's used to restore a Cloud SQL instance: Format: "projects/{project-id}/locations/{location}/backupVaults/{backupvault}/dataSources/{datasource}/backups/{backup-uid}". Only one of restore_backup_context, backup, backupdr_backup can be passed to the input.
862 863 864 865 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 862 class InstancesRestoreBackupRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#restore_backup_context ⇒ ::Google::Cloud::Sql::V1::RestoreBackupContext
Returns Parameters required to perform the restore backup operation.
862 863 864 865 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 862 class InstancesRestoreBackupRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#restore_instance_clear_overrides_field_names ⇒ ::Array<::String>
Returns Optional. This field has the same purpose as restore_instance_settings, changes any instance settings stored in the backup you are restoring from. With the difference that these fields are cleared in the settings.
862 863 864 865 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 862 class InstancesRestoreBackupRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#restore_instance_settings ⇒ ::Google::Cloud::Sql::V1::DatabaseInstance
Returns Optional. By using this parameter, Cloud SQL overrides any instance settings stored in the backup you are restoring from. You can't change the instance's major database version and you can only increase the disk size. You can use this field to restore new instances only. This field is not applicable for restore to existing instances.
862 863 864 865 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 862 class InstancesRestoreBackupRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |