Module: Google::Cloud::Sql::V1::IpConfiguration::SslMode
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb
Overview
The SSL options for database connections.
Constant Summary collapse
- SSL_MODE_UNSPECIFIED =
The SSL mode is unknown.
0- ALLOW_UNENCRYPTED_AND_ENCRYPTED =
Allow non-SSL/non-TLS and SSL/TLS connections. For SSL connections to MySQL and PostgreSQL, the client certificate isn't verified.
When this value is used, the legacy
require_sslflag must be false or cleared to avoid a conflict between the values of the two flags. 1- ENCRYPTED_ONLY =
Only allow connections encrypted with SSL/TLS. For SSL connections to MySQL and PostgreSQL, the client certificate isn't verified.
When this value is used, the legacy
require_sslflag must be false or cleared to avoid a conflict between the values of the two flags. 2- TRUSTED_CLIENT_CERTIFICATE_REQUIRED =
Only allow connections encrypted with SSL/TLS and with valid client certificates.
When this value is used, the legacy
require_sslflag must be true or cleared to avoid the conflict between values of two flags. PostgreSQL clients or users that connect using IAM database authentication must use either the Cloud SQL Auth Proxy or Cloud SQL Connectors to enforce client identity verification.Only applicable to MySQL and PostgreSQL. Not applicable to SQL Server.
3