Class: Google::Cloud::Sql::V1::ListBackupsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::ListBackupsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_backups.rb
Overview
The request payload to list the backups.
Instance Attribute Summary collapse
-
#filter ⇒ ::String
Multiple filter queries are separated by spaces.
-
#page_size ⇒ ::Integer
The maximum number of backups to return per response.
-
#page_token ⇒ ::String
A page token, received from a previous
ListBackupscall. -
#parent ⇒ ::String
Required.
Instance Attribute Details
#filter ⇒ ::String
Returns Multiple filter queries are separated by spaces. For example, 'instance:abc AND type:FINAL, 'location:us', 'backupInterval.startTime>=1950-01-01T01:01:25.771Z'. You can filter by type, instance, backupInterval.startTime (creation time), or location.
72 73 74 75 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backups.rb', line 72 class ListBackupsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
The maximum number of backups to return per response. The service might return fewer backups than this value. If a value for this parameter isn't specified, then, at most, 500 backups are returned. The maximum value is 2,000. Any values that you set, which are greater than 2,000, are changed to 2,000.
72 73 74 75 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backups.rb', line 72 class ListBackupsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns A page token, received from a previous ListBackups call.
Provide this to retrieve the subsequent page.
When paginating, all other parameters provided to ListBackups must match
the call that provided the page token.
72 73 74 75 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backups.rb', line 72 class ListBackupsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The parent that owns this collection of backups. Format: projects/{project}.
72 73 74 75 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_backups.rb', line 72 class ListBackupsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |