Class: Google::Cloud::Sql::V1::LocationPreference

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb

Overview

Preferred location. This specifies where a Cloud SQL instance is located. Note that if the preferred location is not available, the instance will be located as close as possible within the region. Only one location may be specified.

Instance Attribute Summary collapse

Instance Attribute Details

#follow_gae_application::String

Deprecated.

This field is deprecated and may be removed in the next major version update.

Returns The App Engine application to follow, it must be in the same region as the Cloud SQL instance. WARNING: Changing this might restart the instance.

Returns:

  • (::String)

    The App Engine application to follow, it must be in the same region as the Cloud SQL instance. WARNING: Changing this might restart the instance.



1036
1037
1038
1039
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1036

class LocationPreference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#kind::String

Returns This is always sql#locationPreference.

Returns:

  • (::String)

    This is always sql#locationPreference.



1036
1037
1038
1039
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1036

class LocationPreference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#secondary_zone::String

Returns The preferred Compute Engine zone for the secondary/failover (for example: us-central1-a, us-central1-b, etc.). To disable this field, set it to 'no_secondary_zone'.

Returns:

  • (::String)

    The preferred Compute Engine zone for the secondary/failover (for example: us-central1-a, us-central1-b, etc.). To disable this field, set it to 'no_secondary_zone'.



1036
1037
1038
1039
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1036

class LocationPreference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#zone::String

Returns The preferred Compute Engine zone (for example: us-central1-a, us-central1-b, etc.). WARNING: Changing this might restart the instance.

Returns:

  • (::String)

    The preferred Compute Engine zone (for example: us-central1-a, us-central1-b, etc.). WARNING: Changing this might restart the instance.



1036
1037
1038
1039
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1036

class LocationPreference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end