Class: Google::Cloud::Sql::V1::MySqlReplicaConfiguration
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::MySqlReplicaConfiguration
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb
Overview
Read-replica configuration specific to MySQL databases.
Instance Attribute Summary collapse
-
#ca_certificate ⇒ ::String
PEM representation of the trusted CA's x509 certificate.
-
#client_certificate ⇒ ::String
PEM representation of the replica's x509 certificate.
-
#client_key ⇒ ::String
PEM representation of the replica's private key.
-
#connect_retry_interval ⇒ ::Google::Protobuf::Int32Value
Seconds to wait between connect retries.
-
#dump_file_path ⇒ ::String
Path to a SQL dump file in Google Cloud Storage from which the replica instance is to be created.
-
#kind ⇒ ::String
This is always
sql#mysqlReplicaConfiguration. -
#master_heartbeat_period ⇒ ::Google::Protobuf::Int64Value
Interval in milliseconds between replication heartbeats.
-
#password ⇒ ::String
The password for the replication connection.
-
#ssl_cipher ⇒ ::String
A list of permissible ciphers to use for SSL encryption.
-
#username ⇒ ::String
The username for the replication connection.
-
#verify_server_certificate ⇒ ::Google::Protobuf::BoolValue
Whether or not to check the primary instance's Common Name value in the certificate that it sends during the SSL handshake.
Instance Attribute Details
#ca_certificate ⇒ ::String
Returns PEM representation of the trusted CA's x509 certificate.
1158 1159 1160 1161 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1158 class MySqlReplicaConfiguration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#client_certificate ⇒ ::String
Returns PEM representation of the replica's x509 certificate.
1158 1159 1160 1161 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1158 class MySqlReplicaConfiguration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#client_key ⇒ ::String
Returns PEM representation of the replica's private key. The corresponding public key is encoded in the client's certificate.
1158 1159 1160 1161 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1158 class MySqlReplicaConfiguration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#connect_retry_interval ⇒ ::Google::Protobuf::Int32Value
Returns Seconds to wait between connect retries. MySQL's default is 60 seconds.
1158 1159 1160 1161 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1158 class MySqlReplicaConfiguration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#dump_file_path ⇒ ::String
Returns Path to a SQL dump file in Google Cloud Storage from which the replica instance is to be created. The URI is in the form gs://bucketName/fileName. Compressed gzip files (.gz) are also supported. Dumps have the binlog co-ordinates from which replication begins. This can be accomplished by setting --master-data to 1 when using mysqldump.
1158 1159 1160 1161 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1158 class MySqlReplicaConfiguration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#kind ⇒ ::String
Returns This is always sql#mysqlReplicaConfiguration.
1158 1159 1160 1161 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1158 class MySqlReplicaConfiguration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#master_heartbeat_period ⇒ ::Google::Protobuf::Int64Value
Returns Interval in milliseconds between replication heartbeats.
1158 1159 1160 1161 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1158 class MySqlReplicaConfiguration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#password ⇒ ::String
Returns The password for the replication connection.
1158 1159 1160 1161 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1158 class MySqlReplicaConfiguration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#ssl_cipher ⇒ ::String
Returns A list of permissible ciphers to use for SSL encryption.
1158 1159 1160 1161 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1158 class MySqlReplicaConfiguration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#username ⇒ ::String
Returns The username for the replication connection.
1158 1159 1160 1161 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1158 class MySqlReplicaConfiguration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#verify_server_certificate ⇒ ::Google::Protobuf::BoolValue
Returns Whether or not to check the primary instance's Common Name value in the certificate that it sends during the SSL handshake.
1158 1159 1160 1161 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1158 class MySqlReplicaConfiguration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |