Class: Google::Cloud::Sql::V1::PasswordValidationPolicy
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::PasswordValidationPolicy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb
Overview
Database instance local user password validation policy. This message defines the password policy for local database users. When enabled, it enforces constraints on password complexity, length, and reuse. Keep this policy enabled to help prevent unauthorized access.
Defined Under Namespace
Modules: Complexity
Instance Attribute Summary collapse
-
#complexity ⇒ ::Google::Cloud::Sql::V1::PasswordValidationPolicy::Complexity
The complexity of the password.
-
#disallow_compromised_credentials ⇒ ::Google::Protobuf::BoolValue
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#disallow_username_substring ⇒ ::Google::Protobuf::BoolValue
Disallow username as a part of the password.
-
#enable_password_policy ⇒ ::Google::Protobuf::BoolValue
Whether to enable the password policy or not.
-
#min_length ⇒ ::Google::Protobuf::Int32Value
Minimum number of characters allowed.
-
#password_change_interval ⇒ ::Google::Protobuf::Duration
Minimum interval after which the password can be changed.
-
#reuse_interval ⇒ ::Google::Protobuf::Int32Value
Number of previous passwords that cannot be reused.
Instance Attribute Details
#complexity ⇒ ::Google::Cloud::Sql::V1::PasswordValidationPolicy::Complexity
Returns The complexity of the password.
1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 1571 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1558 class PasswordValidationPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The complexity choices of the password. module Complexity # Complexity check is not specified. COMPLEXITY_UNSPECIFIED = 0 # A combination of lowercase, uppercase, numeric, and non-alphanumeric # characters. COMPLEXITY_DEFAULT = 1 end end |
#disallow_compromised_credentials ⇒ ::Google::Protobuf::BoolValue
This field is deprecated and may be removed in the next major version update.
Returns This field is deprecated and will be removed in a future version of the API.
1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 1571 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1558 class PasswordValidationPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The complexity choices of the password. module Complexity # Complexity check is not specified. COMPLEXITY_UNSPECIFIED = 0 # A combination of lowercase, uppercase, numeric, and non-alphanumeric # characters. COMPLEXITY_DEFAULT = 1 end end |
#disallow_username_substring ⇒ ::Google::Protobuf::BoolValue
Returns Disallow username as a part of the password.
1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 1571 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1558 class PasswordValidationPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The complexity choices of the password. module Complexity # Complexity check is not specified. COMPLEXITY_UNSPECIFIED = 0 # A combination of lowercase, uppercase, numeric, and non-alphanumeric # characters. COMPLEXITY_DEFAULT = 1 end end |
#enable_password_policy ⇒ ::Google::Protobuf::BoolValue
Returns Whether to enable the password policy or not. When enabled, passwords must meet complexity requirements. Keep this policy enabled to help prevent unauthorized access. Disabling this policy allows weak passwords.
1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 1571 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1558 class PasswordValidationPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The complexity choices of the password. module Complexity # Complexity check is not specified. COMPLEXITY_UNSPECIFIED = 0 # A combination of lowercase, uppercase, numeric, and non-alphanumeric # characters. COMPLEXITY_DEFAULT = 1 end end |
#min_length ⇒ ::Google::Protobuf::Int32Value
Returns Minimum number of characters allowed.
1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 1571 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1558 class PasswordValidationPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The complexity choices of the password. module Complexity # Complexity check is not specified. COMPLEXITY_UNSPECIFIED = 0 # A combination of lowercase, uppercase, numeric, and non-alphanumeric # characters. COMPLEXITY_DEFAULT = 1 end end |
#password_change_interval ⇒ ::Google::Protobuf::Duration
Returns Minimum interval after which the password can be changed. This flag is only supported for PostgreSQL.
1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 1571 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1558 class PasswordValidationPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The complexity choices of the password. module Complexity # Complexity check is not specified. COMPLEXITY_UNSPECIFIED = 0 # A combination of lowercase, uppercase, numeric, and non-alphanumeric # characters. COMPLEXITY_DEFAULT = 1 end end |
#reuse_interval ⇒ ::Google::Protobuf::Int32Value
Returns Number of previous passwords that cannot be reused.
1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 1571 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1558 class PasswordValidationPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The complexity choices of the password. module Complexity # Complexity check is not specified. COMPLEXITY_UNSPECIFIED = 0 # A combination of lowercase, uppercase, numeric, and non-alphanumeric # characters. COMPLEXITY_DEFAULT = 1 end end |