Class: Google::Cloud::Sql::V1::PerformanceCaptureConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::PerformanceCaptureConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb
Overview
Performance capture configuration.
Defined Under Namespace
Modules: TransactionKillType
Instance Attribute Summary collapse
-
#cpu_utilization_threshold_percent ⇒ ::Integer
Optional.
-
#enabled ⇒ ::Boolean
Optional.
-
#history_list_length_threshold_count ⇒ ::Integer
Optional.
-
#memory_usage_threshold_percent ⇒ ::Integer
Optional.
-
#probe_threshold ⇒ ::Integer
Optional.
-
#probing_interval_seconds ⇒ ::Integer
Optional.
-
#running_threads_threshold ⇒ ::Integer
Optional.
-
#seconds_behind_source_threshold ⇒ ::Integer
Optional.
-
#semaphore_wait_threshold_count ⇒ ::Integer
Optional.
-
#transaction_duration_threshold ⇒ ::Integer
Optional.
-
#transaction_kill_excluded_user_hosts ⇒ ::Array<::String>
Optional.
-
#transaction_kill_threshold_seconds ⇒ ::Integer
Optional.
-
#transaction_kill_type ⇒ ::Google::Cloud::Sql::V1::PerformanceCaptureConfig::TransactionKillType
Optional.
-
#transaction_lock_wait_threshold_count ⇒ ::Integer
Optional.
Instance Attribute Details
#cpu_utilization_threshold_percent ⇒ ::Integer
Returns Optional. Specifies the minimum percentage of CPU utilization to trigger
the performance capture. Valid integers range from 10 to 99. Enter 0
to disable the check.
1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1971 class PerformanceCaptureConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the categories of long-running transactions eligible for automatic # termination by the Performance Capture. module TransactionKillType # Unspecified. TRANSACTION_KILL_TYPE_UNSPECIFIED = 0 # Only read-only transactions are eligible for termination. READ_ONLY_TRANSACTIONS = 1 # All transactions are eligible for termination, including those with write # operations (such as INSERT, UPDATE, DELETE, or DDL). ALL_TRANSACTIONS = 2 end end |
#enabled ⇒ ::Boolean
Returns Optional. Enables or disables the performance capture feature.
1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1971 class PerformanceCaptureConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the categories of long-running transactions eligible for automatic # termination by the Performance Capture. module TransactionKillType # Unspecified. TRANSACTION_KILL_TYPE_UNSPECIFIED = 0 # Only read-only transactions are eligible for termination. READ_ONLY_TRANSACTIONS = 1 # All transactions are eligible for termination, including those with write # operations (such as INSERT, UPDATE, DELETE, or DDL). ALL_TRANSACTIONS = 2 end end |
#history_list_length_threshold_count ⇒ ::Integer
Returns Optional. Specifies the minimum number of undo log entries in the history
list length to trigger the performance capture. Valid integers range from
10000 to 10000000. Enter 0 to disable the check.
1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1971 class PerformanceCaptureConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the categories of long-running transactions eligible for automatic # termination by the Performance Capture. module TransactionKillType # Unspecified. TRANSACTION_KILL_TYPE_UNSPECIFIED = 0 # Only read-only transactions are eligible for termination. READ_ONLY_TRANSACTIONS = 1 # All transactions are eligible for termination, including those with write # operations (such as INSERT, UPDATE, DELETE, or DDL). ALL_TRANSACTIONS = 2 end end |
#memory_usage_threshold_percent ⇒ ::Integer
Returns Optional. Specifies the minimum percentage of memory usage to trigger the
performance capture.
Valid integers range from 10 to 99. Enter 0 to disable the check.
1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1971 class PerformanceCaptureConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the categories of long-running transactions eligible for automatic # termination by the Performance Capture. module TransactionKillType # Unspecified. TRANSACTION_KILL_TYPE_UNSPECIFIED = 0 # Only read-only transactions are eligible for termination. READ_ONLY_TRANSACTIONS = 1 # All transactions are eligible for termination, including those with write # operations (such as INSERT, UPDATE, DELETE, or DDL). ALL_TRANSACTIONS = 2 end end |
#probe_threshold ⇒ ::Integer
Returns Optional. Specifies the minimum number of consecutive probe threshold that triggers performance capture.
1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1971 class PerformanceCaptureConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the categories of long-running transactions eligible for automatic # termination by the Performance Capture. module TransactionKillType # Unspecified. TRANSACTION_KILL_TYPE_UNSPECIFIED = 0 # Only read-only transactions are eligible for termination. READ_ONLY_TRANSACTIONS = 1 # All transactions are eligible for termination, including those with write # operations (such as INSERT, UPDATE, DELETE, or DDL). ALL_TRANSACTIONS = 2 end end |
#probing_interval_seconds ⇒ ::Integer
Returns Optional. Specifies the interval in seconds between consecutive probes that check if any trigger condition thresholds have been reached.
1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1971 class PerformanceCaptureConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the categories of long-running transactions eligible for automatic # termination by the Performance Capture. module TransactionKillType # Unspecified. TRANSACTION_KILL_TYPE_UNSPECIFIED = 0 # Only read-only transactions are eligible for termination. READ_ONLY_TRANSACTIONS = 1 # All transactions are eligible for termination, including those with write # operations (such as INSERT, UPDATE, DELETE, or DDL). ALL_TRANSACTIONS = 2 end end |
#running_threads_threshold ⇒ ::Integer
Returns Optional. Specifies the minimum number of MySQL Threads_running to
trigger the performance capture on the primary instance.
1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1971 class PerformanceCaptureConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the categories of long-running transactions eligible for automatic # termination by the Performance Capture. module TransactionKillType # Unspecified. TRANSACTION_KILL_TYPE_UNSPECIFIED = 0 # Only read-only transactions are eligible for termination. READ_ONLY_TRANSACTIONS = 1 # All transactions are eligible for termination, including those with write # operations (such as INSERT, UPDATE, DELETE, or DDL). ALL_TRANSACTIONS = 2 end end |
#seconds_behind_source_threshold ⇒ ::Integer
Returns Optional. Specifies the minimum number of seconds replica must be lagging behind primary instance to trigger the performance capture on replica.
1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1971 class PerformanceCaptureConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the categories of long-running transactions eligible for automatic # termination by the Performance Capture. module TransactionKillType # Unspecified. TRANSACTION_KILL_TYPE_UNSPECIFIED = 0 # Only read-only transactions are eligible for termination. READ_ONLY_TRANSACTIONS = 1 # All transactions are eligible for termination, including those with write # operations (such as INSERT, UPDATE, DELETE, or DDL). ALL_TRANSACTIONS = 2 end end |
#semaphore_wait_threshold_count ⇒ ::Integer
Returns Optional. Specifies the minimum allowed number of semaphore waits to
trigger the performance capture. Valid integers range from 10 to 10000.
Enter 0 to disable the check.
1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1971 class PerformanceCaptureConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the categories of long-running transactions eligible for automatic # termination by the Performance Capture. module TransactionKillType # Unspecified. TRANSACTION_KILL_TYPE_UNSPECIFIED = 0 # Only read-only transactions are eligible for termination. READ_ONLY_TRANSACTIONS = 1 # All transactions are eligible for termination, including those with write # operations (such as INSERT, UPDATE, DELETE, or DDL). ALL_TRANSACTIONS = 2 end end |
#transaction_duration_threshold ⇒ ::Integer
Returns Optional. Specifies the amount of time in seconds that a transaction needs to have been open before the watcher starts recording it.
1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1971 class PerformanceCaptureConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the categories of long-running transactions eligible for automatic # termination by the Performance Capture. module TransactionKillType # Unspecified. TRANSACTION_KILL_TYPE_UNSPECIFIED = 0 # Only read-only transactions are eligible for termination. READ_ONLY_TRANSACTIONS = 1 # All transactions are eligible for termination, including those with write # operations (such as INSERT, UPDATE, DELETE, or DDL). ALL_TRANSACTIONS = 2 end end |
#transaction_kill_excluded_user_hosts ⇒ ::Array<::String>
Returns Optional. Specifies a customer-defined list of users to exclude from
transaction termination. Entries can be in the format 'user@host' or just
'user'. A standalone 'user' implies 'user@%', excluding the user from any
host. Wildcard '%' is allowed in the host part of the 'user@host' format.
Example: ["app_user", "db_admin@10.1.2.3", "report_user@%"].
1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1971 class PerformanceCaptureConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the categories of long-running transactions eligible for automatic # termination by the Performance Capture. module TransactionKillType # Unspecified. TRANSACTION_KILL_TYPE_UNSPECIFIED = 0 # Only read-only transactions are eligible for termination. READ_ONLY_TRANSACTIONS = 1 # All transactions are eligible for termination, including those with write # operations (such as INSERT, UPDATE, DELETE, or DDL). ALL_TRANSACTIONS = 2 end end |
#transaction_kill_threshold_seconds ⇒ ::Integer
Returns Optional. Specifies the amount of time in seconds that a transaction needs
to have been open before the watcher starts terminating it. Valid integers
range from 60 to 604800 (7 days). Enter 0 to disable. If enabled
(i.e., > 0), this value must be greater than or equal to
transaction_duration_threshold. Configurations where
0 < transaction_kill_threshold_seconds < transaction_duration_threshold
will be rejected.
1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1971 class PerformanceCaptureConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the categories of long-running transactions eligible for automatic # termination by the Performance Capture. module TransactionKillType # Unspecified. TRANSACTION_KILL_TYPE_UNSPECIFIED = 0 # Only read-only transactions are eligible for termination. READ_ONLY_TRANSACTIONS = 1 # All transactions are eligible for termination, including those with write # operations (such as INSERT, UPDATE, DELETE, or DDL). ALL_TRANSACTIONS = 2 end end |
#transaction_kill_type ⇒ ::Google::Cloud::Sql::V1::PerformanceCaptureConfig::TransactionKillType
Returns Optional. Determines which transactions are allowed to be terminated when
they exceed transaction_kill_threshold_seconds. This allows protecting
write-heavy transactions from auto-termination if desired. Defaults to
READ_ONLY_TRANSACTIONS if unspecified.
1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1971 class PerformanceCaptureConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the categories of long-running transactions eligible for automatic # termination by the Performance Capture. module TransactionKillType # Unspecified. TRANSACTION_KILL_TYPE_UNSPECIFIED = 0 # Only read-only transactions are eligible for termination. READ_ONLY_TRANSACTIONS = 1 # All transactions are eligible for termination, including those with write # operations (such as INSERT, UPDATE, DELETE, or DDL). ALL_TRANSACTIONS = 2 end end |
#transaction_lock_wait_threshold_count ⇒ ::Integer
Returns Optional. Specifies the minimum allowed number of transactions in lock wait
state to trigger the performance capture. Valid integers range from 10 to
10000. Enter 0 to disable the check.
1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1971 class PerformanceCaptureConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the categories of long-running transactions eligible for automatic # termination by the Performance Capture. module TransactionKillType # Unspecified. TRANSACTION_KILL_TYPE_UNSPECIFIED = 0 # Only read-only transactions are eligible for termination. READ_ONLY_TRANSACTIONS = 1 # All transactions are eligible for termination, including those with write # operations (such as INSERT, UPDATE, DELETE, or DDL). ALL_TRANSACTIONS = 2 end end |