Class: Google::Cloud::Sql::V1::PerformanceCaptureConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::PerformanceCaptureConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb
Overview
Performance capture configuration.
Instance Attribute Summary collapse
-
#enabled ⇒ ::Boolean
Optional.
-
#probe_threshold ⇒ ::Integer
Optional.
-
#probing_interval_seconds ⇒ ::Integer
Optional.
-
#running_threads_threshold ⇒ ::Integer
Optional.
-
#seconds_behind_source_threshold ⇒ ::Integer
Optional.
-
#transaction_duration_threshold ⇒ ::Integer
Optional.
Instance Attribute Details
#enabled ⇒ ::Boolean
Returns Optional. Enables or disables the performance capture feature.
1891 1892 1893 1894 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1891 class PerformanceCaptureConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#probe_threshold ⇒ ::Integer
Returns Optional. Specifies the minimum number of consecutive probe threshold that triggers performance capture.
1891 1892 1893 1894 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1891 class PerformanceCaptureConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#probing_interval_seconds ⇒ ::Integer
Returns Optional. Specifies the interval in seconds between consecutive probes that check if any trigger condition thresholds have been reached.
1891 1892 1893 1894 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1891 class PerformanceCaptureConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#running_threads_threshold ⇒ ::Integer
Returns Optional. Specifies the minimum number of MySQL Threads_running to
trigger the performance capture on the primary instance.
1891 1892 1893 1894 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1891 class PerformanceCaptureConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#seconds_behind_source_threshold ⇒ ::Integer
Returns Optional. Specifies the minimum number of seconds replica must be lagging behind primary instance to trigger the performance capture on replica.
1891 1892 1893 1894 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1891 class PerformanceCaptureConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#transaction_duration_threshold ⇒ ::Integer
Returns Optional. Specifies the amount of time in seconds that a transaction needs to have been open before the watcher starts recording it.
1891 1892 1893 1894 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1891 class PerformanceCaptureConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |