Class: Google::Cloud::Sql::V1::PscAutoConnectionConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::PscAutoConnectionConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb
Overview
Settings for an automatically-setup Private Service Connect consumer endpoint that is used to connect to a Cloud SQL instance.
Instance Attribute Summary collapse
-
#consumer_network ⇒ ::String
Optional.
-
#consumer_network_status ⇒ ::String
The connection policy status of the consumer network.
-
#consumer_project ⇒ ::String
Optional.
-
#instance_auto_dns_status ⇒ ::Google::Cloud::Sql::V1::AutoDnsStatus
readonly
Output only.
-
#ip_address ⇒ ::String
The IP address of the consumer endpoint.
-
#service_connection_policy ⇒ ::String
readonly
Output only.
-
#service_connection_policy_creation_result ⇒ ::String
readonly
Output only.
-
#status ⇒ ::String
The connection status of the consumer endpoint.
-
#write_endpoint_auto_dns_status ⇒ ::Google::Cloud::Sql::V1::AutoDnsStatus
readonly
Output only.
Instance Attribute Details
#consumer_network ⇒ ::String
Returns Optional. The consumer network of this consumer endpoint. This must be a resource path that includes both the host project and the network name.
For example, projects/project1/global/networks/network1.
The consumer host project of this network might be different from the consumer service project.
1035 1036 1037 1038 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1035 class PscAutoConnectionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#consumer_network_status ⇒ ::String
Returns The connection policy status of the consumer network.
1035 1036 1037 1038 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1035 class PscAutoConnectionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#consumer_project ⇒ ::String
Returns Optional. This is the project ID of consumer service project of this consumer endpoint.
This is only applicable if consumer_network is a shared VPC
network.
1035 1036 1037 1038 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1035 class PscAutoConnectionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#instance_auto_dns_status ⇒ ::Google::Cloud::Sql::V1::AutoDnsStatus (readonly)
Returns Output only. The status of automated DNS provisioning.
1035 1036 1037 1038 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1035 class PscAutoConnectionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#ip_address ⇒ ::String
Returns The IP address of the consumer endpoint.
1035 1036 1037 1038 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1035 class PscAutoConnectionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#service_connection_policy ⇒ ::String (readonly)
Returns Output only. The service connection policy created automatically for the
consumer network when psc_auto_connection_policy_enabled is true. It is
in the format of:
projects/{project}/regions/{region}/serviceConnectionPolicies/{policy_id}
The policy_id is in format of $NETWORK-$RANDOM.
1035 1036 1037 1038 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1035 class PscAutoConnectionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#service_connection_policy_creation_result ⇒ ::String (readonly)
Returns Output only. The status of service connection policy creation.
1035 1036 1037 1038 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1035 class PscAutoConnectionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#status ⇒ ::String
Returns The connection status of the consumer endpoint.
1035 1036 1037 1038 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1035 class PscAutoConnectionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#write_endpoint_auto_dns_status ⇒ ::Google::Cloud::Sql::V1::AutoDnsStatus (readonly)
Returns Output only. The status of automated DNS provisioning for the write endpoint.
1035 1036 1037 1038 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1035 class PscAutoConnectionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |