Class: Google::Cloud::Sql::V1::PscAutoConnectionConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::PscAutoConnectionConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb
Overview
Settings for an automatically-setup Private Service Connect consumer endpoint that is used to connect to a Cloud SQL instance.
Instance Attribute Summary collapse
-
#consumer_network ⇒ ::String
Optional.
-
#consumer_network_status ⇒ ::String
The connection policy status of the consumer network.
-
#consumer_project ⇒ ::String
Optional.
-
#ip_address ⇒ ::String
The IP address of the consumer endpoint.
-
#status ⇒ ::String
The connection status of the consumer endpoint.
Instance Attribute Details
#consumer_network ⇒ ::String
Returns Optional. The consumer network of this consumer endpoint. This must be a resource path that includes both the host project and the network name.
For example, projects/project1/global/networks/network1.
The consumer host project of this network might be different from the consumer service project.
1010 1011 1012 1013 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1010 class PscAutoConnectionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#consumer_network_status ⇒ ::String
Returns The connection policy status of the consumer network.
1010 1011 1012 1013 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1010 class PscAutoConnectionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#consumer_project ⇒ ::String
Returns Optional. This is the project ID of consumer service project of this consumer endpoint.
This is only applicable if consumer_network is a shared VPC
network.
1010 1011 1012 1013 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1010 class PscAutoConnectionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#ip_address ⇒ ::String
Returns The IP address of the consumer endpoint.
1010 1011 1012 1013 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1010 class PscAutoConnectionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#status ⇒ ::String
Returns The connection status of the consumer endpoint.
1010 1011 1012 1013 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1010 class PscAutoConnectionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |