Class: Google::Cloud::Sql::V1::QueryResult
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::QueryResult
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb
Overview
QueryResult contains the result of executing a single SQL statement.
Instance Attribute Summary collapse
-
#columns ⇒ ::Array<::Google::Cloud::Sql::V1::Column>
List of columns included in the result.
-
#message ⇒ ::String
Message related to the SQL execution result.
-
#partial_result ⇒ ::Boolean
Set to true if the SQL execution's result is truncated due to size limits or an error retrieving results.
-
#rows ⇒ ::Array<::Google::Cloud::Sql::V1::Row>
Rows returned by the SQL statement.
-
#status ⇒ ::Google::Rpc::Status
If results were truncated due to an error, details of that error.
Instance Attribute Details
#columns ⇒ ::Array<::Google::Cloud::Sql::V1::Column>
Returns List of columns included in the result. This also includes the data type of the column.
2182 2183 2184 2185 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 2182 class QueryResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#message ⇒ ::String
Returns Message related to the SQL execution result.
2182 2183 2184 2185 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 2182 class QueryResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#partial_result ⇒ ::Boolean
Returns Set to true if the SQL execution's result is truncated due to size limits or an error retrieving results.
2182 2183 2184 2185 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 2182 class QueryResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#rows ⇒ ::Array<::Google::Cloud::Sql::V1::Row>
Returns Rows returned by the SQL statement.
2182 2183 2184 2185 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 2182 class QueryResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#status ⇒ ::Google::Rpc::Status
Returns If results were truncated due to an error, details of that error.
2182 2183 2184 2185 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 2182 class QueryResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |