Class: Google::Cloud::Sql::V1::ReadPoolAutoScaleConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::ReadPoolAutoScaleConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb
Overview
The read pool auto-scale configuration.
Defined Under Namespace
Classes: TargetMetric
Instance Attribute Summary collapse
-
#disable_scale_in ⇒ ::Boolean
Indicates whether read pool auto scaling supports scale in operations (removing nodes).
-
#enabled ⇒ ::Boolean
Indicates whether read pool auto scaling is enabled.
-
#max_node_count ⇒ ::Integer
Maximum number of read pool nodes to be maintained.
-
#min_node_count ⇒ ::Integer
Minimum number of read pool nodes to be maintained.
-
#scale_in_cooldown_seconds ⇒ ::Integer
The cooldown period for scale-in operations.
-
#scale_out_cooldown_seconds ⇒ ::Integer
The cooldown period for scale-out operations.
-
#target_metrics ⇒ ::Array<::Google::Cloud::Sql::V1::ReadPoolAutoScaleConfig::TargetMetric>
Optional.
Instance Attribute Details
#disable_scale_in ⇒ ::Boolean
Returns Indicates whether read pool auto scaling supports scale in operations (removing nodes).
2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2043 class ReadPoolAutoScaleConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Target metric for read pool auto scaling. # @!attribute [rw] metric # @return [::String] # The metric name to be used for auto scaling. # @!attribute [rw] target_value # @return [::Float] # The target value for the metric. class TargetMetric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#enabled ⇒ ::Boolean
Returns Indicates whether read pool auto scaling is enabled.
2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2043 class ReadPoolAutoScaleConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Target metric for read pool auto scaling. # @!attribute [rw] metric # @return [::String] # The metric name to be used for auto scaling. # @!attribute [rw] target_value # @return [::Float] # The target value for the metric. class TargetMetric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#max_node_count ⇒ ::Integer
Returns Maximum number of read pool nodes to be maintained.
2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2043 class ReadPoolAutoScaleConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Target metric for read pool auto scaling. # @!attribute [rw] metric # @return [::String] # The metric name to be used for auto scaling. # @!attribute [rw] target_value # @return [::Float] # The target value for the metric. class TargetMetric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#min_node_count ⇒ ::Integer
Returns Minimum number of read pool nodes to be maintained.
2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2043 class ReadPoolAutoScaleConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Target metric for read pool auto scaling. # @!attribute [rw] metric # @return [::String] # The metric name to be used for auto scaling. # @!attribute [rw] target_value # @return [::Float] # The target value for the metric. class TargetMetric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#scale_in_cooldown_seconds ⇒ ::Integer
Returns The cooldown period for scale-in operations.
2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2043 class ReadPoolAutoScaleConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Target metric for read pool auto scaling. # @!attribute [rw] metric # @return [::String] # The metric name to be used for auto scaling. # @!attribute [rw] target_value # @return [::Float] # The target value for the metric. class TargetMetric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#scale_out_cooldown_seconds ⇒ ::Integer
Returns The cooldown period for scale-out operations.
2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2043 class ReadPoolAutoScaleConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Target metric for read pool auto scaling. # @!attribute [rw] metric # @return [::String] # The metric name to be used for auto scaling. # @!attribute [rw] target_value # @return [::Float] # The target value for the metric. class TargetMetric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#target_metrics ⇒ ::Array<::Google::Cloud::Sql::V1::ReadPoolAutoScaleConfig::TargetMetric>
Returns Optional. Target metrics for read pool auto scaling.
2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2043 class ReadPoolAutoScaleConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Target metric for read pool auto scaling. # @!attribute [rw] metric # @return [::String] # The metric name to be used for auto scaling. # @!attribute [rw] target_value # @return [::Float] # The target value for the metric. class TargetMetric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |