Class: Google::Cloud::Sql::V1::ReadPoolAutoScaleConfig::TargetMetric
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::ReadPoolAutoScaleConfig::TargetMetric
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb
Overview
Target metric for read pool auto scaling.
Instance Attribute Summary collapse
-
#metric ⇒ ::String
The metric name to be used for auto scaling.
-
#target_value ⇒ ::Float
The target value for the metric.
Instance Attribute Details
#metric ⇒ ::String
Returns The metric name to be used for auto scaling.
1960 1961 1962 1963 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1960 class TargetMetric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#target_value ⇒ ::Float
Returns The target value for the metric.
1960 1961 1962 1963 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 1960 class TargetMetric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |