Class: Google::Cloud::Sql::V1::ReplicaConfiguration
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::ReplicaConfiguration
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb
Overview
Read-replica configuration for connecting to the primary instance.
Instance Attribute Summary collapse
-
#cascadable_replica ⇒ ::Google::Protobuf::BoolValue
Optional.
-
#failover_target ⇒ ::Google::Protobuf::BoolValue
Specifies if the replica is the failover target.
-
#kind ⇒ ::String
This is always
sql#replicaConfiguration. -
#mysql_replica_configuration ⇒ ::Google::Cloud::Sql::V1::MySqlReplicaConfiguration
MySQL specific configuration when replicating from a MySQL on-premises primary instance.
Instance Attribute Details
#cascadable_replica ⇒ ::Google::Protobuf::BoolValue
Returns Optional. Specifies if a SQL Server replica is a cascadable replica. A cascadable replica is a SQL Server cross region replica that supports replica(s) under it.
2053 2054 2055 2056 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 2053 class ReplicaConfiguration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#failover_target ⇒ ::Google::Protobuf::BoolValue
Returns Specifies if the replica is the failover target. If the field is set to
true, the replica will be designated as a failover replica. In case the
primary instance fails, the replica instance will be promoted as the new
primary instance. Only one replica can be specified as failover target, and
the replica has to be in different zone with the primary instance.
2053 2054 2055 2056 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 2053 class ReplicaConfiguration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#kind ⇒ ::String
Returns This is always sql#replicaConfiguration.
2053 2054 2055 2056 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 2053 class ReplicaConfiguration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#mysql_replica_configuration ⇒ ::Google::Cloud::Sql::V1::MySqlReplicaConfiguration
Returns MySQL specific configuration when replicating from a MySQL on-premises
primary instance. Replication configuration information such as the
username, password, certificates, and keys are not stored in the instance
metadata. The configuration information is used only to set up the
replication connection and is stored by MySQL in a file named
master.info in the data directory.
2053 2054 2055 2056 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 2053 class ReplicaConfiguration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |