Class: Google::Cloud::Sql::V1::RestoreBackupContext
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::RestoreBackupContext
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb
Overview
Database instance restore from backup context. Backup context contains source instance id and project id.
Instance Attribute Summary collapse
-
#backup_run_id ⇒ ::Integer
The ID of the backup run to restore from.
-
#instance_id ⇒ ::String
The ID of the instance that the backup was taken from.
-
#kind ⇒ ::String
This is always
sql#restoreBackupContext. -
#project ⇒ ::String
The full project ID of the source instance.
Instance Attribute Details
#backup_run_id ⇒ ::Integer
Returns The ID of the backup run to restore from.
1678 1679 1680 1681 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1678 class RestoreBackupContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#instance_id ⇒ ::String
Returns The ID of the instance that the backup was taken from.
1678 1679 1680 1681 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1678 class RestoreBackupContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#kind ⇒ ::String
Returns This is always sql#restoreBackupContext.
1678 1679 1680 1681 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1678 class RestoreBackupContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#project ⇒ ::String
Returns The full project ID of the source instance.
1678 1679 1680 1681 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1678 class RestoreBackupContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |