Class: Google::Cloud::Sql::V1::RotateEntraIdCertificateContext
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::RotateEntraIdCertificateContext
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb
Overview
Instance rotate Entra ID certificate context.
Instance Attribute Summary collapse
-
#kind ⇒ ::String
Optional.
-
#next_version ⇒ ::String
Optional.
Instance Attribute Details
#kind ⇒ ::String
Returns Optional. This is always sql#rotateEntraIdCertificateContext.
1718 1719 1720 1721 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1718 class RotateEntraIdCertificateContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_version ⇒ ::String
Returns Optional. The fingerprint of the next version to be rotated to. If left unspecified, will be rotated to the most recently added server certificate version.
1718 1719 1720 1721 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 1718 class RotateEntraIdCertificateContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |