Class: Google::Cloud::Sql::V1::SqlActiveDirectoryConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb

Overview

Active Directory configuration, relevant only for Cloud SQL for SQL Server.

Defined Under Namespace

Modules: ActiveDirectoryMode

Instance Attribute Summary collapse

Instance Attribute Details

#admin_credential_secret_name::String

Returns Optional. The secret manager key storing the administrator credential. (e.g., projects/{project}/secrets/{secret}).

Returns:

  • (::String)

    Optional. The secret manager key storing the administrator credential. (e.g., projects/{project}/secrets/{secret}).



2047
2048
2049
2050
2051
2052
2053
2054
2055
2056
2057
2058
2059
2060
2061
2062
2063
2064
2065
2066
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2047

class SqlActiveDirectoryConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The modes of Active Directory configuration.
  module ActiveDirectoryMode
    # Unspecified mode. Will default to MANAGED_ACTIVE_DIRECTORY if the mode is
    # not specified to maintain backward compatibility.
    ACTIVE_DIRECTORY_MODE_UNSPECIFIED = 0

    # Managed Active Directory mode.
    MANAGED_ACTIVE_DIRECTORY = 1

    # Deprecated: Use CUSTOMER_MANAGED_ACTIVE_DIRECTORY instead.
    SELF_MANAGED_ACTIVE_DIRECTORY = 2

    # Customer-managed Active Directory mode.
    CUSTOMER_MANAGED_ACTIVE_DIRECTORY = 3
  end
end

#dns_servers::Array<::String>

Returns Optional. Domain controller IPv4 addresses used to bootstrap Active Directory.

Returns:

  • (::Array<::String>)

    Optional. Domain controller IPv4 addresses used to bootstrap Active Directory.



2047
2048
2049
2050
2051
2052
2053
2054
2055
2056
2057
2058
2059
2060
2061
2062
2063
2064
2065
2066
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2047

class SqlActiveDirectoryConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The modes of Active Directory configuration.
  module ActiveDirectoryMode
    # Unspecified mode. Will default to MANAGED_ACTIVE_DIRECTORY if the mode is
    # not specified to maintain backward compatibility.
    ACTIVE_DIRECTORY_MODE_UNSPECIFIED = 0

    # Managed Active Directory mode.
    MANAGED_ACTIVE_DIRECTORY = 1

    # Deprecated: Use CUSTOMER_MANAGED_ACTIVE_DIRECTORY instead.
    SELF_MANAGED_ACTIVE_DIRECTORY = 2

    # Customer-managed Active Directory mode.
    CUSTOMER_MANAGED_ACTIVE_DIRECTORY = 3
  end
end

#domain::String

Returns The name of the domain (e.g., mydomain.com).

Returns:

  • (::String)

    The name of the domain (e.g., mydomain.com).



2047
2048
2049
2050
2051
2052
2053
2054
2055
2056
2057
2058
2059
2060
2061
2062
2063
2064
2065
2066
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2047

class SqlActiveDirectoryConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The modes of Active Directory configuration.
  module ActiveDirectoryMode
    # Unspecified mode. Will default to MANAGED_ACTIVE_DIRECTORY if the mode is
    # not specified to maintain backward compatibility.
    ACTIVE_DIRECTORY_MODE_UNSPECIFIED = 0

    # Managed Active Directory mode.
    MANAGED_ACTIVE_DIRECTORY = 1

    # Deprecated: Use CUSTOMER_MANAGED_ACTIVE_DIRECTORY instead.
    SELF_MANAGED_ACTIVE_DIRECTORY = 2

    # Customer-managed Active Directory mode.
    CUSTOMER_MANAGED_ACTIVE_DIRECTORY = 3
  end
end

#kind::String

Returns This is always sql#activeDirectoryConfig.

Returns:

  • (::String)

    This is always sql#activeDirectoryConfig.



2047
2048
2049
2050
2051
2052
2053
2054
2055
2056
2057
2058
2059
2060
2061
2062
2063
2064
2065
2066
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2047

class SqlActiveDirectoryConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The modes of Active Directory configuration.
  module ActiveDirectoryMode
    # Unspecified mode. Will default to MANAGED_ACTIVE_DIRECTORY if the mode is
    # not specified to maintain backward compatibility.
    ACTIVE_DIRECTORY_MODE_UNSPECIFIED = 0

    # Managed Active Directory mode.
    MANAGED_ACTIVE_DIRECTORY = 1

    # Deprecated: Use CUSTOMER_MANAGED_ACTIVE_DIRECTORY instead.
    SELF_MANAGED_ACTIVE_DIRECTORY = 2

    # Customer-managed Active Directory mode.
    CUSTOMER_MANAGED_ACTIVE_DIRECTORY = 3
  end
end

#mode::Google::Cloud::Sql::V1::SqlActiveDirectoryConfig::ActiveDirectoryMode

Returns Optional. The mode of the Active Directory configuration.

Returns:



2047
2048
2049
2050
2051
2052
2053
2054
2055
2056
2057
2058
2059
2060
2061
2062
2063
2064
2065
2066
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2047

class SqlActiveDirectoryConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The modes of Active Directory configuration.
  module ActiveDirectoryMode
    # Unspecified mode. Will default to MANAGED_ACTIVE_DIRECTORY if the mode is
    # not specified to maintain backward compatibility.
    ACTIVE_DIRECTORY_MODE_UNSPECIFIED = 0

    # Managed Active Directory mode.
    MANAGED_ACTIVE_DIRECTORY = 1

    # Deprecated: Use CUSTOMER_MANAGED_ACTIVE_DIRECTORY instead.
    SELF_MANAGED_ACTIVE_DIRECTORY = 2

    # Customer-managed Active Directory mode.
    CUSTOMER_MANAGED_ACTIVE_DIRECTORY = 3
  end
end

#organizational_unit::String

Returns Optional. The organizational unit distinguished name. This is the full hierarchical path to the organizational unit.

Returns:

  • (::String)

    Optional. The organizational unit distinguished name. This is the full hierarchical path to the organizational unit.



2047
2048
2049
2050
2051
2052
2053
2054
2055
2056
2057
2058
2059
2060
2061
2062
2063
2064
2065
2066
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2047

class SqlActiveDirectoryConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The modes of Active Directory configuration.
  module ActiveDirectoryMode
    # Unspecified mode. Will default to MANAGED_ACTIVE_DIRECTORY if the mode is
    # not specified to maintain backward compatibility.
    ACTIVE_DIRECTORY_MODE_UNSPECIFIED = 0

    # Managed Active Directory mode.
    MANAGED_ACTIVE_DIRECTORY = 1

    # Deprecated: Use CUSTOMER_MANAGED_ACTIVE_DIRECTORY instead.
    SELF_MANAGED_ACTIVE_DIRECTORY = 2

    # Customer-managed Active Directory mode.
    CUSTOMER_MANAGED_ACTIVE_DIRECTORY = 3
  end
end