Class: Google::Cloud::Sql::V1::SqlInstancesDeleteRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::SqlInstancesDeleteRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb
Overview
Instance delete request.
Instance Attribute Summary collapse
-
#enable_final_backup ⇒ ::Boolean
Flag to opt-in for final backup.
-
#final_backup_description ⇒ ::String
Optional.
-
#final_backup_expiry_time ⇒ ::Google::Protobuf::Timestamp
Optional.
-
#final_backup_ttl_days ⇒ ::Integer
Optional.
-
#instance ⇒ ::String
Cloud SQL instance ID.
-
#project ⇒ ::String
Project ID of the project that contains the instance to be deleted.
Instance Attribute Details
#enable_final_backup ⇒ ::Boolean
Returns Flag to opt-in for final backup. By default, it is turned off.
99 100 101 102 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 99 class SqlInstancesDeleteRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#final_backup_description ⇒ ::String
Returns Optional. The description of the final backup.
99 100 101 102 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 99 class SqlInstancesDeleteRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#final_backup_expiry_time ⇒ ::Google::Protobuf::Timestamp
Returns Optional. Final Backup expiration time. Timestamp in UTC of when this resource is considered expired.
Note: The following fields are mutually exclusive: final_backup_expiry_time, final_backup_ttl_days. If a field in that set is populated, all other fields in the set will automatically be cleared.
99 100 101 102 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 99 class SqlInstancesDeleteRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#final_backup_ttl_days ⇒ ::Integer
Returns Optional. Retention period of the final backup.
Note: The following fields are mutually exclusive: final_backup_ttl_days, final_backup_expiry_time. If a field in that set is populated, all other fields in the set will automatically be cleared.
99 100 101 102 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 99 class SqlInstancesDeleteRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#instance ⇒ ::String
Returns Cloud SQL instance ID. This does not include the project ID.
99 100 101 102 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 99 class SqlInstancesDeleteRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#project ⇒ ::String
Returns Project ID of the project that contains the instance to be deleted.
99 100 101 102 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 99 class SqlInstancesDeleteRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |