Class: Google::Cloud::Sql::V1::SqlInstancesExecuteSqlResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb

Overview

Execute SQL statements response.

Defined Under Namespace

Classes: Message

Instance Attribute Summary collapse

Instance Attribute Details

#messages::Array<::Google::Cloud::Sql::V1::SqlInstancesExecuteSqlResponse::Message>

Returns A list of notices and warnings generated during query execution. For PostgreSQL, this includes all notices and warnings. For MySQL, this includes warnings generated by the last executed statement. To retrieve all warnings for a multi-statement query, SHOW WARNINGS must be executed after each statement.

Returns:

  • (::Array<::Google::Cloud::Sql::V1::SqlInstancesExecuteSqlResponse::Message>)

    A list of notices and warnings generated during query execution. For PostgreSQL, this includes all notices and warnings. For MySQL, this includes warnings generated by the last executed statement. To retrieve all warnings for a multi-statement query, SHOW WARNINGS must be executed after each statement.



2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
2159
2160
2161
2162
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 2143

class SqlInstancesExecuteSqlResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents a notice or warning message from the database.
  # @!attribute [rw] message
  #   @return [::String]
  #     The full message string.
  #     For PostgreSQL, this is a formatted string that may include severity,
  #     code, and the notice/warning message.
  #     For MySQL, this contains the warning message.
  # @!attribute [rw] severity
  #   @return [::String]
  #     The severity of the message (e.g., "NOTICE" for PostgreSQL, "WARNING" for
  #     MySQL).
  class Message
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#metadata::Google::Cloud::Sql::V1::Metadata

Returns The additional metadata information regarding the execution of the SQL statements.

Returns:



2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
2159
2160
2161
2162
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 2143

class SqlInstancesExecuteSqlResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents a notice or warning message from the database.
  # @!attribute [rw] message
  #   @return [::String]
  #     The full message string.
  #     For PostgreSQL, this is a formatted string that may include severity,
  #     code, and the notice/warning message.
  #     For MySQL, this contains the warning message.
  # @!attribute [rw] severity
  #   @return [::String]
  #     The severity of the message (e.g., "NOTICE" for PostgreSQL, "WARNING" for
  #     MySQL).
  class Message
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#results::Array<::Google::Cloud::Sql::V1::QueryResult>

Returns The list of results after executing all the SQL statements.

Returns:



2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
2159
2160
2161
2162
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 2143

class SqlInstancesExecuteSqlResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents a notice or warning message from the database.
  # @!attribute [rw] message
  #   @return [::String]
  #     The full message string.
  #     For PostgreSQL, this is a formatted string that may include severity,
  #     code, and the notice/warning message.
  #     For MySQL, this contains the warning message.
  # @!attribute [rw] severity
  #   @return [::String]
  #     The severity of the message (e.g., "NOTICE" for PostgreSQL, "WARNING" for
  #     MySQL).
  class Message
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#status::Google::Rpc::Status

Returns Contains the error from the database if the SQL execution failed.

Returns:



2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
2159
2160
2161
2162
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 2143

class SqlInstancesExecuteSqlResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents a notice or warning message from the database.
  # @!attribute [rw] message
  #   @return [::String]
  #     The full message string.
  #     For PostgreSQL, this is a formatted string that may include severity,
  #     code, and the notice/warning message.
  #     For MySQL, this contains the warning message.
  # @!attribute [rw] severity
  #   @return [::String]
  #     The severity of the message (e.g., "NOTICE" for PostgreSQL, "WARNING" for
  #     MySQL).
  class Message
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end