Class: Google::Cloud::Sql::V1::SqlInstancesGetDiskShrinkConfigResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::SqlInstancesGetDiskShrinkConfigResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb
Overview
Instance get disk shrink config response.
Instance Attribute Summary collapse
-
#kind ⇒ ::String
This is always
sql#getDiskShrinkConfig. -
#message ⇒ ::String
Additional message to customers.
-
#minimal_target_size_gb ⇒ ::Integer
The minimum size to which a disk can be shrunk in GigaBytes.
Instance Attribute Details
#kind ⇒ ::String
Returns This is always sql#getDiskShrinkConfig.
953 954 955 956 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 953 class SqlInstancesGetDiskShrinkConfigResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#message ⇒ ::String
Returns Additional message to customers.
953 954 955 956 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 953 class SqlInstancesGetDiskShrinkConfigResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#minimal_target_size_gb ⇒ ::Integer
Returns The minimum size to which a disk can be shrunk in GigaBytes.
953 954 955 956 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 953 class SqlInstancesGetDiskShrinkConfigResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |