Class: Google::Cloud::Sql::V1::SqlInstancesPatchRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::SqlInstancesPatchRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb
Overview
Instance patch request.
Instance Attribute Summary collapse
- #body ⇒ ::Google::Cloud::Sql::V1::DatabaseInstance
-
#instance ⇒ ::String
Cloud SQL instance ID.
-
#project ⇒ ::String
Project ID of the project that contains the instance.
-
#reconcile_psc_networking ⇒ ::Boolean
Optional.
-
#reconcile_psc_networking_force ⇒ ::Boolean
Optional.
Instance Attribute Details
#body ⇒ ::Google::Cloud::Sql::V1::DatabaseInstance
282 283 284 285 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 282 class SqlInstancesPatchRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#instance ⇒ ::String
Returns Cloud SQL instance ID. This does not include the project ID.
282 283 284 285 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 282 class SqlInstancesPatchRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#project ⇒ ::String
Returns Project ID of the project that contains the instance.
282 283 284 285 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 282 class SqlInstancesPatchRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#reconcile_psc_networking ⇒ ::Boolean
Returns Optional. Set PSC config to the same value as the existing config to reconcile the PSC networking.
282 283 284 285 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 282 class SqlInstancesPatchRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#reconcile_psc_networking_force ⇒ ::Boolean
Returns Optional. Set PSC config to the same value as the existing config and force reconcile the PSC networking.
282 283 284 285 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 282 class SqlInstancesPatchRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |