Class: Google::Cloud::Sql::V1::SqlInstancesPromoteReplicaRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::SqlInstancesPromoteReplicaRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb
Overview
Instance promote replica request.
Instance Attribute Summary collapse
-
#failover ⇒ ::Boolean
Set to true to invoke a replica failover to the DR replica.
-
#instance ⇒ ::String
Cloud SQL read replica instance name.
-
#project ⇒ ::String
ID of the project that contains the read replica.
Instance Attribute Details
#failover ⇒ ::Boolean
Returns Set to true to invoke a replica failover to the DR replica. As part of replica failover, the promote operation attempts to add the original primary instance as a replica of the promoted DR replica when the original primary instance comes back online. If set to false or not specified, then the original primary instance becomes an independent Cloud SQL primary instance.
294 295 296 297 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 294 class SqlInstancesPromoteReplicaRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#instance ⇒ ::String
Returns Cloud SQL read replica instance name.
294 295 296 297 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 294 class SqlInstancesPromoteReplicaRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#project ⇒ ::String
Returns ID of the project that contains the read replica.
294 295 296 297 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 294 class SqlInstancesPromoteReplicaRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |