Class: Google::Cloud::Sql::V1::SqlInstancesStopReplicaRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::SqlInstancesStopReplicaRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb
Overview
Instance stop replica request.
Instance Attribute Summary collapse
-
#instance ⇒ ::String
Cloud SQL read replica instance name.
-
#project ⇒ ::String
ID of the project that contains the read replica.
Instance Attribute Details
#instance ⇒ ::String
Returns Cloud SQL read replica instance name.
434 435 436 437 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 434 class SqlInstancesStopReplicaRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#project ⇒ ::String
Returns ID of the project that contains the read replica.
434 435 436 437 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 434 class SqlInstancesStopReplicaRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |