Class: Google::Cloud::Sql::V1::SqlInstancesVerifyExternalSyncSettingsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::SqlInstancesVerifyExternalSyncSettingsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb
Overview
Instance verify external sync settings request.
Defined Under Namespace
Modules: ExternalSyncMode, MigrationType
Instance Attribute Summary collapse
-
#instance ⇒ ::String
Cloud SQL instance ID.
-
#migration_type ⇒ ::Google::Cloud::Sql::V1::SqlInstancesVerifyExternalSyncSettingsRequest::MigrationType
Optional.
-
#mysql_sync_config ⇒ ::Google::Cloud::Sql::V1::MySqlSyncConfig
Optional.
-
#project ⇒ ::String
Project ID of the project that contains the instance.
-
#selected_objects ⇒ ::Array<::Google::Cloud::Sql::V1::ExternalSyncSelectedObject>
Optional.
-
#sync_mode ⇒ ::Google::Cloud::Sql::V1::SqlInstancesVerifyExternalSyncSettingsRequest::ExternalSyncMode
External sync mode.
-
#sync_parallel_level ⇒ ::Google::Cloud::Sql::V1::ExternalSyncParallelLevel
Optional.
-
#verify_connection_only ⇒ ::Boolean
Flag to enable verifying connection only.
-
#verify_replication_only ⇒ ::Boolean
Optional.
Instance Attribute Details
#instance ⇒ ::String
Returns Cloud SQL instance ID. This does not include the project ID.
597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 597 class SqlInstancesVerifyExternalSyncSettingsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module ExternalSyncMode # Unknown external sync mode, will be defaulted to ONLINE mode EXTERNAL_SYNC_MODE_UNSPECIFIED = 0 # Online external sync will set up replication after initial data external # sync ONLINE = 1 # Offline external sync only dumps and loads a one-time snapshot of # the primary instance's data OFFLINE = 2 end # MigrationType determines whether the migration is a physical file-based # migration or a logical dump file-based migration. module MigrationType # Default value is a logical dump file-based migration MIGRATION_TYPE_UNSPECIFIED = 0 # Logical dump file-based migration LOGICAL = 1 # Physical file-based migration PHYSICAL = 2 end end |
#migration_type ⇒ ::Google::Cloud::Sql::V1::SqlInstancesVerifyExternalSyncSettingsRequest::MigrationType
Returns Optional. MigrationType configures the migration to use physical files or
logical dump files. If not set, then the logical dump file configuration is
used. Valid values are LOGICAL or PHYSICAL. Only applicable to MySQL.
597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 597 class SqlInstancesVerifyExternalSyncSettingsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module ExternalSyncMode # Unknown external sync mode, will be defaulted to ONLINE mode EXTERNAL_SYNC_MODE_UNSPECIFIED = 0 # Online external sync will set up replication after initial data external # sync ONLINE = 1 # Offline external sync only dumps and loads a one-time snapshot of # the primary instance's data OFFLINE = 2 end # MigrationType determines whether the migration is a physical file-based # migration or a logical dump file-based migration. module MigrationType # Default value is a logical dump file-based migration MIGRATION_TYPE_UNSPECIFIED = 0 # Logical dump file-based migration LOGICAL = 1 # Physical file-based migration PHYSICAL = 2 end end |
#mysql_sync_config ⇒ ::Google::Cloud::Sql::V1::MySqlSyncConfig
Returns Optional. MySQL-specific settings for start external sync.
597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 597 class SqlInstancesVerifyExternalSyncSettingsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module ExternalSyncMode # Unknown external sync mode, will be defaulted to ONLINE mode EXTERNAL_SYNC_MODE_UNSPECIFIED = 0 # Online external sync will set up replication after initial data external # sync ONLINE = 1 # Offline external sync only dumps and loads a one-time snapshot of # the primary instance's data OFFLINE = 2 end # MigrationType determines whether the migration is a physical file-based # migration or a logical dump file-based migration. module MigrationType # Default value is a logical dump file-based migration MIGRATION_TYPE_UNSPECIFIED = 0 # Logical dump file-based migration LOGICAL = 1 # Physical file-based migration PHYSICAL = 2 end end |
#project ⇒ ::String
Returns Project ID of the project that contains the instance.
597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 597 class SqlInstancesVerifyExternalSyncSettingsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module ExternalSyncMode # Unknown external sync mode, will be defaulted to ONLINE mode EXTERNAL_SYNC_MODE_UNSPECIFIED = 0 # Online external sync will set up replication after initial data external # sync ONLINE = 1 # Offline external sync only dumps and loads a one-time snapshot of # the primary instance's data OFFLINE = 2 end # MigrationType determines whether the migration is a physical file-based # migration or a logical dump file-based migration. module MigrationType # Default value is a logical dump file-based migration MIGRATION_TYPE_UNSPECIFIED = 0 # Logical dump file-based migration LOGICAL = 1 # Physical file-based migration PHYSICAL = 2 end end |
#selected_objects ⇒ ::Array<::Google::Cloud::Sql::V1::ExternalSyncSelectedObject>
Returns Optional. Migrate only the specified objects from the source instance. If this field is empty, then migrate all objects.
597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 597 class SqlInstancesVerifyExternalSyncSettingsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module ExternalSyncMode # Unknown external sync mode, will be defaulted to ONLINE mode EXTERNAL_SYNC_MODE_UNSPECIFIED = 0 # Online external sync will set up replication after initial data external # sync ONLINE = 1 # Offline external sync only dumps and loads a one-time snapshot of # the primary instance's data OFFLINE = 2 end # MigrationType determines whether the migration is a physical file-based # migration or a logical dump file-based migration. module MigrationType # Default value is a logical dump file-based migration MIGRATION_TYPE_UNSPECIFIED = 0 # Logical dump file-based migration LOGICAL = 1 # Physical file-based migration PHYSICAL = 2 end end |
#sync_mode ⇒ ::Google::Cloud::Sql::V1::SqlInstancesVerifyExternalSyncSettingsRequest::ExternalSyncMode
Returns External sync mode.
597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 597 class SqlInstancesVerifyExternalSyncSettingsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module ExternalSyncMode # Unknown external sync mode, will be defaulted to ONLINE mode EXTERNAL_SYNC_MODE_UNSPECIFIED = 0 # Online external sync will set up replication after initial data external # sync ONLINE = 1 # Offline external sync only dumps and loads a one-time snapshot of # the primary instance's data OFFLINE = 2 end # MigrationType determines whether the migration is a physical file-based # migration or a logical dump file-based migration. module MigrationType # Default value is a logical dump file-based migration MIGRATION_TYPE_UNSPECIFIED = 0 # Logical dump file-based migration LOGICAL = 1 # Physical file-based migration PHYSICAL = 2 end end |
#sync_parallel_level ⇒ ::Google::Cloud::Sql::V1::ExternalSyncParallelLevel
Returns Optional. Parallel level for initial data sync. Only applicable for PostgreSQL.
597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 597 class SqlInstancesVerifyExternalSyncSettingsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module ExternalSyncMode # Unknown external sync mode, will be defaulted to ONLINE mode EXTERNAL_SYNC_MODE_UNSPECIFIED = 0 # Online external sync will set up replication after initial data external # sync ONLINE = 1 # Offline external sync only dumps and loads a one-time snapshot of # the primary instance's data OFFLINE = 2 end # MigrationType determines whether the migration is a physical file-based # migration or a logical dump file-based migration. module MigrationType # Default value is a logical dump file-based migration MIGRATION_TYPE_UNSPECIFIED = 0 # Logical dump file-based migration LOGICAL = 1 # Physical file-based migration PHYSICAL = 2 end end |
#verify_connection_only ⇒ ::Boolean
Returns Flag to enable verifying connection only.
597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 597 class SqlInstancesVerifyExternalSyncSettingsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module ExternalSyncMode # Unknown external sync mode, will be defaulted to ONLINE mode EXTERNAL_SYNC_MODE_UNSPECIFIED = 0 # Online external sync will set up replication after initial data external # sync ONLINE = 1 # Offline external sync only dumps and loads a one-time snapshot of # the primary instance's data OFFLINE = 2 end # MigrationType determines whether the migration is a physical file-based # migration or a logical dump file-based migration. module MigrationType # Default value is a logical dump file-based migration MIGRATION_TYPE_UNSPECIFIED = 0 # Logical dump file-based migration LOGICAL = 1 # Physical file-based migration PHYSICAL = 2 end end |
#verify_replication_only ⇒ ::Boolean
Returns Optional. Flag to verify settings required by replication setup only.
597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 597 class SqlInstancesVerifyExternalSyncSettingsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module ExternalSyncMode # Unknown external sync mode, will be defaulted to ONLINE mode EXTERNAL_SYNC_MODE_UNSPECIFIED = 0 # Online external sync will set up replication after initial data external # sync ONLINE = 1 # Offline external sync only dumps and loads a one-time snapshot of # the primary instance's data OFFLINE = 2 end # MigrationType determines whether the migration is a physical file-based # migration or a logical dump file-based migration. module MigrationType # Default value is a logical dump file-based migration MIGRATION_TYPE_UNSPECIFIED = 0 # Logical dump file-based migration LOGICAL = 1 # Physical file-based migration PHYSICAL = 2 end end |