Module: Google::Cloud::Sql::V1::SqlIpAddressType
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb
Constant Summary collapse
- SQL_IP_ADDRESS_TYPE_UNSPECIFIED =
This is an unknown IP address type.
0- PRIMARY =
IP address the customer is supposed to connect to. Usually this is the load balancer's IP address
1- OUTGOING =
Source IP address of the connection a read replica establishes to its external primary instance. This IP address can be allowlisted by the customer in case it has a firewall that filters incoming connection to its on premises primary instance.
2- PRIVATE =
Private IP used when using private IPs and network peering.
3- MIGRATED_1ST_GEN =
V1 IP of a migrated instance. We want the user to decommission this IP as soon as the migration is complete. Note: V1 instances with V1 ip addresses will be counted as PRIMARY.
4