Module: Google::Cloud::Sql::V1::SqlPricingPlan
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb
Overview
The pricing plan for this instance.
Constant Summary collapse
- SQL_PRICING_PLAN_UNSPECIFIED =
This is an unknown pricing plan for this instance.
0- PACKAGE =
The instance is billed at a monthly flat rate.
1- PER_USE =
The instance is billed per usage.
2