Module: Google::Cloud::Sql::V1::SqlReplicationType
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb
Constant Summary collapse
- SQL_REPLICATION_TYPE_UNSPECIFIED =
This is an unknown replication type for a Cloud SQL instance.
0- SYNCHRONOUS =
The synchronous replication mode for First Generation instances. It is the default value.
1- ASYNCHRONOUS =
The asynchronous replication mode for First Generation instances. It provides a slight performance gain, but if an outage occurs while this option is set to asynchronous, you can lose up to a few seconds of updates to your data.
2