Class: Google::Cloud::Sql::V1::SqlServerDatabaseDetails
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::SqlServerDatabaseDetails
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb
Overview
Represents a Sql Server database on the Cloud SQL instance.
Instance Attribute Summary collapse
-
#compatibility_level ⇒ ::Integer
The version of SQL Server with which the database is to be made compatible.
-
#recovery_model ⇒ ::String
The recovery model of a SQL Server database.
Instance Attribute Details
#compatibility_level ⇒ ::Integer
Returns The version of SQL Server with which the database is to be made compatible.
302 303 304 305 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 302 class SqlServerDatabaseDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#recovery_model ⇒ ::String
Returns The recovery model of a SQL Server database.
302 303 304 305 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 302 class SqlServerDatabaseDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |