Class: Google::Cloud::Sql::V1::SqlTiersListRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::SqlTiersListRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_tiers.rb
Overview
Tiers list request.
Instance Attribute Summary collapse
-
#project ⇒ ::String
Project ID of the project for which to list tiers.
Instance Attribute Details
#project ⇒ ::String
Returns Project ID of the project for which to list tiers.
28 29 30 31 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_tiers.rb', line 28 class SqlTiersListRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |