Class: Google::Cloud::Sql::V1::SslCert
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::SslCert
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb
Overview
SslCerts Resource
Instance Attribute Summary collapse
-
#cert ⇒ ::String
PEM representation.
-
#cert_serial_number ⇒ ::String
Serial number, as extracted from the certificate.
-
#common_name ⇒ ::String
User supplied name.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
The time when the certificate was created in RFC 3339 format, for example
2012-11-15T16:19:00.094Z. -
#expiration_time ⇒ ::Google::Protobuf::Timestamp
The time when the certificate expires in RFC 3339 format, for example
2012-11-15T16:19:00.094Z. -
#instance ⇒ ::String
Name of the database instance.
-
#kind ⇒ ::String
This is always
sql#sslCert. -
#self_link ⇒ ::String
The URI of this resource.
-
#sha1_fingerprint ⇒ ::String
Sha1 Fingerprint.
Instance Attribute Details
#cert ⇒ ::String
Returns PEM representation.
2007 2008 2009 2010 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2007 class SslCert include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#cert_serial_number ⇒ ::String
Returns Serial number, as extracted from the certificate.
2007 2008 2009 2010 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2007 class SslCert include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#common_name ⇒ ::String
Returns User supplied name. Constrained to [a-zA-Z.-_ ]+.
2007 2008 2009 2010 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2007 class SslCert include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#create_time ⇒ ::Google::Protobuf::Timestamp
Returns The time when the certificate was created in RFC
3339 format, for example
2012-11-15T16:19:00.094Z.
2007 2008 2009 2010 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2007 class SslCert include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#expiration_time ⇒ ::Google::Protobuf::Timestamp
Returns The time when the certificate expires in RFC
3339 format, for example
2012-11-15T16:19:00.094Z.
2007 2008 2009 2010 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2007 class SslCert include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#instance ⇒ ::String
Returns Name of the database instance.
2007 2008 2009 2010 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2007 class SslCert include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#kind ⇒ ::String
Returns This is always sql#sslCert.
2007 2008 2009 2010 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2007 class SslCert include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |