Class: Google::Cloud::Sql::V1::SslCertDetail
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::SslCertDetail
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb
Overview
SslCertDetail.
Instance Attribute Summary collapse
-
#cert_info ⇒ ::Google::Cloud::Sql::V1::SslCert
The public information about the cert.
-
#cert_private_key ⇒ ::String
The private key for the client cert, in pem format.
Instance Attribute Details
#cert_info ⇒ ::Google::Cloud::Sql::V1::SslCert
Returns The public information about the cert.
2020 2021 2022 2023 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2020 class SslCertDetail include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#cert_private_key ⇒ ::String
Returns The private key for the client cert, in pem format. Keep private in order to protect your security.
2020 2021 2022 2023 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_resources.rb', line 2020 class SslCertDetail include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |