Class: Google::Cloud::Sql::V1::SslCertsCreateEphemeralRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::SslCertsCreateEphemeralRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb
Overview
SslCerts create ephemeral certificate request.
Instance Attribute Summary collapse
-
#access_token ⇒ ::String
Access token to include in the signed certificate.
-
#public_key ⇒ ::String
PEM encoded public key to include in the signed certificate.
Instance Attribute Details
#access_token ⇒ ::String
Returns Access token to include in the signed certificate.
743 744 745 746 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 743 class SslCertsCreateEphemeralRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#public_key ⇒ ::String
Returns PEM encoded public key to include in the signed certificate.
743 744 745 746 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_instances.rb', line 743 class SslCertsCreateEphemeralRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |