Class: Google::Cloud::Sql::V1::SslCertsInsertResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::SslCertsInsertResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_ssl_certs.rb
Overview
SslCert insert response.
Instance Attribute Summary collapse
-
#client_cert ⇒ ::Google::Cloud::Sql::V1::SslCertDetail
The new client certificate and private key.
-
#kind ⇒ ::String
This is always
sql#sslCertsInsert. -
#operation ⇒ ::Google::Cloud::Sql::V1::Operation
The operation to track the ssl certs insert request.
-
#server_ca_cert ⇒ ::Google::Cloud::Sql::V1::SslCert
The server Certificate Authority's certificate.
Instance Attribute Details
#client_cert ⇒ ::Google::Cloud::Sql::V1::SslCertDetail
Returns The new client certificate and private key.
101 102 103 104 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_ssl_certs.rb', line 101 class SslCertsInsertResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#kind ⇒ ::String
Returns This is always sql#sslCertsInsert.
101 102 103 104 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_ssl_certs.rb', line 101 class SslCertsInsertResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#operation ⇒ ::Google::Cloud::Sql::V1::Operation
Returns The operation to track the ssl certs insert request.
101 102 103 104 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_ssl_certs.rb', line 101 class SslCertsInsertResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#server_ca_cert ⇒ ::Google::Cloud::Sql::V1::SslCert
Returns The server Certificate Authority's certificate. If this is missing you can force a new one to be generated by calling resetSslConfig method on instances resource.
101 102 103 104 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_ssl_certs.rb', line 101 class SslCertsInsertResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |