Class: Google::Cloud::Sql::V1::Tier
- Inherits:
-
Object
- Object
- Google::Cloud::Sql::V1::Tier
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/sql/v1/cloud_sql_tiers.rb
Overview
A Google Cloud SQL service tier resource.
Instance Attribute Summary collapse
-
#Disk_Quota ⇒ ::Integer
The maximum disk size of this tier in bytes.
-
#kind ⇒ ::String
This is always
sql#tier. -
#RAM ⇒ ::Integer
The maximum RAM usage of this tier in bytes.
-
#region ⇒ ::Array<::String>
The applicable regions for this tier.
-
#tier ⇒ ::String
An identifier for the machine type, for example,
db-custom-1-3840.
Instance Attribute Details
#Disk_Quota ⇒ ::Integer
Returns The maximum disk size of this tier in bytes.
62 63 64 65 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_tiers.rb', line 62 class Tier include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#kind ⇒ ::String
Returns This is always sql#tier.
62 63 64 65 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_tiers.rb', line 62 class Tier include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#RAM ⇒ ::Integer
Returns The maximum RAM usage of this tier in bytes.
62 63 64 65 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_tiers.rb', line 62 class Tier include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#region ⇒ ::Array<::String>
Returns The applicable regions for this tier.
62 63 64 65 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_tiers.rb', line 62 class Tier include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#tier ⇒ ::String
Returns An identifier for the machine type, for example, db-custom-1-3840. For
related information, see Pricing.
62 63 64 65 |
# File 'proto_docs/google/cloud/sql/v1/cloud_sql_tiers.rb', line 62 class Tier include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |